(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    168333,       3912]*)
(*NotebookOutlinePosition[    168977,       3934]*)
(*  CellTagsIndexPosition[    168933,       3930]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[{
    \(\(<< Graphics`MultipleListPlot`;\)\), "\[IndentingNewLine]", 
    \(\(<< 
        Statistics`MultiDescriptiveStatistics`;\)\), "\[IndentingNewLine]", 
    \(\(<< Statistics`LinearRegression`;\)\), "\[IndentingNewLine]", 
    \(\(Off[General::spell1];\)\), "\[IndentingNewLine]", 
    \(\(Off[General::spell];\)\)}], "Input"],

Cell[CellGroupData[{

Cell["Define the HP Filter", "Subsubsection"],

Cell[BoxData[{
    \(\(\(Trend[vec_, smooth_] := 
        Module[{T, A, B}, 
          T = Length[vec]; \[IndentingNewLine]A = 
            Append[Append[
                Prepend[
                  Prepend[
                    Table[PadRight[
                        PadLeft[{\(-1\), 4, \(-6\), 4, \(-1\)}, t + 2], 
                        T], {t, 3, T - 2}], 
                    PadRight[{2, \(-5\), 4, \(-1\)}, T]], 
                  PadRight[{\(-1\), 2, \(-1\)}, T]], 
                PadLeft[{\(-1\), 4, \(-5\), 2}, T]], 
              PadLeft[{\(-1\), 2, \(-1\)}, T]]; \[IndentingNewLine]B = 
            Inverse[IdentityMatrix[T] - N[smooth]\ A]; \[IndentingNewLine]Exp[
            B . Log[N[vec]]]];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Detrend[vec_, smooth_] := 
        Log[vec] - Log[Trend[vec, smooth]];\)\)}], "Input"],

Cell[BoxData[
    \(\(SetDirectory["\<C:\FindSep\>"];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Set the HP Filter parameter to my preferred high value.", \
"Subsubsection"],

Cell[BoxData[
    \(\(smooth\  = \ 10\^5;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Set the start year.", "Subsubsection"],

Cell[BoxData[
    \(\(start = 1951;\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Import monthly data on Unemployment, Employment, Short-term Employment, and \
Help-Wanted Advertisements.  Adjust  the Short-Term Unemployment Rate Data to \
Account for the CPS Redesign.\
\>", "Subsubsection"],

Cell["\<\
The first 517 elements of the short-term unemployment rate series are fine.  \
On and after February 1994, the data are messed up by the January 1994 CPS \
Redesign.   See Appendix A in  \"Reassessing the Ins and Outs of \
Unemployment,\" January 28, 2005 version.  I correct this using the CPS \
microdata.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(UnempM = Import["\<unemp.txt\>", "\<Lines\>"];\)\), "\n", 
    \(\(Print[UnempM\[LeftDoubleBracket]1\[RightDoubleBracket]];\)\), "\n", 
    \(\(\(UnempM = ToExpression @@ {Drop[UnempM, 1]};\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(EmpM = Import["\<emp.txt\>", "\<Lines\>"];\)\), "\n", 
    \(\(Print[EmpM\[LeftDoubleBracket]1\[RightDoubleBracket]];\)\), "\n", 
    \(\(\(EmpM = ToExpression @@ {Drop[EmpM, 1]};\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(ShortM = Import["\<short.txt\>", "\<Lines\>"];\)\), "\n", 
    \(\(Print[ShortM\[LeftDoubleBracket]1\[RightDoubleBracket]];\)\), "\n", 
    \(\(\(ShortM = ToExpression @@ {Drop[ShortM, 1]};\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(HelpM = Import["\<helpwant.txt\>", "\<Lines\>"];\)\), "\n", 
    \(\(Print[HelpM\[LeftDoubleBracket]1\[RightDoubleBracket]];\)\), "\n", 
    \(\(\(HelpM = ToExpression @@ {Drop[HelpM, 1]};\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(ShortShareM = Import["\<shortadj.txt\>", "\<Lines\>"];\)\), "\n", 
    \(Print[ShortShareM\[LeftDoubleBracket]1\[RightDoubleBracket]]; 
    ShortShareM = 
      ToExpression @@ {Drop[ShortShareM, 1]};\), "\[IndentingNewLine]", 
    \(\(ShortAdjM = 
        ShortShareM*
          Take[UnempM, {12 \((1976 - start)\) + 1, 
              12 \((1976 - start)\) + Length[ShortShareM]}];\)\), "\n", 
    \(\(ShortAdjM = 
        Flatten[Prepend[ShortAdjM, 
            Take[ShortM, 12 \((1976 - start)\)]]];\)\)}], "Input"],

Cell[BoxData[
    \("LNS13000000, Seas Adj Unmployment Level (Thousands), 16 years and \
over, 1951:M1--2005:M4, Downloaded May 14, 2005"\)], "Print"],

Cell[BoxData[
    \("LNS12000000, Seas Adj Employment Level (Thousands), 16 years and over, \
1951:M1--2005:M4, Downloaded May 14, 2005"\)], "Print"],

Cell[BoxData[
    \("LNS13008396, Seas Adj Unemployed for Less than 5 Weeks (Thousands), 16 \
years and over, 1951:M1--2005:M4, Downloaded May 14, 2005"\)], "Print"],

Cell[BoxData[
    \("Index of Help Wanted Advertising in Newspapers, The Conference Board, \
1987=100, 1951:M1 to 2005:M3 Last Updated: 2005-04-28 10:06 AM CT"\)], "Print"],

Cell[BoxData[
    \("Fraction of Unemployed with Duration <= 4 weeks, Sample: Age >= 16, \
MIS = 1 or 5.  Computed from CPS Microdata and seasonally adjusted using the \
Census X-12 Algorithm, 1976:M1--2005:M1"\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Figure out the longest available data series and print the stopping date.\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(available\  = 
        Min[{Length[UnempM], Length[EmpM], Length[HelpM], 
            Length[ShortAdjM]}];\)\), "\n", 
    \(UnempM = Take[UnempM, available]; EmpM = Take[EmpM, available]; 
    HelpM = Take[HelpM, available]; 
    ShortAdjM = Take[ShortAdjM, available];\), "\n", 
    \(\(Print[IntegerPart[start + available\/12], "\<:M\>", 
        available - 12  IntegerPart[available\/12]];\)\), "\n", 
    \(dateM[x_] := 
      Transpose[{Table[start + \(i - 1\)\/12. , {i, 1, Length[x]}], x}]; 
    dateQ[x_] := 
      Transpose[{Table[start + \(i - 1\)\/4. , {i, 1, Length[x]}], 
          x}];\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\(2005\[InvisibleSpace]":M"\[InvisibleSpace]1\),
      SequenceForm[ 2005, ":M", 1],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Construct the unemployment rate, led by one period.", "Subsubsection"],

Cell[BoxData[
    \(\(UrateM = Drop[UnempM\/\(UnempM + EmpM\), 1];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot the Adjustment to the Short Term Unemployment Rate time series.\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(MultipleListPlot[dateM[ShortAdjM], dateM[ShortM], 
        PlotJoined \[Rule] True, PlotStyle \[Rule] {Hue[0], Hue[2/3]}, 
        PlotLegend \[Rule] {"\<Adjusted\>", "\<Published Data\>"}, 
        PlotLabel \[Rule] "\<Short Term Unemployment\>", 
        SymbolShape \[Rule] None];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42623 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.352217 0.328407 0.213115 0.328407 [
[ 0 0 0 0 ]
[ 1 .42623 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0101483 0.680624 0.416082 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-34.2268 0.0175554 -0.176125 0.000196136 [
[.18181 -0.0121 -12 -9 ]
[.18181 -0.0121 12 0 ]
[.35736 -0.0121 -12 -9 ]
[.35736 -0.0121 12 0 ]
[.53292 -0.0121 -12 -9 ]
[.53292 -0.0121 12 0 ]
[.70847 -0.0121 -12 -9 ]
[.70847 -0.0121 12 0 ]
[.88402 -0.0121 -12 -9 ]
[.88402 -0.0121 12 0 ]
[-0.00625 .02001 -24 -4.5 ]
[-0.00625 .02001 0 4.5 ]
[-0.00625 .11808 -24 -4.5 ]
[-0.00625 .11808 0 4.5 ]
[-0.00625 .21615 -24 -4.5 ]
[-0.00625 .21615 0 4.5 ]
[-0.00625 .31421 -24 -4.5 ]
[-0.00625 .31421 0 4.5 ]
[-0.00625 .41228 -24 -4.5 ]
[-0.00625 .41228 0 4.5 ]
[-0.00625 .51035 -24 -4.5 ]
[-0.00625 .51035 0 4.5 ]
[-0.00625 .60842 -24 -4.5 ]
[-0.00625 .60842 0 4.5 ]
[.5 .63053 -71 0 ]
[.5 .63053 71 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18181 .0004 m
.18181 .00665 L
s
[(1960)] .18181 -0.0121 0 1 Mshowa
.35736 .0004 m
.35736 .00665 L
s
[(1970)] .35736 -0.0121 0 1 Mshowa
.53292 .0004 m
.53292 .00665 L
s
[(1980)] .53292 -0.0121 0 1 Mshowa
.70847 .0004 m
.70847 .00665 L
s
[(1990)] .70847 -0.0121 0 1 Mshowa
.88402 .0004 m
.88402 .00665 L
s
[(2000)] .88402 -0.0121 0 1 Mshowa
.125 Mabswid
.04136 .0004 m
.04136 .00415 L
s
.07648 .0004 m
.07648 .00415 L
s
.11159 .0004 m
.11159 .00415 L
s
.1467 .0004 m
.1467 .00415 L
s
.21692 .0004 m
.21692 .00415 L
s
.25203 .0004 m
.25203 .00415 L
s
.28714 .0004 m
.28714 .00415 L
s
.32225 .0004 m
.32225 .00415 L
s
.39247 .0004 m
.39247 .00415 L
s
.42758 .0004 m
.42758 .00415 L
s
.46269 .0004 m
.46269 .00415 L
s
.49781 .0004 m
.49781 .00415 L
s
.56803 .0004 m
.56803 .00415 L
s
.60314 .0004 m
.60314 .00415 L
s
.63825 .0004 m
.63825 .00415 L
s
.67336 .0004 m
.67336 .00415 L
s
.74358 .0004 m
.74358 .00415 L
s
.77869 .0004 m
.77869 .00415 L
s
.8138 .0004 m
.8138 .00415 L
s
.84891 .0004 m
.84891 .00415 L
s
.91914 .0004 m
.91914 .00415 L
s
.95425 .0004 m
.95425 .00415 L
s
.98936 .0004 m
.98936 .00415 L
s
.25 Mabswid
0 .0004 m
1 .0004 L
s
.00625 .02001 m
.0125 .02001 L
s
[(1000)] -0.00625 .02001 1 0 Mshowa
.00625 .11808 m
.0125 .11808 L
s
[(1500)] -0.00625 .11808 1 0 Mshowa
.00625 .21615 m
.0125 .21615 L
s
[(2000)] -0.00625 .21615 1 0 Mshowa
.00625 .31421 m
.0125 .31421 L
s
[(2500)] -0.00625 .31421 1 0 Mshowa
.00625 .41228 m
.0125 .41228 L
s
[(3000)] -0.00625 .41228 1 0 Mshowa
.00625 .51035 m
.0125 .51035 L
s
[(3500)] -0.00625 .51035 1 0 Mshowa
.00625 .60842 m
.0125 .60842 L
s
[(4000)] -0.00625 .60842 1 0 Mshowa
.125 Mabswid
.00625 .03962 m
.01 .03962 L
s
.00625 .05924 m
.01 .05924 L
s
.00625 .07885 m
.01 .07885 L
s
.00625 .09847 m
.01 .09847 L
s
.00625 .13769 m
.01 .13769 L
s
.00625 .15731 m
.01 .15731 L
s
.00625 .17692 m
.01 .17692 L
s
.00625 .19653 m
.01 .19653 L
s
.00625 .23576 m
.01 .23576 L
s
.00625 .25537 m
.01 .25537 L
s
.00625 .27499 m
.01 .27499 L
s
.00625 .2946 m
.01 .2946 L
s
.00625 .33383 m
.01 .33383 L
s
.00625 .35344 m
.01 .35344 L
s
.00625 .37306 m
.01 .37306 L
s
.00625 .39267 m
.01 .39267 L
s
.00625 .4319 m
.01 .4319 L
s
.00625 .45151 m
.01 .45151 L
s
.00625 .47112 m
.01 .47112 L
s
.00625 .49074 m
.01 .49074 L
s
.00625 .52996 m
.01 .52996 L
s
.00625 .54958 m
.01 .54958 L
s
.00625 .56919 m
.01 .56919 L
s
.00625 .5888 m
.01 .5888 L
s
.25 Mabswid
.00625 0 m
.00625 .61803 L
s
gsave
.5 .63053 -132 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Short) show
99.000 12.813 moveto
(Term) show
129.000 12.813 moveto
(Unemployment) show
201.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.001 w
.02381 .04257 m
.02527 .041 L
.02674 .06218 L
.0282 .05139 L
.02966 .04453 L
.03112 .04453 L
.03259 .0559 L
.03405 .0561 L
.03551 .07767 L
.03698 .07473 L
.03844 .06571 L
.0399 .04708 L
.04136 .03296 L
.04283 .05551 L
.04429 .04943 L
.04575 .04688 L
.04722 .05512 L
.04868 .05845 L
.05014 .05669 L
.05161 .07297 L
.05307 .04551 L
.05453 .02982 L
.05599 .02335 L
.05746 .02864 L
.05892 .03158 L
.06038 .03335 L
.06185 .0257 L
.06331 .0457 L
.06477 .01472 L
.06624 .01707 L
.0677 .0204 L
.06916 .03492 L
.07062 .05198 L
.07209 .06748 L
.07355 .08022 L
.07501 .16927 L
.07648 .14377 L
.07794 .15848 L
.0794 .16299 L
.08086 .16221 L
.08233 .14613 L
.08379 .1324 L
.08525 .1422 L
.08672 .13514 L
.08818 .14554 L
.08964 .12494 L
.09111 .10964 L
.09257 .10121 L
.09403 .09807 L
.09549 .07807 L
Mistroke
.09696 .0561 L
.09842 .07905 L
.09988 .07787 L
.10135 .07983 L
.10281 .07532 L
.10427 .10729 L
.10573 .09003 L
.1072 .10415 L
.10866 .09572 L
.11012 .0863 L
.11159 .08591 L
.11305 .07669 L
.11451 .11847 L
.11598 .08925 L
.11744 .11474 L
.1189 .11906 L
.12036 .112 L
.12183 .09376 L
.12329 .08984 L
.12475 .08258 L
.12622 .11435 L
.12768 .10749 L
.12914 .09317 L
.1306 .07748 L
.13207 .06728 L
.13353 .08572 L
.13499 .10298 L
.13646 .0969 L
.13792 .0918 L
.13938 .09748 L
.14085 .11494 L
.14231 .09827 L
.14377 .1373 L
.14523 .13475 L
.1467 .1575 L
.14816 .1932 L
.14962 .20301 L
.15109 .19281 L
.15255 .18771 L
.15401 .16809 L
.15548 .18045 L
.15694 .16907 L
.1584 .14279 L
.15986 .14613 L
.16133 .12416 L
.16279 .15574 L
.16425 .13259 L
.16572 .12867 L
.16718 .11004 L
.16864 .1169 L
Mistroke
.1701 .11396 L
.17157 .12239 L
.17303 .13593 L
.17449 .13907 L
.17596 .13808 L
.17742 .16711 L
.17888 .16613 L
.18035 .14887 L
.18181 .14515 L
.18327 .10455 L
.18473 .15064 L
.1862 .16417 L
.18766 .16084 L
.18912 .16476 L
.19059 .15907 L
.19205 .16633 L
.19351 .15279 L
.19497 .17025 L
.19644 .16084 L
.1979 .23615 L
.19936 .19339 L
.20083 .2234 L
.20229 .18928 L
.20375 .16299 L
.20522 .16672 L
.20668 .18496 L
.20814 .17476 L
.2096 .1575 L
.21107 .18849 L
.21253 .17908 L
.21399 .14515 L
.21546 .16397 L
.21692 .1575 L
.21838 .11886 L
.21984 .16142 L
.22131 .14338 L
.22277 .12651 L
.22423 .1373 L
.2257 .13612 L
.22716 .16339 L
.22862 .16692 L
.23009 .14475 L
.23155 .18437 L
.23301 .16358 L
.23447 .16319 L
.23594 .1883 L
.2374 .1575 L
.23886 .16064 L
.24033 .19065 L
.24179 .16103 L
Mistroke
.24325 .15593 L
.24472 .15279 L
.24618 .15633 L
.24764 .16476 L
.2491 .18849 L
.25057 .17182 L
.25203 .1779 L
.25349 .15887 L
.25496 .17359 L
.25642 .17045 L
.25788 .15358 L
.25934 .16103 L
.26081 .11533 L
.26227 .15652 L
.26373 .15789 L
.2652 .1679 L
.26666 .13691 L
.26812 .15181 L
.26959 .14279 L
.27105 .16574 L
.27251 .1577 L
.27397 .16652 L
.27544 .15142 L
.2769 .14868 L
.27836 .14828 L
.27983 .14024 L
.28129 .14299 L
.28275 .12455 L
.28421 .12416 L
.28568 .10553 L
.28714 .12259 L
.2886 .11906 L
.29007 .12259 L
.29153 .13044 L
.29299 .14377 L
.29446 .14691 L
.29592 .14554 L
.29738 .14201 L
.29884 .12887 L
.30031 .12612 L
.30177 .11788 L
.30323 .13416 L
.3047 .13926 L
.30616 .13691 L
.30762 .13495 L
.30908 .1273 L
.31055 .13397 L
.31201 .15809 L
.31347 .14593 L
.31494 .13671 L
Mistroke
.3164 .15083 L
.31786 .16319 L
.31933 .15338 L
.32079 .14083 L
.32225 .10984 L
.32371 .15927 L
.32518 .1477 L
.32664 .10553 L
.3281 .13122 L
.32957 .16809 L
.33103 .14691 L
.33249 .14652 L
.33396 .12475 L
.33542 .11945 L
.33688 .13632 L
.33834 .12337 L
.33981 .12867 L
.34127 .1067 L
.34273 .13828 L
.3442 .13769 L
.34566 .1473 L
.34712 .15024 L
.34858 .15456 L
.35005 .14495 L
.35151 .15593 L
.35297 .17967 L
.35444 .13377 L
.3559 .13475 L
.35736 .17692 L
.35883 .20634 L
.36029 .21183 L
.36175 .24341 L
.36321 .23753 L
.36468 .23576 L
.36614 .24204 L
.3676 .25184 L
.36907 .26224 L
.37053 .29186 L
.37199 .28244 L
.37345 .28852 L
.37492 .27538 L
.37638 .25106 L
.37784 .24439 L
.37931 .25655 L
.38077 .26106 L
.38223 .25145 L
.3837 .25734 L
.38516 .28224 L
.38662 .27518 L
.38808 .25969 L
Mistroke
.38955 .27577 L
.39101 .27891 L
.39247 .27969 L
.39394 .23792 L
.3954 .27558 L
.39686 .26106 L
.39832 .2538 L
.39979 .27087 L
.40125 .26479 L
.40271 .27205 L
.40418 .28538 L
.40564 .28499 L
.4071 .25361 L
.40857 .21674 L
.41003 .22301 L
.41149 .26695 L
.41295 .24282 L
.41442 .26714 L
.41588 .25988 L
.41734 .2793 L
.41881 .2693 L
.42027 .27303 L
.42173 .25753 L
.4232 .2285 L
.42466 .27263 L
.42612 .28126 L
.42758 .2946 L
.42905 .30088 L
.43051 .29715 L
.43197 .28224 L
.43344 .30578 L
.4349 .31363 L
.43636 .31931 L
.43782 .33559 L
.43929 .35795 L
.44075 .35795 L
.44221 .42248 L
.44368 .4368 L
.44514 .46975 L
.4466 .40189 L
.44807 .45014 L
.44953 .39561 L
.45099 .42229 L
.45245 .38718 L
.45392 .38914 L
.45538 .37462 L
.45684 .38835 L
.45831 .40483 L
.45977 .35697 L
.46123 .3656 L
Mistroke
.46269 .36855 L
.46416 .37234 L
.46562 .32842 L
.46708 .37318 L
.46855 .35584 L
.47001 .38091 L
.47147 .39577 L
.47294 .39152 L
.4744 .39705 L
.47586 .40451 L
.47732 .38772 L
.47879 .40633 L
.48025 .39397 L
.48171 .41136 L
.48318 .40569 L
.48464 .39903 L
.4861 .34768 L
.48756 .43478 L
.48903 .37731 L
.49049 .39739 L
.49195 .38525 L
.49342 .38815 L
.49488 .39822 L
.49634 .36862 L
.49781 .3888 L
.49927 .37152 L
.50073 .39216 L
.50219 .3668 L
.50366 .38434 L
.50512 .36785 L
.50658 .41536 L
.50805 .38765 L
.50951 .4003 L
.51097 .37549 L
.51244 .39005 L
.5139 .40868 L
.51536 .38061 L
.51682 .40203 L
.51829 .38818 L
.51975 .40907 L
.52121 .36962 L
.52268 .39564 L
.52414 .37525 L
.5256 .47133 L
.52706 .39837 L
.52853 .42422 L
.52999 .42964 L
.53145 .42336 L
.53292 .46591 L
.53438 .44594 L
Mistroke
.53584 .43763 L
.53731 .49114 L
.53877 .5608 L
.54023 .50909 L
.54169 .50096 L
.54316 .49494 L
.54462 .43646 L
.54608 .45773 L
.54755 .44235 L
.54901 .41711 L
.55047 .45913 L
.55193 .45421 L
.5534 .46239 L
.55486 .43694 L
.55632 .48582 L
.55779 .48032 L
.55925 .457 L
.56071 .46215 L
.56218 .49153 L
.56364 .53796 L
.5651 .56522 L
.56656 .58404 L
.56803 .57924 L
.56949 .5639 L
.57095 .57562 L
.57242 .58634 L
.57388 .56632 L
.57534 .52934 L
.5768 .59254 L
.57827 .57826 L
.57973 .5945 L
.58119 .57846 L
.58266 .58832 L
.58412 .58017 L
.58558 .53727 L
.58705 .54467 L
.58851 .51474 L
.58997 .5234 L
.59143 .52341 L
.5929 .56023 L
.59436 .5042 L
.59582 .5294 L
.59729 .54986 L
.59875 .50299 L
.60021 .47355 L
.60168 .49553 L
.60314 .46174 L
.6046 .47662 L
.60606 .47089 L
.60753 .47792 L
Mistroke
.60899 .44923 L
.61045 .45618 L
.61192 .48979 L
.61338 .51765 L
.61484 .47187 L
.6163 .49538 L
.61777 .49374 L
.61923 .48971 L
.62069 .53534 L
.62216 .5032 L
.62362 .51293 L
.62508 .51067 L
.62655 .51024 L
.62801 .52123 L
.62947 .53248 L
.63093 .49829 L
.6324 .50709 L
.63386 .49752 L
.63532 .50089 L
.63679 .49281 L
.63825 .47075 L
.63971 .52164 L
.64117 .51667 L
.64264 .53607 L
.6441 .52842 L
.64556 .50928 L
.64703 .50292 L
.64849 .49189 L
.64995 .49063 L
.65142 .50222 L
.65288 .47536 L
.65434 .47065 L
.6558 .48269 L
.65727 .47897 L
.65873 .48434 L
.66019 .44832 L
.66166 .48234 L
.66312 .445 L
.66458 .44874 L
.66604 .45197 L
.66751 .45425 L
.66897 .46438 L
.67043 .45063 L
.6719 .45907 L
.67336 .43131 L
.67482 .43008 L
.67629 .42874 L
.67775 .45371 L
.67921 .43273 L
.68067 .41759 L
Mistroke
.68214 .40209 L
.6836 .45238 L
.68506 .43866 L
.68653 .43287 L
.68799 .43019 L
.68945 .41785 L
.69092 .4491 L
.69238 .45696 L
.69384 .41868 L
.6953 .43772 L
.69677 .42527 L
.69823 .46532 L
.69969 .44477 L
.70116 .43057 L
.70262 .45184 L
.70408 .4514 L
.70554 .45674 L
.70701 .47177 L
.70847 .45533 L
.70993 .46643 L
.7114 .46502 L
.71286 .47676 L
.71432 .42503 L
.71579 .42118 L
.71725 .44496 L
.71871 .48949 L
.72017 .46437 L
.72164 .48271 L
.7231 .52377 L
.72456 .51299 L
.72603 .5146 L
.72749 .52581 L
.72895 .52737 L
.73041 .50037 L
.73188 .53634 L
.73334 .49308 L
.7348 .49883 L
.73627 .5186 L
.73773 .51347 L
.73919 .50046 L
.74066 .50913 L
.74212 .50201 L
.74358 .49742 L
.74504 .45674 L
.74651 .49376 L
.74797 .46535 L
.74943 .50211 L
.7509 .52281 L
.75236 .49472 L
.75382 .4933 L
Mistroke
.75528 .4915 L
.75675 .47283 L
.75821 .48196 L
.75967 .44111 L
.76114 .47936 L
.7626 .48589 L
.76406 .45796 L
.76553 .48416 L
.76699 .49125 L
.76845 .45894 L
.76991 .4647 L
.77138 .43112 L
.77284 .44053 L
.7743 .4544 L
.77577 .43151 L
.77723 .4564 L
.77869 .47158 L
.78016 .4419 L
.78162 .42325 L
.78308 .49237 L
.78454 .45298 L
.78601 .47129 L
.78747 .48867 L
.78893 .48071 L
.7904 .45595 L
.79186 .39689 L
.79332 .47535 L
.79478 .39046 L
.79625 .4436 L
.79771 .4481 L
.79917 .43745 L
.80064 .47808 L
.8021 .44063 L
.80356 .4676 L
.80503 .46521 L
.80649 .46312 L
.80795 .49274 L
.80941 .42202 L
.81088 .46231 L
.81234 .47776 L
.8138 .47687 L
.81527 .43679 L
.81673 .42039 L
.81819 .4479 L
.81965 .43442 L
.82112 .4517 L
.82258 .4791 L
.82404 .44103 L
.82551 .42603 L
.82697 .46872 L
Mistroke
.82843 .474 L
.8299 .46169 L
.83136 .48858 L
.83282 .44058 L
.83428 .45707 L
.83575 .40091 L
.83721 .43917 L
.83867 .44798 L
.84014 .38855 L
.8416 .42873 L
.84306 .41701 L
.84452 .41753 L
.84599 .41592 L
.84745 .41037 L
.84891 .40436 L
.85038 .45984 L
.85184 .45641 L
.8533 .41538 L
.85477 .45508 L
.85623 .37877 L
.85769 .43866 L
.85915 .40213 L
.86062 .45676 L
.86208 .45645 L
.86354 .39442 L
.86501 .39332 L
.86647 .37227 L
.86793 .40113 L
.8694 .39385 L
.87086 .40589 L
.87232 .36862 L
.87378 .38018 L
.87525 .41963 L
.87671 .39758 L
.87817 .4104 L
.87964 .35859 L
.8811 .41405 L
.88256 .44063 L
.88402 .42629 L
.88549 .42628 L
.88695 .36126 L
.88841 .37519 L
.88988 .40972 L
.89134 .3932 L
.8928 .40441 L
.89427 .41569 L
.89573 .3959 L
.89719 .38268 L
.89865 .40542 L
.90012 .40798 L
Mistroke
.90158 .42309 L
.90304 .4336 L
.90451 .43894 L
.90597 .48889 L
.90743 .41205 L
.90889 .41569 L
.91036 .40435 L
.91182 .48569 L
.91328 .4617 L
.91475 .53652 L
.91621 .45044 L
.91767 .51525 L
.91914 .52653 L
.9206 .46172 L
.92206 .5027 L
.92352 .50516 L
.92499 .47351 L
.92645 .48465 L
.92791 .50821 L
.92938 .49222 L
.93084 .45944 L
.9323 .41658 L
.93376 .4702 L
.93523 .46566 L
.93669 .45102 L
.93815 .50573 L
.93962 .43933 L
.94108 .45428 L
.94254 .47796 L
.94401 .49924 L
.94547 .43147 L
.94693 .4112 L
.94839 .37398 L
.94986 .43802 L
.95132 .47505 L
.95278 .41501 L
.95425 .4035 L
.95571 .40572 L
.95717 .35112 L
.95864 .41092 L
.9601 .44277 L
.96156 .43593 L
.96302 .4656 L
.96449 .36705 L
.96595 .43636 L
.96741 .42121 L
.96888 .41125 L
.97034 .50929 L
.9718 .39869 L
Mfstroke
0 0 1 r
.02381 .04257 m
.02527 .041 L
.02674 .06218 L
.0282 .05139 L
.02966 .04453 L
.03112 .04453 L
.03259 .0559 L
.03405 .0561 L
.03551 .07767 L
.03698 .07473 L
.03844 .06571 L
.0399 .04708 L
.04136 .03296 L
.04283 .05551 L
.04429 .04943 L
.04575 .04688 L
.04722 .05512 L
.04868 .05845 L
.05014 .05669 L
.05161 .07297 L
.05307 .04551 L
.05453 .02982 L
.05599 .02335 L
.05746 .02864 L
.05892 .03158 L
.06038 .03335 L
.06185 .0257 L
.06331 .0457 L
.06477 .01472 L
.06624 .01707 L
.0677 .0204 L
.06916 .03492 L
.07062 .05198 L
.07209 .06748 L
.07355 .08022 L
.07501 .16927 L
.07648 .14377 L
.07794 .15848 L
.0794 .16299 L
.08086 .16221 L
.08233 .14613 L
.08379 .1324 L
.08525 .1422 L
.08672 .13514 L
.08818 .14554 L
.08964 .12494 L
.09111 .10964 L
.09257 .10121 L
.09403 .09807 L
.09549 .07807 L
Mistroke
.09696 .0561 L
.09842 .07905 L
.09988 .07787 L
.10135 .07983 L
.10281 .07532 L
.10427 .10729 L
.10573 .09003 L
.1072 .10415 L
.10866 .09572 L
.11012 .0863 L
.11159 .08591 L
.11305 .07669 L
.11451 .11847 L
.11598 .08925 L
.11744 .11474 L
.1189 .11906 L
.12036 .112 L
.12183 .09376 L
.12329 .08984 L
.12475 .08258 L
.12622 .11435 L
.12768 .10749 L
.12914 .09317 L
.1306 .07748 L
.13207 .06728 L
.13353 .08572 L
.13499 .10298 L
.13646 .0969 L
.13792 .0918 L
.13938 .09748 L
.14085 .11494 L
.14231 .09827 L
.14377 .1373 L
.14523 .13475 L
.1467 .1575 L
.14816 .1932 L
.14962 .20301 L
.15109 .19281 L
.15255 .18771 L
.15401 .16809 L
.15548 .18045 L
.15694 .16907 L
.1584 .14279 L
.15986 .14613 L
.16133 .12416 L
.16279 .15574 L
.16425 .13259 L
.16572 .12867 L
.16718 .11004 L
.16864 .1169 L
Mistroke
.1701 .11396 L
.17157 .12239 L
.17303 .13593 L
.17449 .13907 L
.17596 .13808 L
.17742 .16711 L
.17888 .16613 L
.18035 .14887 L
.18181 .14515 L
.18327 .10455 L
.18473 .15064 L
.1862 .16417 L
.18766 .16084 L
.18912 .16476 L
.19059 .15907 L
.19205 .16633 L
.19351 .15279 L
.19497 .17025 L
.19644 .16084 L
.1979 .23615 L
.19936 .19339 L
.20083 .2234 L
.20229 .18928 L
.20375 .16299 L
.20522 .16672 L
.20668 .18496 L
.20814 .17476 L
.2096 .1575 L
.21107 .18849 L
.21253 .17908 L
.21399 .14515 L
.21546 .16397 L
.21692 .1575 L
.21838 .11886 L
.21984 .16142 L
.22131 .14338 L
.22277 .12651 L
.22423 .1373 L
.2257 .13612 L
.22716 .16339 L
.22862 .16692 L
.23009 .14475 L
.23155 .18437 L
.23301 .16358 L
.23447 .16319 L
.23594 .1883 L
.2374 .1575 L
.23886 .16064 L
.24033 .19065 L
.24179 .16103 L
Mistroke
.24325 .15593 L
.24472 .15279 L
.24618 .15633 L
.24764 .16476 L
.2491 .18849 L
.25057 .17182 L
.25203 .1779 L
.25349 .15887 L
.25496 .17359 L
.25642 .17045 L
.25788 .15358 L
.25934 .16103 L
.26081 .11533 L
.26227 .15652 L
.26373 .15789 L
.2652 .1679 L
.26666 .13691 L
.26812 .15181 L
.26959 .14279 L
.27105 .16574 L
.27251 .1577 L
.27397 .16652 L
.27544 .15142 L
.2769 .14868 L
.27836 .14828 L
.27983 .14024 L
.28129 .14299 L
.28275 .12455 L
.28421 .12416 L
.28568 .10553 L
.28714 .12259 L
.2886 .11906 L
.29007 .12259 L
.29153 .13044 L
.29299 .14377 L
.29446 .14691 L
.29592 .14554 L
.29738 .14201 L
.29884 .12887 L
.30031 .12612 L
.30177 .11788 L
.30323 .13416 L
.3047 .13926 L
.30616 .13691 L
.30762 .13495 L
.30908 .1273 L
.31055 .13397 L
.31201 .15809 L
.31347 .14593 L
.31494 .13671 L
Mistroke
.3164 .15083 L
.31786 .16319 L
.31933 .15338 L
.32079 .14083 L
.32225 .10984 L
.32371 .15927 L
.32518 .1477 L
.32664 .10553 L
.3281 .13122 L
.32957 .16809 L
.33103 .14691 L
.33249 .14652 L
.33396 .12475 L
.33542 .11945 L
.33688 .13632 L
.33834 .12337 L
.33981 .12867 L
.34127 .1067 L
.34273 .13828 L
.3442 .13769 L
.34566 .1473 L
.34712 .15024 L
.34858 .15456 L
.35005 .14495 L
.35151 .15593 L
.35297 .17967 L
.35444 .13377 L
.3559 .13475 L
.35736 .17692 L
.35883 .20634 L
.36029 .21183 L
.36175 .24341 L
.36321 .23753 L
.36468 .23576 L
.36614 .24204 L
.3676 .25184 L
.36907 .26224 L
.37053 .29186 L
.37199 .28244 L
.37345 .28852 L
.37492 .27538 L
.37638 .25106 L
.37784 .24439 L
.37931 .25655 L
.38077 .26106 L
.38223 .25145 L
.3837 .25734 L
.38516 .28224 L
.38662 .27518 L
.38808 .25969 L
Mistroke
.38955 .27577 L
.39101 .27891 L
.39247 .27969 L
.39394 .23792 L
.3954 .27558 L
.39686 .26106 L
.39832 .2538 L
.39979 .27087 L
.40125 .26479 L
.40271 .27205 L
.40418 .28538 L
.40564 .28499 L
.4071 .25361 L
.40857 .21674 L
.41003 .22301 L
.41149 .26695 L
.41295 .24282 L
.41442 .26714 L
.41588 .25988 L
.41734 .2793 L
.41881 .2693 L
.42027 .27303 L
.42173 .25753 L
.4232 .2285 L
.42466 .27263 L
.42612 .28126 L
.42758 .2946 L
.42905 .30088 L
.43051 .29715 L
.43197 .28224 L
.43344 .30578 L
.4349 .31363 L
.43636 .31931 L
.43782 .33559 L
.43929 .35795 L
.44075 .35795 L
.44221 .42248 L
.44368 .4368 L
.44514 .46975 L
.4466 .40189 L
.44807 .45014 L
.44953 .39561 L
.45099 .42229 L
.45245 .38718 L
.45392 .38914 L
.45538 .37462 L
.45684 .38835 L
.45831 .40483 L
.45977 .35697 L
.46123 .3656 L
Mistroke
.46269 .36305 L
.46416 .37286 L
.46562 .33932 L
.46708 .40012 L
.46855 .37207 L
.47001 .37051 L
.47147 .40542 L
.47294 .3913 L
.4744 .39463 L
.47586 .4015 L
.47732 .37815 L
.47879 .39679 L
.48025 .39149 L
.48171 .41522 L
.48318 .41091 L
.48464 .41522 L
.4861 .36403 L
.48756 .43935 L
.48903 .38463 L
.49049 .39188 L
.49195 .38933 L
.49342 .38933 L
.49488 .39738 L
.49634 .35913 L
.49781 .37776 L
.49927 .36599 L
.50073 .38698 L
.50219 .36325 L
.50366 .38678 L
.50512 .3707 L
.50658 .42582 L
.50805 .38443 L
.50951 .40071 L
.51097 .37031 L
.51244 .39326 L
.5139 .40797 L
.51536 .37129 L
.51682 .39247 L
.51829 .38149 L
.51975 .40012 L
.52121 .36776 L
.52268 .40189 L
.52414 .39071 L
.5256 .47034 L
.52706 .40169 L
.52853 .41993 L
.52999 .41817 L
.53145 .41483 L
.53292 .45445 L
.53438 .43856 L
Mistroke
.53584 .43131 L
.53731 .48564 L
.53877 .56017 L
.54023 .4925 L
.54169 .50211 L
.54316 .49368 L
.54462 .4417 L
.54608 .45857 L
.54755 .44092 L
.54901 .43131 L
.55047 .47465 L
.55193 .46857 L
.5534 .47662 L
.55486 .44857 L
.55632 .4925 L
.55779 .47897 L
.55925 .4725 L
.56071 .47505 L
.56218 .50898 L
.56364 .54095 L
.5651 .57154 L
.56656 .59842 L
.56803 .59351 L
.56949 .57076 L
.57095 .58802 L
.57242 .59881 L
.57388 .58586 L
.57534 .53114 L
.5768 .59449 L
.57827 .58782 L
.57973 .60175 L
.58119 .58351 L
.58266 .60332 L
.58412 .59645 L
.58558 .54056 L
.58705 .55291 L
.58851 .51074 L
.58997 .518 L
.59143 .51643 L
.5929 .54683 L
.59436 .50231 L
.59582 .53624 L
.59729 .56291 L
.59875 .50859 L
.60021 .48034 L
.60168 .50152 L
.60314 .47289 L
.6046 .47642 L
.60606 .47799 L
.60753 .48328 L
Mistroke
.60899 .44504 L
.61045 .46347 L
.61192 .48917 L
.61338 .52349 L
.61484 .47603 L
.6163 .49525 L
.61777 .48917 L
.61923 .48505 L
.62069 .54311 L
.62216 .50466 L
.62362 .51408 L
.62508 .51015 L
.62655 .51094 L
.62801 .5178 L
.62947 .52114 L
.63093 .49839 L
.6324 .50917 L
.63386 .49544 L
.63532 .50309 L
.63679 .48936 L
.63825 .4776 L
.63971 .51349 L
.64117 .5182 L
.64264 .52957 L
.6441 .52722 L
.64556 .50819 L
.64703 .49976 L
.64849 .49839 L
.64995 .49172 L
.65142 .49388 L
.65288 .47956 L
.65434 .47053 L
.6558 .48878 L
.65727 .47563 L
.65873 .48799 L
.66019 .44406 L
.66166 .47407 L
.66312 .44504 L
.66458 .45484 L
.66604 .44974 L
.66751 .45622 L
.66897 .45955 L
.67043 .44602 L
.6719 .44719 L
.67336 .42915 L
.67482 .42346 L
.67629 .42052 L
.67775 .43327 L
.67921 .43092 L
.68067 .43209 L
Mistroke
.68214 .41189 L
.6836 .44602 L
.68506 .4421 L
.68653 .43307 L
.68799 .43131 L
.68945 .40679 L
.69092 .44092 L
.69238 .45033 L
.69384 .42052 L
.6953 .43386 L
.69677 .42248 L
.69823 .47171 L
.69969 .44621 L
.70116 .42993 L
.70262 .45426 L
.70408 .45504 L
.70554 .46073 L
.70701 .46622 L
.70847 .44935 L
.70993 .45602 L
.7114 .45269 L
.71286 .46504 L
.71432 .43523 L
.71579 .4419 L
.71725 .45563 L
.71871 .47505 L
.72017 .4672 L
.72164 .48034 L
.7231 .49897 L
.72456 .5029 L
.72603 .50447 L
.72749 .52702 L
.72895 .518 L
.73041 .49074 L
.73188 .53408 L
.73334 .49623 L
.7348 .49505 L
.73627 .49976 L
.73773 .50604 L
.73919 .50505 L
.74066 .50251 L
.74212 .50505 L
.74358 .49034 L
.74504 .46661 L
.74651 .49309 L
.74797 .47034 L
.74943 .49407 L
.7509 .51388 L
.75236 .49819 L
.75382 .4978 L
Mistroke
.75528 .49623 L
.75675 .48211 L
.75821 .47446 L
.75967 .44935 L
.76114 .47093 L
.7626 .5027 L
.76406 .46328 L
.76553 .48093 L
.76699 .48348 L
.76845 .45504 L
.76991 .46955 L
.77138 .4468 L
.77284 .43719 L
.7743 .47818 L
.77577 .42935 L
.77723 .46053 L
.77869 .44837 L
.78016 .34403 L
.78162 .3709 L
.78308 .38129 L
.78454 .34403 L
.78601 .36462 L
.78747 .37698 L
.78893 .34775 L
.7904 .34775 L
.79186 .29931 L
.79332 .33755 L
.79478 .3301 L
.79625 .36599 L
.79771 .32951 L
.79917 .32834 L
.80064 .35933 L
.8021 .33442 L
.80356 .36207 L
.80503 .33912 L
.80649 .35972 L
.80795 .38424 L
.80941 .35835 L
.81088 .37541 L
.81234 .34599 L
.8138 .35835 L
.81527 .35599 L
.81673 .33265 L
.81819 .3201 L
.81965 .36619 L
.82112 .32441 L
.82258 .34795 L
.82404 .31343 L
.82551 .31912 L
.82697 .3097 L
Mistroke
.82843 .39659 L
.8299 .33795 L
.83136 .36482 L
.83282 .32383 L
.83428 .33422 L
.83575 .30225 L
.83721 .31951 L
.83867 .32638 L
.84014 .29499 L
.8416 .31912 L
.84306 .30912 L
.84452 .32716 L
.84599 .3101 L
.84745 .32088 L
.84891 .33128 L
.85038 .32834 L
.85184 .3709 L
.8533 .33932 L
.85477 .34187 L
.85623 .32324 L
.85769 .33246 L
.85915 .33324 L
.86062 .33854 L
.86208 .37757 L
.86354 .31618 L
.86501 .33128 L
.86647 .30676 L
.86793 .32716 L
.8694 .30892 L
.87086 .36933 L
.87232 .31637 L
.87378 .31833 L
.87525 .34226 L
.87671 .32324 L
.87817 .33599 L
.87964 .32128 L
.8811 .32638 L
.88256 .34207 L
.88402 .32226 L
.88549 .33461 L
.88695 .36913 L
.88841 .31618 L
.88988 .32677 L
.89134 .32971 L
.8928 .31382 L
.89427 .32402 L
.89573 .32814 L
.89719 .31363 L
.89865 .31657 L
.90012 .3097 L
Mistroke
.90158 .34265 L
.90304 .38286 L
.90451 .34913 L
.90597 .40561 L
.90743 .35638 L
.90889 .37894 L
.91036 .33952 L
.91182 .40483 L
.91328 .38051 L
.91475 .43464 L
.91621 .42876 L
.91767 .41719 L
.91914 .41758 L
.9206 .40934 L
.92206 .42562 L
.92352 .39777 L
.92499 .386 L
.92645 .35972 L
.92791 .38953 L
.92938 .39443 L
.93084 .36952 L
.9323 .36776 L
.93376 .40012 L
.93523 .38306 L
.93669 .37678 L
.93815 .3758 L
.93962 .37541 L
.94108 .37109 L
.94254 .41267 L
.94401 .40091 L
.94547 .35521 L
.94693 .3658 L
.94839 .35874 L
.94986 .35913 L
.95132 .34128 L
.95278 .33285 L
.95425 .33834 L
.95571 .30421 L
.95717 .33834 L
.95864 .36756 L
.9601 .35952 L
.96156 .35638 L
.96302 .37364 L
.96449 .33481 L
.96595 .37227 L
.96741 .36384 L
.96888 .33599 L
.97034 .3858 L
.9718 .33363 L
.97326 .36423 L
Mistroke
.97473 .32029 L
.97619 .34677 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.71346 .08175 m
.71346 .2788 L
.97619 .2788 L
.97619 .08175 L
F
1 g
.71346 .08175 m
.71346 .2788 L
.97619 .2788 L
.97619 .08175 L
F
0 g
.001 w
[ ] 0 setdash
.71346 .08175 m
.97619 .08175 L
.97619 .2788 L
.71346 .2788 L
.71346 .08175 L
s
% Start of sub-graphic
p
0.713465 0.0817523 0.97619 0.278797 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0297619 0.297619 [
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0535714 0.35119 0.35119 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.00468 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .20238 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Published) show
123.000 12.813 moveto
(Data) show
147.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.39881 0.35119 0.696429 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.00468 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .54762 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Adjusted) show
111.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .42623 L
0 .42623 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{638.375, 272.063},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<M0001E2000`400?l00000o`00003oo`3ooooo
0?ooool0oooo803oool00?l0ooooo`3ooooo0?ooob00oooo003o0?ooool0ooooo`3ooolP0?ooo`00
o`3ooooo0?ooool0oooo803oool00?l0ooooo`3ooooo0?ooob00oooo003o0?ooool0ooooo`3ooolP
0?ooo`00o`3ooooo0?ooool0oooo803oool00?l0ooooo`3ooooo0?ooob00oooo003o0?ooool0oooo
o`3ooolP0?ooo`00Q`3oool00`3DV`0000000000000200000004001b^P3oool0oooo0?oDV`<00000
00<009_D0?ooo`3oool00P3oool01@3oom@0V`00000000000000VmCo00<0oooo00@0^W8000000000
000009_D=03oool00`3DV`0000000000000200000004001b^P3oool0oooo0?oDV`<0000000<009_D
0?ooo`3oool00`3oool00`3Z^W80VmCo0?ooo`040?ooo`040;Yb000000000000002Ke3@0oooo00<0
e9/00000000000000P0000001000L[X0oooo0?ooo`3oe9/300000006002Ke03oool0oooo0?ooo`3o
om@0V`000P0000000`0009/0e?oo0?ooo`020?ooo`040;Yb000000000000002Ke3@0oooo00<0e9/0
0000000000000P0000001000L[X0oooo0?ooo`3oe9/300000005002Ke03oool0oooo0?ooo`3oe9/0
0`0000000`00Vm@0oooo0?ooo`020?ooo`040;Yb000000000000002Ke3<0oooo00<0onZj07800000
00000`0000001@2Ke?l0oooo0?ooo`3oool0^W800080000000<009_D0?ooo`3oool00P3oool0102j
LP00000000000000Vm@40?ooo`040;Yb000000000000002Ke?l0oooo=P3oool008T0oooo00<0omBK
07:jjP3oool01`3oool00`3DV`00VmCo0?ooo`020?ooo`050;Yb002Ke?l0oooo0?ooe02KL[X00P3o
ool01P3oj[X0Vk[Z0?ooo`3oool0e9/009_DocD0oooo00<0omBK07:jjP3oool01`3oool00`3DV`00
VmCo0?ooo`030?ooo`030?oZ^P1bVm@0oooo00<0oooo00H0onZj09^jjP3oool0oooo0=BK002Ke?le
0?ooo`030?oDV`1b^^X0oooo00L0oooo00H0e9/009_Do`3oool0oooo0>ZjLP2Ke?l20?ooo`060?oD
V`1b^^X0oooo0?ooo`3oj[X0Vk[Z0P3oool00`3DV`00VmCo0?ooo`0d0?ooo`030?oDV`1b^^X0oooo
00L0oooo00<0e9/009_Do`3oool01@3oool01P3DV`00VmCo0?ooo`3oool0onZj09^jjP80oooo00<0
e9/009_Do`3oool0<P3oool00`3DV`0007:j0?ooo`050?ooo`060?oZ^P2K^^X0oooo0?ooo`3DV`00
VmCo0P3oool01P3oj[X0Vk[Z0?ooo`3oool0e9/009_Do`80oooo00H0onZj09^jjP3oool0oooo0=BK
002Ke?oo0?ooocD0oooo00290?ooo`030?oDV`1b^^X0oooo00L0oooo00H0oooD09]b^P3oool0oooo
0>ZjLP00L[X30?ooo`050;YbLP2jj_l0oooo0=BK002Ke?l00P3oool00`3oj[X0LY_D0?ooo`0d0?oo
o`030?oDV`1b^^X0oooo00L0oooo00<0oooD09]b^P3oool0103oool00`2jLY/0e?oo0?ooo`020?oo
o`060=BK002Ke?l0oooo0?ooo`3oj[X0LY_D=@3oool00`3oe9/0L[[Z0?ooo`070?ooo`060?ooe02K
L[X0oooo0?ooo`3DVg80^^[o0P3oool01P3oe9/0L[[Z0?ooo`3oool0e9/009_Do`80oooo00<0onZj
07:Ke03oool0=03oool00`3oe9/0L[[Z0?ooo`070?ooo`030?ooe02KL[X0oooo00D0oooo00H0oooD
09]b^P3oool0oooo0=BK002Ke?l20?ooo`030?oZ^P1bVm@0oooo03<0oooo00<0j[Yb0000LP2jj_l0
103oool01P3DV`00VmCo0?ooo`3oool0onZj07:Ke080oooo00H0e9/009_Do`3oool0oooo0?oZ^P1b
Vm@20?ooo`060=BK002Ke?l0oooo0?ooo`3oj[X0LY_Do`3ooole0?ooo`00R@3oool00`3oe9/0L[[Z
0?ooo`040?ooo`0=0>ZjLP0000000000001b^P2jLY/0e?oo0?ooo`3Z^W80000007:jjP3oool0onZj
079b^P020?ooo`060=BKLP2jj_l0oooo0?ooo`3oj[X0LW:j=@3oool00`3oe9/0L[[Z0?ooo`040?oo
o`060>ZjLP0000000000001b^P2jLY/0e?oo103oool00`3Z^W80VmCo0?ooo`020?ooo`060=BKLP2j
j_l0oooo0?ooo`3oj[X0LW:j=@3oool00`3oe9/0L[[Z0?ooo`040?ooo`090>ZjLP0000000000001b
^P2jLY/0e?oo0?ooo`3oe9/0VmCo0080oooo00H0j[ZK0;[Zo`3oool0oooo0=BKLP2jj_l20?ooo`03
0?oZ^P1bL[X0oooo03@0oooo00<0omBK07:jjP3oool0103oool01P3Z^W80000000000000L[X0^W:K
0=Coo`80oooo00T0j[Yb00000000000007:j0;YbV`3Dool0oooo0=BKLP2jj_l00P3oool00`3oj[X0
LW:j0?ooo`0d0?ooo`030?oZ^P1b0000VmCo00<0oooo00H0e9]b0;[Zo`3oool0oooo0?oZ^P1bL[X2
0?ooo`060=BKLP2jj_l0oooo0?ooo`3oj[X0LW:j0P3oool01P3DVg80^^[o0?ooo`3oool0onZj079b
^_l0oooo=@3oool008T0oooo00<0omBK07:jjP3oool00`3oool03P3oe9/007:j0?ooo`3oool0j[Yb
0000V`3Dool0oooo0?oDV`1bVi/0LP00000000000780^^[o0P3oool01P3DVg80^^[o0?ooo`3oool0
onZj079b^SD0oooo00<0omBK07:jjP3oool00`3oool01`3oe9/007:j0?ooo`3oool0j[Yb0000V`3D
ool0103oool00`3oj[X0LY_D0?ooo`020?ooo`060=BKLP2jj_l0oooo0?ooo`3oj[X0LW:j=@3oool0
0`3oe9/0L[[Z0?ooo`030?ooo`0:0?oDV`00L[X0oooo0?ooo`3Z^W80002K0=Coo`3oool0oooD09/0
0080000000H007:j0?ooo`3oool0oooo0=BKLP2jj_l20?ooo`030?oZ^P1bL[X0oooo03@0oooo00<0
omBK07:jjP3oool00`3oool02P3oe9/007:j0?ooo`3oool0j[Yb0000V`3Dool0oooo0?oDV`00L[X2
0?ooo`060>ZjLP0009/0e?oo0?ooo`3DVg80^^[o0P3oool00`3oj[X0LW:j0?ooo`0e0?ooo`030?oo
e02KL[X0oooo0080oooo00H0e9]b0;[Zo`3oool0oooo0?oZ^P1bL[X20?ooo`060=BKLP2jj_l0oooo
0?ooo`3oj[X0LW:j0P3oool01P3DVg80^^[o0?ooo`3oool0onZj079b^_l0oooo=@3oool008T0oooo
00<0omBK07:jjP3oool00`3oool01P3Z^W80VmCo0?ooo`3oool0oooD09]b^P80oooo00<0onZj079b
^P3oool01@3oool01P3DVg80^^[o0?ooo`3oool0onZj07:Ke3D0oooo00<0omBK07:jjP3oool00`3o
ool01P3Z^W80VmCo0?ooo`3oool0oooD09]b^PH0oooo00H0^W:K0=Coo`3oool0oooo0=BKLP2jj_l2
0?ooo`030?oZ^P1bVm@0oooo03@0oooo00<0omBK07:jjP3oool00`3oool01P3Z^W80VmCo0?ooo`3o
ool0oooD09]b^P80oooo00H0j[Yb09_Do`3oool0oooo0>ZjLP1b^^X20?ooo`060=BKLP2jj_l0oooo
0?ooo`3oj[X0LY_D=@3oool00`3oe9/0L[[Z0?ooo`030?ooo`060>ZjLP2Ke?l0oooo0?ooo`3oom@0
Vg:j0P3oool01P3Z^W80VmCo0?ooo`3oool0oooD09]b^P80oooo00H0e9]b0;[Zo`3oool0oooo0?oZ
^P1bVm@g0?ooo`060>ZjLP2Ke?l0oooo0?ooo`3DVg80^^[o0P3oool01P3oj[X0LY_D0?ooo`3oool0
e9]b0;[Zo`80oooo00H0onZj07:Ke03oool0oooo0=BKLP2jj_l20?ooo`030?oZ^P1bVm@0oooo0?l0
oooo=03oool008L0oooo00@0j[Yb002Ke03oe9/0L[[Z103oool01P3oe9/007:j0?ooo`3oool0e9/0
07:jjP<0oooo00<0j[Yb0000V`3Dool0103oool01P3oe9/007:j0?ooo`3oool0e9/009_Doc<0oooo
00@0j[Yb002Ke03oe9/0L[[Z103oool01P3oe9/007:j0?ooo`3oool0e9/007:jjP80oooo00H0^W:K
0=Coo`3oool0oooo0>ZjLP1b^^X20?ooo`060?oDV`00L[X0oooo0?ooo`3DV`00VmCo<`3oool0103Z
^W8009_D0?oDV`1b^^X40?ooo`060?oDV`00L[X0oooo0?ooo`3DV`00L[[Z0P3oool01P3Z^W8009_D
0?ooo`3oool0e9/009_Do`80oooo00H0omBK001b^P3oool0oooo0=BK002Ke?lc0?ooo`040>ZjLP00
Vm@0omBK07:jjP@0oooo00H0omBK001b^P3oool0oooo0=BK001b^^X20?ooo`060?oDV`00L[X0oooo
0?ooo`3DV`00L[[Z0P3oool01P3oe9/007:j0?ooo`3oool0e9/009_Doc<0oooo00H0e9/007:jjP3o
ool0oooD09/0002Ke?l20?ooo`060?oDV`00L[X0oooo0?ooo`3DV`00VmCo0P3oool01P3oe9/007:j
0?ooo`3oool0e9/009_Do`80oooo00H0omBK001b^P3oool0oooo0=BK002Ke?oo0?ooocD0oooo0028
0?ooo`030=BK00000000L[[Z00D0oooo00@0e9/000000000000009_D1@3oool01@3oe9/000000000
000009/0e?oo0080oooo00@0j[Yb00000000000009_D=@3oool00`3DV`00000007:jjP050?ooo`04
0=BK000000000000002Ke0<0oooo00<0^W800000000000000P0000001@1b^^X0oooo0?ooo`3oool0
j[Yb0080000000<009_D0?ooo`3oool0<`3oool00`3DV`00000007:jjP050?ooo`040=BK00000000
0000002Ke0@0oooo00@0e9/000000000000009_D103oool0103Z^W80000000000000Vm@e0?ooo`03
0=BK00000000L[[Z00D0oooo00@0e9/000000000000009_D103oool0103DV`00000000000000Vm@4
0?ooo`040>ZjLP0000000000002Ke3D0oooo00@0^W80000000000000L[[Z103oool0103Z^W800000
00000000Vm@40?ooo`040>ZjLP0000000000002Ke0@0oooo00@0j[Yb00000000000009_Do`3ooolf
0?ooo`00o`3ooooo0?ooool0oooo803oool00?l0ooooo`3ooooo0?ooob00oooo003o0?ooool0oooo
o`3ooolP0?ooo`00o`3ooooo0?ooool0oooo803oool00?l0ooooo`3ooooo0?ooob00oooo003o0?oo
ool0ooooo`3ooolP0?ooo`00o`3ooooo0?ooool0oooo803oool00?l0ooooo`3ooooo0?ooob00oooo
00150?ooo`030000003oool0oooo0?l0ooooo`3ooooG0?ooo`00@`3ooooo00000<h00000o`3oool>
0?ooo`00A@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo4@3oool004D0
oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo04h0
oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0?l0
oooo@@3oool004D0oooo00<000000?ooo`3oool0o`3ooooo0?ooomL0oooo00150?ooo`030000003o
ool0oooo0?l0ooooo`3ooooG0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooool0ooooe`3oool0
0240oooo00<0e9/00000000000000P0000001@00L[X0oooo0?ooo`3oool0^W800080000000<009_D
0?ooo`3oool00P3oool0102jLP00000000000000Vm@40?ooo`040;Yb000000000000002Ke0L0oooo
00<000000?ooo`3oool0603oool00`000?l0oooo0?ooo`3o0?ooool0oooo_03oool002<0oooo00<0
omBK07:jjP3oool00`3oool01P3oj[X0Vk[Z0?ooo`3oool0e9/009_Do`80oooo00H0onZj09^jjP3o
ool0oooo0=BK002Ke?l20?ooo`060?oZ^P2K^^X0oooo0?ooo`3DV`00VmCo1P3oool00`000000oooo
0?ooo`0H0?ooo`80003oo`3ooooo0?oookd0oooo000S0?ooo`030?oDV`1b^^X0oooo00<0oooo00H0
e9/009_Do`3oool0oooo0?oZ^P1bVm@20?ooo`060=BK002Ke?l0oooo0?ooo`3oj[X0LY_D0P3oool0
1P3DV`00VmCo0?ooo`3oool0onZj07:Ke0H0oooo00<000000?ooo`3oool0603oool20000ool0oooo
o`3ooonm0?ooo`008`3oool00`3oe9/0L[[Z0?ooo`030?ooo`060=BKLP2jj_l0oooo0?ooo`3oj[X0
LW:j0P3oool01P3DVg80^^[o0?ooo`3oool0onZj079b^P80oooo00H0e9]b0;[Zo`3oool0oooo0?oZ
^P1bL[X60?ooo`@000005`3oool00`000?l0oooo0000o`3o0?ooool0oooo_03oool002<0oooo00<0
omBK07:jjP3oool00`3oool01P3DVg80^^[o0?ooo`3oool0onZj079b^P80oooo00H0e9]b0;[Zo`3o
ool0oooo0?oZ^P1bL[X20?ooo`060=BKLP2jj_l0oooo0?ooo`3oj[X0LW:j1P3oool00`000000oooo
0?ooo`0D0?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0000o`3o0?ooool0oooo_03oool002<0
oooo00<0omBK07:jjP3oool00`3oool01P3DVg80^^[o0?ooo`3oool0onZj07:Ke080oooo00H0e9]b
0;[Zo`3oool0oooo0?oZ^P1bVm@20?ooo`060=BKLP2jj_l0oooo0?ooo`3oj[X0LY_D1P3oool00`00
0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo0080003o00<0oooo0000o`3oool0o`3ooooo0?oo
ok/0oooo000Q0?ooo`040>ZjLP00Vm@0omBK07:jjP@0oooo00H0omBK001b^P3oool0oooo0=BK002K
e?l20?ooo`060?oDV`00L[X0oooo0?ooo`3DV`00VmCo0P3oool01P3oe9/007:j0?ooo`3oool0e9/0
09_Do`H0oooo00<000000?ooo`3oool0503oool20000o`050?ooo`000?l0003o0?ooo`000?l0o`3o
oooo0?oook`0oooo000R0?ooo`030=BK00000000L[[Z00D0oooo00@0j[Yb00000000000009_D103o
ool0103Z^W80000000000000Vm@40?ooo`040>ZjLP0000000000002Ke0L0oooo00<000000?ooo`3o
ool0503oool50000o`030?ooo`000?l0oooo0?l0ooooo`3ooonk0?ooo`00A@3oool00`000000oooo
0?ooo`0D0?ooo`030000o`3oool0003o0080003o00<0oooo0000o`3oool0o`3ooooo0?oook/0oooo
00150?ooo`030000003oool0oooo00h0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0000
o`020000o`030?ooo`000?l0oooo0?l0ooooo`3ooonk0?ooo`00A@3oool00`000000oooo0?ooo`0>
0?ooo`030000o`3oool0oooo00<0oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o0?l0oooo
o`3ooonl0?ooo`00A@3oool00`000000oooo0?ooo`0>0?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0000o`3o0?ooool0oooo_03oool004D0oooo0`000006
0?ooo`030000o`3oool0oooo00@0oooo0P000?l40?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`000?l0o`3ooooo0?oook`0oooo00150?ooo`030000003oool0oooo00H0oooo00<0003o0?oo
o`3oool0103oool20000o`@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0000o`3o0?oo
ool0oooo_03oool004D0oooo00<000000?ooo`3oool01P3oool010000?l0oooo0000o`000?l30?oo
o`80003o103oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0000ool0ooooo`3ooonk
0?ooo`00A@3oool00`000000oooo0?ooo`060?ooo`040000o`3oool0003o0000o`<0oooo0P000?l0
1@3oool0003o0?ooo`3oool0003o00L0oooo00<0003o0?ooo`3oool0o`3ooooo0?oookT0oooo0015
0?ooo`030000003oool0oooo00H0oooo00@0003o0?ooo`000?l0003o0`3oool40000o`80oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`3o0?ooool0oooo^@3oool004D0oooo00<00000
0?ooo`3oool01P3oool01@000?l0oooo0000o`3oool0003o0080oooo10000?l20?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool0o`3ooooo0?oookT0oooo00150?ooo`030000003oool0
oooo00L0oooo0P000?l0103oool0003o0?ooo`3oool20000o`050?ooo`000?l0oooo0?ooo`000?l0
1`3oool00`000?l0oooo0?ooo`3o0?ooool0oooo^@3oool004D0oooo00<000000?ooo`3oool01`3o
ool20000o`040?ooo`000?l0oooo0?ooo`80003o00<0oooo0000o`3oool00P000?l70?ooo`030000
o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0o`3ooooo0?ooojd0oooo00150?ooo`030000003o
ool0oooo00L0oooo00H0003o0?ooo`3oool0003o0?ooo`000?l40?ooo`<0003o1`3oool00`000?l0
oooo0?ooo`090?ooo`030000o`3oool0oooo0?l0ooooo`3ooon]0?ooo`00A@3oool3000000L0oooo
00H0003o0?ooo`3oool0003o0?ooo`000?l50?ooo`030000o`3oool0oooo00L0oooo00<0003o0?oo
o`3oool0203oool00`000?l0oooo0?ooo`3o0?ooool0oooo[@3oool004D0oooo00<000000?ooo`3o
ool01`3oool01P000?l0oooo0?ooo`000?l0oooo0000o`D0oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0?l0ooooo`3ooon]0?ooo`00A@3oool00`00
0000oooo0?ooo`0:0?ooo`030000o`3oool0003o00D0oooo00<0003o0?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0?l0ooooo`3ooon]0?ooo`00A@3oool00`000000
oooo0?ooo`0:0?ooo`030000o`3oool0003o00D0oooo00<0003o0?ooo`3oool01`3oool00`000?l0
oooo0?ooo`080?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool0o`3ooooo0?oooid0
oooo00150?ooo`030000003oool0oooo00/0oooo0P000?l50?ooo`030000o`3oool0oooo00L0oooo
00<0003o0?ooo`3oool0203oool20000o`h0oooo00<0003o0?ooo`3oool0o`3ooooo0?oooid0oooo
00150?ooo`030000003oool0oooo00/0oooo0P000?l50?ooo`030000o`3oool0oooo00L0oooo00<0
003o0?ooo`3oool0203oool20000o`h0oooo00<0003o0?ooo`3oool0o`3ooooo0?oooid0oooo0015
0?ooo`030000003oool0oooo00/0oooo0P000?l50?ooo`030000o`3oool0oooo00L0oooo00<0003o
0?ooo`3oool0203oool20000o`h0oooo00<0003o0?ooo`3oool0o`3ooooo0?oooid0oooo00150?oo
o`030000003oool0oooo00/0oooo0P000?l?0?ooo`030000o`3oool0oooo00P0oooo0P000?l00`3o
ool0003o0?ooo`0;0?ooo`030000o`3oool0oooo0?l0ooooo`3ooonM0?ooo`00A@3oool00`000000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool0203oool40000o`@0
oooo00<0003o0?ooo`3oool01@3oool20000ool0ooooo`3ooonN0?ooo`00A@3oool3000001`0oooo
00<0003o0?ooo`3oool0203oool40000o`@0oooo00<0003o0?ooo`3oool01@3oool20000ool0oooo
o`3ooonN0?ooo`00A@3oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo00P0oooo00@0
003o0?ooo`3oool0003o0`3oool20000o`@0oooo00<0003o0?ooo`3oool00P000?oo0?ooool0oooo
WP3oool004D0oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`080?ooo`040000o`3o
ool0oooo0000o`<0oooo0P000?l40?ooo`030000o`3oool0oooo0080003oo`3ooooo0?oooih0oooo
00150?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool0203oool010000?l0oooo0?oo
o`000?l20?ooo`<0003o0`3oool20000o`040?ooo`000?l0oooo0000ool0oooo^03ooooB000001<0
oooo00150?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool01`3oool01@000?l0oooo
0?ooo`3oool0003o0080oooo00@0003o0?ooo`000?l0003o0P3oool20000o`040?ooo`000?l0oooo
0000ool0oooo^03oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0140oooo00150?oo
o`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool01`3oool010000?l0oooo0?ooo`3oool2
0000o`030?ooo`000?l0oooo0080003o0P3oool20000o`040?ooo`000?l0oooo0000ool0oooo^03o
ool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0140oooo00150?ooo`030000003oool0
oooo01`0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0
003o0?ooo`80003o0P3oool20000o`060?ooo`000?l0oooo0000o`3oool0003oo`3ooonf0?ooo`03
0000003oool0oooo0<h0oooo00<000000?ooo`3oool04@3oool004D0oooo00<000000?ooo`3oool0
703oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`000?l0
oooo0P000?l20?ooo`80003o00<0oooo0000o`3oool00`000?oo0?oookH0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo0?ooo`0L0?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0000o`3oool20000o`80
oooo0P000?l01`3oool0003o0?ooo`3oool0003o0?ooo`000?l0o`3ooone0?ooo`030000003oool0
oooo0<h0oooo00<000000?ooo`3oool04@3oool004D0oooo0`00000L0?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?ooo`3oool00P3oool20000o`80oooo0P000?l20?ooo`040000o`3oool0003o
0000o`80oooo00@0003o0?ooo`000?l0003oo`3ooond0?ooo`030000003oool0oooo0<h0oooo00<0
00000?ooo`3oool04@3oool004D0oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0oooo00<0oooo0P000?l20?ooo`80003o0P3oool00`000?l0oooo0000o`03
0?ooo`040000o`3oool0003o0000ool0oooo]03oool00`000000oooo0?ooo`3>0?ooo`030000003o
ool0oooo0140oooo00150?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`030?ooo`80003o0P3oool010000?l0oooo0000o`000?l20?ooo`060000o`3o
ool0oooo0?ooo`000?l0oooo0P000?oo0?oook@0oooo00<000000?ooo`3oool0cP3oool00`000000
oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo00H0oooo
00<0003o0?ooo`3oool00`3oool01P000?l0oooo0?ooo`3oool0003o0?ooo`80003o0P3oool00`00
0?l0oooo0?ooo`030?ooo`80003o4P3oool00`000?l0oooo0?ooo`0/0?ooo`030000o`3oool0oooo
0100oooo00<0003o0?ooo`3oool0o`3ooomM0?ooo`030000003oool0oooo0<h0oooo00<000000?oo
o`3oool04@3oool004D0oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo00<0oooo00H0003o0?ooo`3oool0oooo0000o`3oool20000o`80oooo00<0003o
0?ooo`3oool00`3oool20000oa80oooo00<0003o0?ooo`3oool0;03oool00`000?l0oooo0?ooo`0@
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0o`3ooomF0?ooo`030000003oool0
oooo0<h0oooo00<000000?ooo`3oool04@3oool004D0oooo00<000000?ooo`3oool0703oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00@0003o0?ooo`000?l0003o0P3oool0
0`000?l0oooo0?ooo`030?ooo`80003o2`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo02`0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0000o`060?ooo`030000o`3oool0
oooo0?l0ooooEP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0140oooo000Q0?oo
o`030=BK0000000000000080000000D007:j0?ooo`3oool0oooo0;Yb000200000003001b^P3oool0
oooo0080oooo00@0^W8000000000000009_D103oool0102jLP00000000000000Vm@70?ooo`030000
003oool0oooo01`0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`040000
o`3oool0003o0000o`80oooo00<0003o0?ooo`3oool00`3oool20000o`/0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0/0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`00
0?l01P3oool00`000?l0oooo0?ooo`3o0?oooeH0oooo00<000000?ooo`3oool0cP3oool00`000000
oooo0?ooo`0A0?ooo`008`3oool00`3oe9/0L[[Z0?ooo`030?ooo`060;Yb001b^^X0oooo0?ooo`3Z
^W8009_D0P3oool01P3oj[X0Vk[Z0?ooo`3oool0e9/009_Do`80oooo00H0onZj09^jjP3oool0oooo
0=BK002Ke?l60?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`070?ooo`040000o`3oool0003o0000o`80oooo00<0003o0?ooo`3oool00`3oool20000
o`/0oooo0P000?l50?ooo`030000o`3oool0oooo0240oooo00<0003o0?ooo`3oool0203oool00`00
0?l0oooo0?ooo`0>0?ooo`030000o`3oool0003o00H0oooo00<0003o0?ooo`3oool0o`3ooomF0?oo
o`030000003oool0oooo0<h0oooo00<000000?ooo`3oool04@3oool002<0oooo00<0omBK07:jjP3o
ool01`3oool01P3oom@0Vg:j0?ooo`3oool0e9/009_Do`80oooo00H0onZj07:Ke03oool0oooo0=BK
002Ke?l20?ooo`030?oZ^P1bVm@0oooo00D0oooo00<000000?ooo`3oool0703oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`000?l02P3oool00`000?l0oooo
0?ooo`090?ooo`80003o1@3oool00`000?l0oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00L0oooo
00<0003o0?ooo`000?l03`3oool00`000?l0oooo0000o`060?ooo`030000o`3oool0oooo0?l0oooo
EP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0140oooo000S0?ooo`030?oDV`1b
^^X0oooo00L0oooo00H0omBK002Ke03oool0oooo0=BKLP2jj_l20?ooo`060?oZ^P1bL[X0oooo0?oo
o`3DVg80^^[o0P3oool00`3oj[X0LW:j0?ooo`050?ooo`@000006`3oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`000?l02P3oool00`000?l0oooo0?ooo`09
0?ooo`80003o1@3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo0140oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0000o`060?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`000?l00`3oool010000?l0oooo0000o`000?oo0?oooeP0oooo00<000000?ooo`3oool0cP3o
ool00`000000oooo0?ooo`0A0?ooo`008`3oool00`3oe9/0L[[Z0?ooo`030?ooo`060?oZ^P1b0000
00000000000009/0e?oo0P3oool01P3DVg80^^[o0?ooo`3oool0onZj079b^P80oooo00H0e9]b0;[Z
o`3oool0oooo0?oZ^P1bL[X60?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`0F0?ooo`030000o`3oool0oooo00L0oooo00@0003o0?ooo`3oool0003o
103oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0oooo0000o`060?ooo`030000o`3oool0oooo00H0oooo00@0003o0?ooo`000?l0
003o0P3oool010000?l0oooo0000o`000?oo0?oooeP0oooo00<000000?ooo`3oool0cP3oool00`00
0000oooo0?ooo`0A0?ooo`008`3oool00`3oe9/0L[[Z0?ooo`030?ooo`030?oZ^P1bVm@0oooo00D0
oooo00H0e9]b0;[Zo`3oool0oooo0?oZ^P1bVm@20?ooo`060=BKLP2jj_l0oooo0?ooo`3oj[X0LY_D
1P3oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
5P3oool00`000?l0oooo0?ooo`070?ooo`040000o`3oool0oooo0000o`@0oooo00<0003o0?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo00L0oooo00@0003o0?ooo`00
0?l0003o103oool20000o`P0oooo00D0003o0?ooo`000?l0003o0?ooo`050000ool0ooooF03oool0
0`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0140oooo000Q0?ooo`040>ZjLP00Vm@0omBK
07:jjP@0oooo00<0onZj07:Ke03oool01@3oool01P3oe9/007:j0?ooo`3oool0e9/009_Do`80oooo
00H0omBK001b^P3oool0oooo0=BK002Ke?l60?ooo`030000003oool0oooo01d0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`0F0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?oo
o`000?l00P3oool010000?l0oooo0?ooo`3oool20000o`l0oooo00<0003o0?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`070?ooo`040000o`3oool0oooo0000o`@0oooo0P000?l70?ooo`80003o00@0
oooo0000o`000?l0oooo1@000?oo0?oooeP0oooo00<000000?ooo`3oool0cP3oool00`000000oooo
0?ooo`0A0?ooo`008P3oool00`3DV`00000007:jjP040?ooo`060?oZ^P1b000000000000000009/0
e?oo0`3oool0103Z^W80000000000000Vm@40?ooo`040>ZjLP0000000000002Ke0L0oooo00<00000
0?ooo`3oool07@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01H0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0000o`020?ooo`040000o`3oool0oooo0?ooo`80003o3`3o
ool00`000?l0oooo0000o`0A0?ooo`030000o`3oool0oooo00L0oooo00D0003o0?ooo`3oool0oooo
0000o`020?ooo`030000o`3oool0003o0080oooo00<0003o0?ooo`3oool00P3oool30000o`030?oo
o`000?l0oooo00D0003oo`3ooomH0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0
4@3oool004D0oooo00<000000?ooo`3oool07@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0oooo01H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0000o`020?ooo`070000o`3o
ool0oooo0?ooo`000?l0oooo0000o`0>0?ooo`030000o`3oool0003o0140oooo00<0003o0?ooo`3o
ool01`3oool01@000?l0oooo0?ooo`3oool0003o0080oooo00<0003o0?ooo`000?l00P3oool00`00
0?l0oooo0?ooo`020?ooo`<0003o00D0oooo0000o`3oool0003o0?ooo`030000ool0ooooF03oool0
0`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0140oooo00150?ooo`030000003oool0oooo
01d0oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`030000o`3oool0oooo01H0oooo00<0003o
0?ooo`3oool01@3oool20000o`<0oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o00h0oooo
00<0003o0?ooo`000?l04@3oool00`000?l0oooo0?ooo`070?ooo`050000o`3oool0oooo0?ooo`00
0?l00P3oool01`000?l0oooo0000o`3oool0003o0?ooo`000?l00`3oool30000o`080?ooo`000?l0
oooo0000o`3oool0003o0?ooo`000?oo0?oooeP0oooo00<000000?ooo`3oool0cP3oool00`000000
oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo0?ooo`0M0?ooo`050000o`3oool0oooo0?ooo`00
0?l00P3oool00`000?l0oooo0?ooo`0F0?ooo`030000o`3oool0oooo00D0oooo0P000?l30?ooo`07
0000o`3oool0oooo0?ooo`000?l0oooo0000o`0>0?ooo`040000o`3oool0003o0000oa00oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`0:0000o`3oool0oooo0000o`3oool0
003o0?ooo`000?l0oooo0000o`<0oooo0`000?l0203oool0003o0?ooo`000?l0oooo0000o`3oool0
003o1@3oool00`000?l0oooo0?ooo`3o0?oooe00oooo00<000000?ooo`3oool0cP3oool00`000000
oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo0?ooo`0M0?ooo`070000o`3oool0oooo0?ooo`00
0?l0oooo0000o`0I0?ooo`030000o`3oool0oooo00@0oooo0`000?l30?ooo`070000o`3oool0oooo
0?ooo`000?l0oooo0000o`0>0?ooo`80003o00<0oooo0000o`000?l03`3oool00`000?l0oooo0000
o`060?ooo`030000o`3oool0oooo0080oooo01P0003o0?ooo`3oool0003o0?ooo`000?l0oooo0000
o`3oool0003o0?ooo`000?l0oooo0000o`3oool0003o0?ooo`000?l0oooo0000o`3oool0003o0?oo
o`000?l50?ooo`030000o`3oool0oooo0?l0ooooD03oool00`000000oooo0?ooo`3>0?ooo`030000
003oool0oooo0140oooo00150?ooo`<000007@3oool010000?l0oooo0?ooo`3oool30000oaT0oooo
00<0003o0?ooo`3oool0103oool30000o`@0oooo0P000?l0103oool0003o0?ooo`000?l=0?ooo`<0
003o00<0oooo0000o`000?l03P3oool20000o`030?ooo`000?l0oooo00D0oooo00<0003o0?ooo`3o
ool00P3oool010000?l0oooo0?ooo`000?l20?ooo`0>0000o`3oool0oooo0000o`3oool0003o0?oo
o`000?l0oooo0000o`3oool0003o0?ooo`000?l30?ooo`80003o103oool00`000?l0oooo0?ooo`3o
0?oooe00oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A0?ooo`00A@3oool00`00
0000oooo0?ooo`0M0?ooo`050000o`3oool0oooo0000o`3oool00P000?lI0?ooo`030000o`3oool0
oooo00@0oooo0`000?l50?ooo`050000o`3oool0003o0?ooo`000?l03@3oool30000o`80oooo00<0
003o0?ooo`3oool0303oool20000o`030?ooo`000?l0oooo00@0oooo0P000?l40?ooo`040000o`3o
ool0oooo0000o`80oooo00h0003o0?ooo`3oool0003o0?ooo`000?l0oooo0000o`3oool0003o0?oo
o`000?l0oooo0000o`@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`3o0?oooe00
oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo
0?ooo`0M0?ooo`050000o`3oool0oooo0000o`3oool00P000?lI0?ooo`030000o`3oool0oooo00@0
oooo00<0003o0?ooo`000?l01@3oool01@000?l0oooo0000o`3oool0003o00d0oooo00<0003o0?oo
o`000?l00P3oool00`000?l0oooo0?ooo`0<0?ooo`80003o00@0oooo0000o`3oool0003o0`3oool2
0000o`@0oooo00@0003o0?ooo`3oool0003o1@3oool30000o`080?ooo`000?l0oooo0000o`3oool0
003o0?ooo`000?l40?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0o`3ooom@0?oo
o`030000003oool0oooo0<h0oooo00<000000?ooo`3oool04@3oool004D0oooo00<000000?ooo`3o
ool07@3oool20000o`050?ooo`000?l0oooo0?ooo`000?l06@3oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0003o00D0oooo00D0003o0?ooo`000?l0oooo0000o`0<0?ooo`80003o00L0oooo
0000o`3oool0oooo0000o`3oool0003o00`0oooo0P000?l0103oool0003o0000o`000?l30?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`000?l01P3oool30000o`080?ooo`000?l0oooo0000
o`3oool0003o0?ooo`000?l50?ooo`050000o`3oool0003o0?ooo`000?l0o`3ooomB0?ooo`030000
003oool0oooo0<h0oooo00<000000?ooo`3oool04@3oool004D0oooo00<000000?ooo`3oool07@3o
ool20000o`030?ooo`000?l0oooo01`0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0000
o`050?ooo`050000o`3oool0003o0?ooo`000?l0303oool20000o`070?ooo`000?l0oooo0?ooo`00
0?l0oooo0000o`0<0?ooo`80003o00@0oooo0000o`000?l0003o0`3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo00D0oooo0`000?l01@3oool0003o0?ooo`000?l0oooo00<0003o1@3o
ool01@000?l0oooo0000o`3oool0003o0?l0ooooDP3oool00`000000oooo0?ooo`3>0?ooo`030000
003oool0oooo0140oooo00150?ooo`030000003oool0oooo01d0oooo0P000?l00`3oool0003o0?oo
o`0L0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`000?l01@3oool01@000?l0oooo0000
o`3oool0003o00`0oooo0P000?l01`3oool0003o0?ooo`3oool0003o0?ooo`000?l0303oool20000
o`040?ooo`000?l0003o0000o`80oooo0P000?l>0?ooo`<0003o00D0oooo0000o`3oool0003o0?oo
o`020000o`H0oooo00D0003o0?ooo`000?l0oooo0000o`3o0?oooe80oooo00<000000?ooo`3oool0
cP3oool00`000000oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo0?ooo`0M0?ooo`80003o00<0
oooo0000o`3oool0703oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0003o00D0oooo00D0
003o0?ooo`000?l0oooo0000o`0<0?ooo`80003o00L0oooo0000o`3oool0oooo0000o`3oool0003o
00`0oooo0P000?l01P3oool0003o0000o`000?l0oooo0000oa00oooo0`000?l01@3oool0003o0?oo
o`000?l0oooo0080003o1P3oool30000o`030?ooo`000?l0oooo0?l0ooooD@3oool00`000000oooo
0?ooo`3>0?ooo`030000003oool0oooo0140oooo00150?ooo`030000003oool0oooo01d0oooo0P00
0?l00`3oool0003o0?ooo`0L0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`000?l01@3o
ool01@000?l0oooo0000o`3oool0003o00<0oooo00<0003o0?ooo`3oool01P3oool20000o`070?oo
o`000?l0oooo0?ooo`000?l0oooo0000o`050?ooo`030000o`3oool0oooo00<0oooo0`000?l01P3o
ool0003o0?ooo`000?l0oooo0000oa00oooo00P0003o0?ooo`000?l0oooo0000o`3oool0003o0?oo
o`80003o1P3oool30000o`030?ooo`000?l0oooo0?l0ooooD@3oool00`000000oooo0?ooo`3>0?oo
o`030000003oool0oooo0140oooo00150?ooo`030000003oool0oooo01d0oooo0P000?l00`3oool0
003o0?ooo`0L0?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`3oool0003o1@3oool01@00
0?l0oooo0000o`3oool0003o00<0oooo00<0003o0?ooo`3oool01P3oool20000o`040?ooo`000?l0
oooo0?ooo`<0003o1@3oool20000o`@0oooo0`000?l01P3oool0003o0?ooo`000?l0oooo0000oa00
oooo00P0003o0?ooo`000?l0oooo0000o`3oool0003o0?ooo`80003o1`3oool20000o`030?ooo`00
0?l0oooo0?l0ooooD@3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0140oooo0015
0?ooo`<000007@3oool20000o`030?ooo`000?l0oooo01`0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`060?ooo`80003o0P3oool01@000?l0oooo0?ooo`3oool0003o00H0oooo00H0
003o0?ooo`000?l0003o0?ooo`000?l20?ooo`<0003o0P3oool00`000?l0oooo0?ooo`020000o`@0
oooo0P000?l0103oool0003o0000o`3oool30000oa00oooo00T0003o0?ooo`000?l0oooo0000o`3o
ool0003o0?ooo`000?l02@3oool20000o`030?ooo`000?l0oooo0?l0ooooD03oool00`000000oooo
0?ooo`3>0?ooo`030000003oool0oooo0140oooo00150?ooo`030000003oool0oooo01d0oooo0P00
0?l00`3oool0003o0?ooo`0L0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3o
ool20000o`80oooo1P000?l50?ooo`060000o`3oool0003o0000o`3oool0003o0P3oool30000o`80
oooo0`000?l01P3oool0003o0?ooo`3oool0003o0?ooo`80003o00@0oooo0000o`000?l0oooo0`00
0?lC0?ooo`060000o`3oool0oooo0000o`3oool0003o2@3oool20000o`030?ooo`000?l0oooo0?l0
ooooD03oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0140oooo00150?ooo`030000
003oool0oooo01d0oooo00@0003o0?ooo`000?l0003o7@3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00H0oooo0P000?l20?ooo`H0003o0P3oool00`000?l0oooo0?ooo`020000o`04
0?ooo`000?l0oooo0000o`80oooo0`000?l20?ooo`<0003o0P3oool010000?l0oooo0000o`3oool2
0000o`040?ooo`000?l0003o0?ooo`<0003o4`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo00L0oooo0P000?l00`3oool0003o0?ooo`3o0?oooe00oooo00<000000?ooo`3oool0cP3o
ool00`000000oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0
oooo01h0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`80003o0P3oool0
0`000?l0oooo0000o`030000o`80oooo00<0003o0?ooo`3oool00P000?l00`3oool0003o0?ooo`03
0?ooo`P0003o0P3oool01@000?l0oooo0000o`3oool0003o00<0oooo00D0003o0?ooo`000?l0oooo
0000o`0C0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01`3oool20000o`030?oo
o`000?l0oooo0?l0ooooD03oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0140oooo
00150?ooo`030000003oool0oooo01d0oooo00<0003o0?ooo`3oool07P3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo00H0oooo0P000?l50?ooo`<0003o0P3oool50000o`L0oooo1`00
0?l20?ooo`050000o`3oool0003o0?ooo`000?l00`3oool01@000?l0oooo0000o`3oool0003o01P0
oooo00<0003o0?ooo`3oool01`3oool20000o`030?ooo`000?l0oooo0?l0ooooD03oool00`000000
oooo0?ooo`3>0?ooo`030000003oool0oooo0140oooo00150?ooo`030000003oool0oooo01d0oooo
00<0003o0?ooo`3oool07P3oool01P000?l0oooo0?ooo`000?l0oooo0000oa00oooo0P000?l20?oo
o`D0003o203oool60000o`80oooo00<0003o0?ooo`000?l00P000?l30?ooo`030000o`3oool0oooo
01X0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0000o`3o0?oooe40oooo00<000000?oo
o`3oool0cP3oool00`000000oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo0?ooo`0n0?ooo`06
0000o`3oool0oooo0000o`3oool0003o403oool20000o`80oooo1@000?l80?ooo`H0003o0P3oool0
0`000?l0oooo0000o`020000ob/0oooo00<0003o0?ooo`000?l0o`3ooomA0?ooo`030000003oool0
oooo0<h0oooo00<000000?ooo`3oool04@3oool004D0oooo00<000000?ooo`3oool0?P3oool01P00
0?l0oooo0?ooo`000?l0oooo0000oa40oooo00<0003o0?ooo`3oool01@000?l80?ooo`<0003o00<0
oooo0000o`000?l00P3oool40000ob`0oooo00<0003o0?ooo`000?l0o`3ooomA0?ooo`030000003o
ool0oooo0<h0oooo00<000000?ooo`3oool04@3oool004D0oooo00<000000?ooo`3oool0?P3oool0
0`000?l0oooo0?ooo`020000oa80oooo00<0003o0?ooo`3oool00`000?l00`3oool0003o0?ooo`07
0?ooo`040000o`3oool0003o0?ooo`80003o0P3oool30000obd0oooo00<0003o0?ooo`000?l0o`3o
oomA0?ooo`030000003oool0oooo0580oooo00D0^W80000000000000001b0;[Zo`030?ooo`0:0?oZ
^P1b000000000000LP2j^Y/0000007:jjP3DV`00001b09^KLP80000000D0001b0;[Zo`3oool0oooD
09/00004000000040000V`3Dool0oooD09/000@0000000@0002K0=Coo`3oool0^W800`0000001000
09/0e?oo0?ooo`3Z^W820000000809_Do`3oe9/000000000001b^^X0oooo0?ooe02K000300000004
0000V`3Dool0oooo0?oDV`<0000000<009^K09/00000L[X00`3oool00`3oj[X0LP00000000030000
000409_Do`3oool0oooo0>ZjLP80000000@0001b09^KLP000000VmCo0P3oool01@3oe9/000000000
000009/0e?oo0080oooo00L0j[Yb000000000000001b09^KLP000000VmCo0180oooo00<000000?oo
o`3oool04@3oool004D0oooo0`00000o0?ooo`040000o`3oool0003o0000oa80oooo00P0003o0?oo
o`3oool0003o0?ooo`000?l0oooo0000o`P0oooo00D0003o0?ooo`000?l0oooo0000o`030?ooo`<0
003o;@3oool00`000?l0oooo0000o`3o0?oooe40oooo00<000000?ooo`3oool0DP3oool00`3oom@0
V`2K0=Coo`050?ooo`060>ZjLP1b^^X0oooo0?oZ^P1b0000L[[Z0P3oool01`2jLP0007:j0?ooo`3o
ool0onZj0780V`3Dool00`3oool00`3Z^W80L[[Z0?ooo`050?ooo`030>ZjLP1b^^X0oooo00<0oooo
00H0^W9b0;[Zo`3oool0oooo0?oDV`00Vm@20?ooo`060>ZjLP2Ke?l0oooo0?ooo`3oe9/0L[[Z0P3o
ool00`2jLP00VmCo0?ooo`040?ooo`030?ooe02K09/0e?oo0080oooo00<0e9/0001b^P3oool0103o
ool03P3oe9/009_D0?ooo`3oool0oooD09/0V`3Dool0oooD09/0V`3Dool0oooo0?oZ^P1b0000VmCo
0`3oool03@2jLW80^^[o0?ooo`3oe9/0002K0=Coo`3oom@0V`2K0=Coo`3oool0onZj0780002Ke?l0
4`3oool00`000000oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo0?ooo`0o0?ooo`040000o`3o
ool0003o0000oa80oooo00P0003o0?ooo`3oool0003o0?ooo`000?l0oooo0000o`P0oooo00D0003o
0?ooo`000?l0oooo0000o`030?ooo`80003o;P3oool00`000?l0oooo0000o`3o0?oooe40oooo00<0
00000?ooo`3oool0203ooolo0000o`/0oooo00<0oooD09/0V`3Dool01@3oool01P3Z^W80VmCo0?oo
o`3oool0omBK07:jjP80oooo00<0^W9b0;[Zo`3oool00P3oool00`3Z^W80VmCo0?ooo`020?ooo`03
0>ZjLP1b^^X0oooo00D0oooo00<0j[Yb07:jjP3oool01`3oool01P3oe9/007:j0?ooo`3oool0j[Yb
09_Do`80oooo00D0omBK07:jjP3oool0omBK002Ke0060?ooo`030?oDV`1b^^X0oooo0080oooo00<0
onZj079b^P3oool0103oool00`3oe9/009_D0?ooo`020?ooo`050>ZjLP1b^^X0oooD09/0LP2jj_l0
0P3oool00`3Z^W80VmCo0?ooo`020?ooo`030;YbV`3Dool0oooo00<0oooo00<0oooD09/0LP2jj_l0
0P3oool00`3Z^W80VmCo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00150?ooo`030000003o
ool0oooo03l0oooo00<0003o0?ooo`000?l04`3oool020000?l0oooo0?ooo`000?l0oooo0000o`3o
ool0003o203oool01@000?l0oooo0000o`3oool0003o00<0oooo00<0003o0?ooo`3oool0;`3oool0
0`000?l0oooo0?ooo`3o0?ooodl0oooo00<000000?ooo`3oool0DP3oool00`3oom@0V`0000000002
0000000507:jjP3oool0oooo0>ZjLP2Ke?l00P3oool01P3oe9/0L[[Z0?ooo`3oool0^W8009_Do`<0
oooo00<0j[Yb09_Do`3oool00P3oool00`3Z^W80L[[Z0?ooo`050?ooo`030>ZjLP1b^^X0oooo00<0
oooo00H0oooD09/00000000000000000V`3Dool20?ooo`080>ZjLP2Ke?l0oooo0?ooo`3oe9/0L[[Z
0?ooo`3oe9/5000000040000V`3Dool0omBK07:jjP<0oooo00<0onZj079b^P3oool0103oool00`3o
e9/009_D0?ooo`020?ooo`050?oDV`00Vm@0oooo0?oZ^P1b00000`0000001P2Ke?l0oooo0?ooo`3o
ool0^W:K0=Coo`D0oooo00<0onZj0780000000000P0000000`2Ke?l0oooo0?ooo`0A0?ooo`030000
003oool0oooo0140oooo00150?ooo`030000003oool0oooo03l0oooo00<0003o0?ooo`000?l04`3o
ool020000?l0oooo0?ooo`000?l0oooo0000o`3oool0003o203oool01@000?l0oooo0000o`3oool0
003o00<0oooo00<0003o0?ooo`3oool0;`3oool00`000?l0oooo0?ooo`3o0?ooodl0oooo00<00000
0?ooo`3oool0DP3oool00`3oom@0V`2K0=Coo`020?ooo`050;YbLP2jj_l0oooo0>ZjLP2Ke?l00P3o
ool02`3oe9/0L[[Z0?ooo`3oool0^W800000LP2jj_l0oooo0?oZ^P1b09/0e?oo00<0oooo00<0j[Yb
07:jjP3oool01@3oool00`3Z^W80L[[Z0?ooo`030?ooo`060>ZjLP1b^^X0oooo0?ooo`3DV`0007:j
0P3oool02P3Z^W80001b0;[Zo`3oool0j[Yb07:jjP3oool0oooD09/0V`3Dool20?ooo`0:0>ZjLP00
L[X0oooo0?ooe02K0780^^[o0?ooo`3oom@0V`00001b^PD0oooo00<0omBK002Ke03oool00P3oool0
1@3oe9/009_D0?ooo`3oom@0e=Co0080oooo00<0^W8009_Do`3oool00P3oool00`2jLY/0e?oo0?oo
o`040?ooo`060?ooe03De?l0oooo0?ooo`2jLP00VmCo4`3oool00`000000oooo0?ooo`0A0?ooo`00
A@3oool00`000000oooo0?ooo`0o0?ooo`030000o`3oool0003o01<0oooo00P0003o0?ooo`3oool0
003o0?ooo`000?l0oooo0000o`X0oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo0?ooo`0_
0?ooo`030000o`3oool0oooo0?l0ooooC`3oool00`000000oooo0?ooo`1B0?ooo`030?ooe02K09/0
e?oo0080oooo00T0j[Yb09_Do`3Z^W80000009_Do`3oool0e9/00000001b^^X00P3oool01P2jLW80
^]Bj078000000000001b0;[Zo`@0oooo00<0j[Yb07:jjP3oool00`3oool0103Z^W8000000000001b
^^X50?ooo`050;Yb000000000000001bLP1bL[X00P3oool01P3Z^W80VkZj078000000000002K0=Co
o`80oooo00D0omBK0000000000000000001b^P030?ooo`060?oZ^P1b000000000000002Ke=@0Vg:j
1@3oool00`3oe9/009_D0?ooo`020?ooo`040>ZjLP1b^^X0oooo0?oDV`<0000000D0L[[Z0?ooo`3o
ool0onZj078000040000000409_Do`3oool0oooo0?oDV`<0000000<0L[[Z0?ooo`3oool04P3oool0
0`000000oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo0?ooo`0o0?ooo`030000o`3oool0003o
01<0oooo00@0003o0?ooo`3oool0003o0`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0
003o00<0oooo00<0003o0?ooo`3oool0;`3oool00`000?l0oooo0?ooo`3o0?ooodl0oooo00<00000
0?ooo`3oool0DP3oool00`3oom@0V`2K0=Coo`020?ooo`030;YbLP2jj_l0oooo00P0oooo00<0^W9b
0;[Zo`3oool01`3oool00`3Z^W80L[[Z0?ooo`0C0?ooo`030>ZjLP2Ke?l0oooo0140oooo00<0oooD
09]b^P3oool0103oool01`3oe9/009_D0?ooo`3oool0omBK0000V`3Dool02P3oool00`2jLY/0e?oo
0?ooo`0M0?ooo`030000003oool0oooo0140oooo00150?ooo`030000003oool0oooo03l0oooo0P00
0?lD0?ooo`040000o`3oool0oooo0000oa00oooo00<0003o0?ooo`3oool0<`3oool00`000?l0oooo
0?ooo`3o0?ooodl0oooo00<000000?ooo`3oool0DP3oool00`2jLP000000000000020000000307:j
jP3oool0oooo00L0oooo00<0e9/00000LP2jj_l01P3oool0103Z^W8000000000001b^^X60?ooo`03
0=BK001b^^X0oooo00X0oooo00<0j[Yb0000002Ke?l04@3oool00`3oom@0V`00001b^P040?ooo`03
0?oZ^P1b000000000080000000<0002K0=Coo`3oool0:P3oool00`000000oooo0?ooo`0A0?ooo`00
A@3oool00`000000oooo0?ooo`0o0?ooo`80003o503oool20000o`030?ooo`000?l0oooo04H0oooo
00<0003o0?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0
4@3oool004D0oooo00<000000?ooo`3oool0?`3oool20000oa@0oooo0P000?l00`3oool0003o0?oo
o`160?ooo`030000o`3oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`3>0?ooo`030000003o
ool0oooo0140oooo00150?ooo`<00000?`3oool20000oa@0oooo0P000?l00`3oool0003o0?ooo`16
0?ooo`030000o`3oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0
oooo0140oooo00150?ooo`030000003oool0oooo03l0oooo00<0003o0?ooo`3oool0503oool00`00
0?l0oooo0000o`170?ooo`030000o`3oool0oooo0?l0ooooCP3oool00`000000oooo0?ooo`3>0?oo
o`030000003oool0oooo0140oooo00150?ooo`030000003oool0oooo03l0oooo00<0003o0?ooo`3o
ool0503oool00`000?l0oooo0000o`170?ooo`030000o`3oool0oooo0?l0ooooCP3oool00`000000
oooo0?ooo`3>0?ooo`030000003oool0oooo0140oooo00150?ooo`030000003oool0oooo03l0oooo
00<0003o0?ooo`3oool0503oool00`000?l0oooo0000o`170?ooo`030000o`3oool0oooo0?l0oooo
CP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0140oooo00150?ooo`030000003o
ool0oooo05H0oooo00<0003o0?ooo`000?l0A`3oool00`000?l0oooo0?ooo`3o0?ooodh0oooo00<0
00000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo0?ooo`1F
0?ooo`80003oB03oool00`000?l0oooo0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0cP3oool0
0`000000oooo0?ooo`0A0?ooo`00803oool00`3oj[X0LP00000000030000000509_Do`3oool0oooo
0?ooo`2jLP000P0000000`00Vm@0oooo0?ooo`020?ooo`040;Yb000000000000002Ke0@0oooo00@0
^W8000000000000009_D1`3oool00`000000oooo0?ooo`1F0?ooo`80003oB03oool00`000?l0oooo
0?ooo`3o0?ooodh0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A0?ooo`008@3o
ool00`3DV`0007:j0?ooo`050?ooo`060?oZ^P2K^^X0oooo0?ooo`3DV`00VmCo0P3oool01P3oj[X0
Vk[Z0?ooo`3oool0e9/009_Do`80oooo00H0onZj09^jjP3oool0oooo0=BK002Ke?l60?ooo`030000
003oool0oooo05H0oooo0P000?m80?ooo`030000o`3oool0oooo0?l0ooooCP3oool00`000000oooo
0?ooo`3>0?ooo`030000003oool0oooo0140oooo000R0?ooo`030>ZjLP000780^^[o00@0oooo00H0
e9/009_Do`3oool0oooo0?oZ^P1bVm@20?ooo`060=BK002Ke?l0oooo0?ooo`3oj[X0LY_D0P3oool0
1P3DV`00VmCo0?ooo`3oool0onZj07:Ke0H0oooo00<000000?ooo`3oool0EP3oool20000odP0oooo
00<0003o0?ooo`3oool0o`3ooom>0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0
4@3oool002<0oooo00<0onZj0780002Ke?l00`3oool01P3DVg80^^[o0?ooo`3oool0onZj079b^P80
oooo00H0e9]b0;[Zo`3oool0oooo0?oZ^P1bL[X20?ooo`060=BKLP2jj_l0oooo0?ooo`3oj[X0LW:j
1P3oool4000005D0oooo0P000?m80?ooo`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool0
o`3ooolg0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool04@3oool002@0oooo00<0
oooD09]b^P3oool00P3oool01P3DVg80^^[o0?ooo`3oool0onZj079b^P80oooo00H0e9]b0;[Zo`3o
ool0oooo0?oZ^P1bL[X20?ooo`060=BKLP2jj_l0oooo0?ooo`3oj[X0LW:j1P3oool00`000000oooo
0?ooo`1F0?ooo`80003oB03oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo0?l0oooo
=`3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0140oooo000U0?ooo`060>ZjLP2K
e?l0oooo0?ooo`3DVg80^^[o0P3oool01P3oj[X0LY_D0?ooo`3oool0e9]b0;[Zo`80oooo00H0onZj
07:Ke03oool0oooo0=BKLP2jj_l20?ooo`030?oZ^P1bVm@0oooo00D0oooo00<000000?ooo`3oool0
EP3oool20000odP0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`3o0?ooocL0oooo
00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A0?ooo`008@3oool01P3DV`00L[[Z0?oo
o`3oom@0V`0009_Do`80oooo00H0omBK001b^P3oool0oooo0=BK002Ke?l20?ooo`060?oDV`00L[X0
oooo0?ooo`3DV`00VmCo0P3oool01P3oe9/007:j0?ooo`3oool0e9/009_Do`H0oooo00<000000?oo
o`3oool0EP3oool20000odP0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`3o0?oo
ocL0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A0?ooo`008P3oool0102jLP00
00000000001b^^X40?ooo`040>ZjLP0000000000002Ke0@0oooo00@0j[Yb00000000000009_D103o
ool0103Z^W80000000000000Vm@70?ooo`030000003oool0oooo05H0oooo00<0003o0?ooo`3oool0
A`3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo0?l0oooo=`3oool00`000000oooo
0?ooo`3>0?ooo`030000003oool0oooo0140oooo00150?ooo`030000003oool0oooo05H0oooo00<0
003o0?ooo`3oool0A`3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo0?l0oooo=`3o
ool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0140oooo00150?ooo`030000003oool0
oooo05H0oooo00<0003o0?ooo`3oool0B03oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool0o`3ooola0?ooo`030000003oool0oooo0<h0oooo00<00000
0?ooo`3oool04@3oool004D0oooo00<000000?ooo`3oool0EP3oool00`000?l0oooo0?ooo`180?oo
o`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`3o0?oo
oc40oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A0?ooo`00A@3oool00`000000
oooo0?ooo`1F0?ooo`030000o`3oool0oooo04P0oooo00<0003o0?ooo`3oool04`3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo0?l0oooo<@3oool00`000000oooo0?ooo`3>0?ooo`03
0000003oool0oooo0140oooo00150?ooo`<00000EP3oool00`000?l0oooo0?ooo`180?ooo`030000
o`3oool0003o0180oooo0P000?l50?ooo`030000o`3oool0oooo0?l0oooo<@3oool00`000000oooo
0?ooo`3>0?ooo`030000003oool0oooo0140oooo00150?ooo`030000003oool0oooo0:40oooo0`00
0?l<0?ooo`030000o`3oool0oooo00<0oooo0P000?l50?ooo`030000o`3oool0oooo0?l0oooo<@3o
ool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0140oooo00150?ooo`030000003oool0
oooo0:40oooo00<0003o0?ooo`000?l0303oool00`000?l0oooo0?ooo`030?ooo`80003o1@3oool0
0`000?l0oooo0?ooo`3o0?oooc40oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A
0?ooo`00A@3oool00`000000oooo0?ooo`2Q0?ooo`030000o`3oool0003o00`0oooo00<0003o0?oo
o`3oool00`3oool20000o`030?ooo`000?l0oooo0080oooo00<0003o0?ooo`3oool0o`3ooola0?oo
o`030000003oool0oooo0<h0oooo00<000000?ooo`3oool04@3oool004D0oooo00<000000?ooo`3o
ool0X`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool00`3oool20000o`030?ooo`000?l0oooo0080oooo00<0003o0?ooo`3oool0o`3ooola0?ooo`03
0000003oool0oooo0<h0oooo00<000000?ooo`3oool04@3oool004D0oooo00<000000?ooo`3oool0
X`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool010000?l0oooo0000o`000?l30?ooo`030000o`3oool0oooo0?l0oooo<@3oool00`000000
oooo0?ooo`3>0?ooo`030000003oool0oooo0140oooo00150?ooo`030000003oool0oooo0:@0oooo
00@0003o0?ooo`3oool0oooo0P000?l60?ooo`030000o`3oool0oooo00<0oooo00@0003o0?ooo`00
0?l0003o0`3oool00`000?l0oooo0?ooo`3o0?oooc40oooo00<000000?ooo`3oool0cP3oool00`00
0000oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo0?ooo`2T0?ooo`040000o`3oool0oooo0?oo
o`80003o00<0oooo0000o`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0003o
0000o`<0oooo00<0003o0?ooo`3oool0o`3ooola0?ooo`030000003oool0oooo0<h0oooo00<00000
0?ooo`3oool04@3oool004D0oooo00<000000?ooo`3oool0Y03oool010000?l0oooo0?ooo`3oool2
0000o`030?ooo`000?l0oooo00<0oooo00<0003o0?ooo`000?l00`3oool010000?l0oooo0000o`00
0?l30?ooo`80003oo`3ooolb0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool04@3o
ool004D0oooo0`00002T0?ooo`040000o`3oool0oooo0?ooo`80003o00<0oooo0000o`3oool00`3o
ool00`000?l0oooo0000o`030?ooo`040000o`3oool0003o0000o`<0oooo0P000?oo0?oooc80oooo
00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo0?oo
o`2U0?ooo`030000o`3oool0oooo00@0003o103oool30000o`<0oooo00@0003o0?ooo`000?l0003o
0`3oool20000ool0oooo<P3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0140oooo
00150?ooo`030000003oool0oooo0:D0oooo00<0003o0?ooo`3oool010000?l01@3oool0003o0?oo
o`000?l0oooo0080003o0`3oool00`000?l0oooo0000o`020000o`80oooo0P000?oo0?oooc80oooo
00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo0?oo
o`2U0?ooo`050000o`3oool0oooo0000o`3oool00P000?l01@3oool0003o0?ooo`000?l0oooo0080
003o0`3oool00`000?l0oooo0000o`020000o`80oooo0P000?oo0?oooc80oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo0?ooo`2U0?ooo`030000
o`3oool0003o00<0oooo00T0003o0?ooo`000?l0oooo0000o`3oool0003o0?ooo`000?l00P3oool0
0`000?l0oooo0000o`020000o`80oooo0P000?oo0?oooc80oooo00<000000?ooo`3oool0cP3oool0
0`000000oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo0?ooo`2U0?ooo`030000o`3oool0003o
00<0oooo00T0003o0?ooo`000?l0oooo0000o`3oool0003o0?ooo`000?l00P3oool00`000?l0oooo
0000o`020000o`040?ooo`000?l0oooo0000ool0oooo<P3oool00`000000oooo0?ooo`3>0?ooo`03
0000003oool0oooo0140oooo00150?ooo`030000003oool0oooo0:D0oooo00<0003o0?ooo`000?l0
0`3oool00`000?l0oooo0000o`020000o`040?ooo`000?l0oooo0000o`80oooo00@0003o0?ooo`3o
ool0oooo0`000?l00`3oool0003o0?ooo`3o0?oooc40oooo00<000000?ooo`3oool0cP3oool00`00
0000oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo0?ooo`2U0?ooo`030000o`3oool0003o00@0
oooo10000?l00`3oool0003o0?ooo`030000o`D0oooo0P000?l00`3oool0003o0?ooo`3o0?oooc40
oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo
0?ooo`2U0?ooo`030000o`3oool0003o00@0oooo10000?l0103oool0003o0?ooo`3oool20000o`D0
oooo0P000?l00`3oool0003o0?ooo`3o0?oooc40oooo00<000000?ooo`3oool0cP3oool00`000000
oooo0?ooo`0A0?ooo`00A@3oool300000:D0oooo00<0003o0?ooo`000?l0103oool40000o`040?oo
o`000?l0oooo0?ooo`80003o1@3oool010000?l0oooo0?ooo`000?oo0?oooc80oooo00<000000?oo
o`3oool0cP3oool00`000000oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo0?ooo`2U0?ooo`03
0000o`3oool0003o00@0oooo10000?l40?ooo`80003o1@3oool010000?l0oooo0?ooo`000?oo0?oo
oc80oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A0?ooo`00A@3oool00`000000
oooo0?ooo`2U0?ooo`030000o`3oool0003o00@0oooo00@0003o0?ooo`3oool0003o103oool20000
o`D0oooo00D0003o0?ooo`3oool0oooo0000o`3o0?oooc40oooo00<000000?ooo`3oool0cP3oool0
0`000000oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo0?ooo`2U0?ooo`<0003o103oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`000?l0o`3oool_0?oo
o`030000003oool0oooo0<h0oooo00<000000?ooo`3oool04@3oool004D0oooo00<000000?ooo`3o
ool0Y@3oool30000o`d0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0000o`3o0?ooobl0
oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo
0?ooo`2U0?ooo`<0003o3@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0003o0?l0oooo
;`3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0140oooo00150?ooo`030000003o
ool0oooo0:D0oooo00<0003o0?ooo`000?l05`3oool00`000?l0oooo0000o`3o0?ooobl0oooo00<0
00000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo0?ooo`2U
0?ooo`030000o`3oool0oooo01L0oooo00<0003o0?ooo`000?l0o`3oool_0?ooo`030000003oool0
oooo0<h0oooo00<000000?ooo`3oool04@3oool004D0oooo00<000000?ooo`3oool0Y@3oool00`00
0?l0oooo0?ooo`0G0?ooo`030000o`3oool0003o0?l0oooo;`3oool00`000000oooo0?ooo`3>0?oo
o`030000003oool0oooo0140oooo00150?ooo`<00000_`3oool010000?l0oooo0000o`000?nj0?oo
o`030000o`3oool0oooo0700oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A0?oo
o`00A@3oool00`000000oooo0?ooo`2o0?ooo`040000o`3oool0003o0000okX0oooo00<0003o0?oo
o`3oool0L03oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0140oooo00150?ooo`03
0000003oool0oooo0<00oooo00<0003o0?ooo`000?l0Y03oool00`000?l0oooo0?ooo`0C0?ooo`03
0000o`3oool0oooo0700oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A0?ooo`00
A@3oool00`000000oooo0?ooo`300?ooo`030000o`3oool0003o0:@0oooo00<0003o0?ooo`3oool0
4`3oool00`000?l0oooo0?ooo`1`0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0
4@3oool004D0oooo00<000000?ooo`3oool0`P3oool00`000?l0oooo0?ooo`2R0?ooo`030000o`3o
ool0oooo0140oooo00<0003o0?ooo`000?l0=@3oool00`000?l0oooo0?ooo`0j0?ooo`030000003o
ool0oooo0<h0oooo00<000000?ooo`3oool04@3oool004D0oooo00<000000?ooo`3oool0`P3oool0
0`000?l0oooo0?ooo`2R0?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`000?l0=@3oool0
0`000?l0oooo0?ooo`0j0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool04@3oool0
0200oooo00<0onZj0780000000000`0000001@2Ke?l0oooo0?ooo`3oool0^W800080000000<007:j
0?ooo`3oool00P3oool0102jLP00000000000000Vm@40?ooo`040;Yb000000000000002Ke0L0oooo
00<000000?ooo`3oool0`P3oool00`000?l0oooo0?ooo`2R0?ooo`030000o`3oool0oooo0140oooo
00@0003o0?ooo`000?l0003o2`3oool00`000?l0oooo0?ooo`0V0?ooo`030000o`3oool0oooo03X0
oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A0?ooo`008@3oool00`3DV`0007:j
0?ooo`050?ooo`060;Yb001b^^X0oooo0?ooo`3Z^W8009_D0P3oool01P3oj[X0Vk[Z0?ooo`3oool0
e9/009_Do`80oooo00H0onZj09^jjP3oool0oooo0=BK002Ke?l60?ooo`030000003oool0oooo0<80
oooo00<0003o0?ooo`3oool0XP3oool00`000?l0oooo0?ooo`0=0?ooo`060000o`3oool0oooo0?oo
o`000?l0oooo10000?l90?ooo`80003o3@3oool00`000?l0oooo0?ooo`0G0?ooo`030000o`3oool0
oooo03X0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A0?ooo`008P3oool00`3Z
^W80001b0;[Zo`080?ooo`060?ooe02KL[X0oooo0?ooo`3DV`00VmCo0P3oool01P3oj[X0LY_D0?oo
o`3oool0e9/009_Do`80oooo00<0onZj07:Ke03oool01@3oool00`000000oooo0?ooo`330?ooo`03
0000o`3oool0oooo0:40oooo00<0003o0?ooo`3oool03@3oool01P000?l0oooo0?ooo`3oool0003o
0?ooo`@0003o2@3oool20000o`d0oooo00<0003o0?ooo`3oool05`3oool00`000?l0oooo0?ooo`0j
0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool04@3oool002<0oooo00<0onZj0780
002Ke?l01`3oool01P3oe9/009_D0?ooo`3oool0e9]b0;[Zo`80oooo00H0onZj079b^P3oool0oooo
0=BKLP2jj_l20?ooo`030?oZ^P1bL[X0oooo00D0oooo100000320?ooo`030000o`3oool0oooo0:40
oooo00<0003o0?ooo`3oool0303oool20000o`<0oooo1P000?l90?ooo`80003o2P3oool010000?l0
oooo0000o`000?lI0?ooo`030000o`3oool0oooo03X0oooo00<000000?ooo`3oool0cP3oool00`00
0000oooo0?ooo`0A0?ooo`00903oool00`3oom@0Vg:j0?ooo`020?ooo`060?oZ^P1b000000000000
000009/0e?oo0P3oool01P3DVg80^^[o0?ooo`3oool0onZj079b^P80oooo00H0e9]b0;[Zo`3oool0
oooo0?oZ^P1bL[X60?ooo`030000003oool0oooo0<<0oooo00<0003o0?ooo`3oool0X@3oool00`00
0?l0oooo0?ooo`0<0?ooo`80003o0`3oool70000o`H0oooo00<0003o0?ooo`000?l00P000?l70?oo
o`040000o`3oool0003o0?ooo`80003o6@3oool00`000?l0oooo0?ooo`0j0?ooo`030000003oool0
oooo0<h0oooo00<000000?ooo`3oool04@3oool002D0oooo00H0j[Yb09_Do`3oool0oooo0?oZ^P1b
Vm@60?ooo`060=BKLP2jj_l0oooo0?ooo`3oj[X0LY_D0P3oool01P3DVg80^^[o0?ooo`3oool0onZj
07:Ke0H0oooo00<000000?ooo`3oool0a03oool00`000?l0oooo0?ooo`2P0?ooo`030000o`3oool0
oooo00`0oooo0P000?l30?ooo`D0003o00<0oooo0000o`3oool01@3oool00`000?l0oooo0000o`03
0000o`H0oooo00@0003o0?ooo`000?l0oooo0P000?lI0?ooo`030000o`3oool0oooo03X0oooo00<0
00000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A0?ooo`008@3oool01P3DV`00L[[Z0?ooo`3o
om@0V`0009_Do`80oooo00<0onZj07:Ke03oool01@3oool01P3oe9/007:j0?ooo`3oool0e9/009_D
o`80oooo00H0omBK001b^P3oool0oooo0=BK002Ke?l60?ooo`030000003oool0oooo0<@0oooo00<0
003o0?ooo`3oool0X03oool20000o`X0oooo00<0003o0?ooo`3oool00P000?l30?ooo`<0003o00@0
oooo0000o`3oool0003o1P3oool60000o`80oooo00H0003o0?ooo`3oool0oooo0000o`3oool20000
o`030?ooo`000?l0oooo01L0oooo0P000?l70?ooo`030000o`3oool0oooo0380oooo00<000000?oo
o`3oool0cP3oool00`000000oooo0?ooo`0A0?ooo`008P3oool0102jLP0000000000001b^^X30?oo
o`060?oZ^P1b000000000000000009/0e?oo0`3oool0103Z^W80000000000000Vm@40?ooo`040>Zj
LP0000000000002Ke0L0oooo00<000000?ooo`3oool0a03oool00`000?l0oooo0?ooo`2P0?ooo`80
003o2P3oool00`000?l0oooo0?ooo`020000o`<0oooo0`000?l0103oool0003o0?ooo`000?l30?oo
o`030000o`3oool0oooo00L0003o00D0oooo0000o`3oool0003o0?ooo`040000o`030?ooo`000?l0
oooo01L0oooo0P000?l70?ooo`030000o`3oool0oooo0380oooo00<000000?ooo`3oool0cP3oool0
0`000000oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo0?ooo`340?ooo`030000o`3oool0oooo
0:00oooo0P000?l:0?ooo`030000o`3oool0003o0080003o0P3oool20000o`060?ooo`000?l0oooo
0000o`3oool0003o0`3oool00`000?l0oooo0?ooo`070000o`050?ooo`000?l0oooo0000o`3oool0
10000?l00`3oool0003o0?ooo`0G0?ooo`80003o1`3oool00`000?l0oooo0?ooo`0b0?ooo`030000
003oool0oooo0<h0oooo00<000000?ooo`3oool04@3oool004D0oooo00<000000?ooo`3oool0a03o
ool00`000?l0oooo0?ooo`2P0?ooo`80003o2P3oool00`000?l0oooo0000o`020000o`80oooo0P00
0?l01P3oool0003o0?ooo`000?l0oooo0000o`<0oooo00<0003o0?ooo`3oool01`000?l01@3oool0
003o0?ooo`000?l0oooo0080003o00D0oooo0000o`3oool0oooo0000o`0G0?ooo`80003o1`3oool0
0`000?l0oooo0?ooo`0b0?ooo`030000003oool0oooo0640oooo00D0oooD09/0000000000000001b
^P1X0?ooo`030000003oool0oooo0140oooo00150?ooo`030000003oool0oooo0<@0oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`2C0?ooo`D0003o1`3oool00`000?l0oooo0000o`02
0000o`80oooo0P000?l50?ooo`80003o0P3oool20000o`040?ooo`000?l0003o0?ooo`H0003o00<0
oooo0000o`3oool00P000?l40?ooo`030000o`3oool0oooo01D0oooo0P000?l70?ooo`030000o`3o
ool0oooo0380oooo00<000000?ooo`3oool0I@3oool00`3Z^W80L[[Z0?ooo`1V0?ooo`030000003o
ool0oooo0140oooo00150?ooo`030000003oool0oooo0<@0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`2C0?ooo`D0003o1`3oool01@000?l0oooo0000o`3oool0003o0080oooo0P00
0?l50?ooo`80003o0P3oool20000o`040?ooo`000?l0003o0?ooo`80003o00P0oooo0000o`000?l0
003o0?ooo`000?l0oooo0000o`D0oooo00<0003o0?ooo`3oool05@3oool20000o`L0oooo00<0003o
0?ooo`3oool0<P3oool00`000000oooo0?ooo`1@0?ooo`0;0?oZ^P1b000000000000LP2jj_l0oooD
09/000000000001b0;[Zo`3oe9/00`0000000`00Vi/0V`00001b^P040?ooo`030?oDV`1b^^X0oooo
0080oooo00T0onZj078000000000001b0;ZjV`000000L[[Z0?ooo`2jLP000`0000000`0009/0e?oo
0?ooo`020?ooo`050?oDV`00000000000000V`3Dool00P3oool00`3oom@0V`000000000200000004
0000V`3Dool0oooo0?oDV`<0000000<009^K09/00000L[X0?@3oool00`000000oooo0?ooo`0A0?oo
o`00A@3oool300000<@0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`2C0?ooo`H0
003o1P3oool01@000?l0oooo0000o`3oool0003o0080oooo0P000?l60?ooo`070000o`3oool0003o
0?ooo`000?l0oooo0000o`020?ooo`80003o00<0oooo0000o`000?l00`000?l00`3oool0003o0?oo
o`040?ooo`030000o`3oool0oooo01@0oooo0`000?l60?ooo`80003o=03oool00`000000oooo0?oo
o`1A0?ooo`030?ooe02KL[X0oooo00<0oooo00D0^W:K0=Coo`3oom@0V`2K0=Coo`020?ooo`030=BK
0000L[X0oooo00@0oooo00<0omBK07:jjP3oool00P3oool01P3Z^W80L[[Z0?ooo`3oj[X0LP0007:j
jP80oooo00H0^W9b0;[Zo`3oool0oooo0?oDV`00Vm@30?ooo`090;YbLP2jj_l0oooo0?oDV`0009/0
e?oo0?ooo`2jLP00VmCo00D0oooo00<0oooD09/0V`3Dool00P3oool00`3DV`0007:j0?ooo`0m0?oo
o`030000003oool0oooo0140oooo00150?ooo`030000003oool0oooo0<@0oooo00<0003o0?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`2C0?ooo`H0003o1P3oool01@000?l0oooo0000o`3oool0003o
0080oooo00<0003o0?ooo`3oool01@3oool01`000?l0oooo0000o`3oool0003o0?ooo`000?l00P3o
ool20000o`040?ooo`000?l0003o0?ooo`80003o00<0oooo0000o`3oool0103oool00`000?l0oooo
0?ooo`0D0?ooo`<0003o0`3oool00`000?l0oooo0000o`030000oc<0oooo00<000000?ooo`3oool0
203ooolo0?l000/0oooo00<0e9/00000000000000P0000001000Vm@0oooo0?oDV`1b^^X30?ooo`03
0?oZ^P1bL[X0oooo00@0oooo00<0omBK07:jjP3oool00P3oool01P3Z^W80VmCo0?ooo`3oool0omBK
07:jjPH0oooo00<0omBK001b^P3oool00P3oool00`2jLY/0e?oo0?ooo`030?ooo`030?oDV`00Vm@0
oooo00D0oooo00<0omBK07:jjP3oool00P3oool00`3oj[X0LW:j0?ooo`0m0?ooo`030000003oool0
oooo0140oooo00150?ooo`030000003oool0oooo0<@0oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0?ooo`2C0?ooo`H0003o1P3oool01P000?l0oooo0000o`3oool0003o0?ooo`80003o1`3o
ool00`000?l0oooo0000o`020?ooo`80003o0P3oool20000o`040?ooo`000?l0oooo0?ooo`80003o
00<0oooo0000o`3oool0103oool00`000?l0oooo0?ooo`0D0?ooo`<0003o0`3oool00`000?l0oooo
0000o`030000oc<0oooo00<000000?ooo`3oool0DP3oool02@3oe9/009_D0?ooo`3oool0e9/009_D
o`3oool0omBK07:jjP030?ooo`030?oZ^P1bL[X0oooo00@0oooo00<0omBK07:jjP3oool00P3oool0
1P3Z^W80VmCo0?ooo`3oool0omBK07:jjP80oooo00H0oooD09/00000000000000000V`3Dool30?oo
o`030;YbV`3Dool0oooo00<0oooo00<0omBK0000000000000`000000100009/0e?oo0?oDV`1b^^X3
0?ooo`030?oZ^P1bL[X0oooo03d0oooo00<000000?ooo`3oool04@3oool004D0oooo00<000000?oo
o`3oool0a03oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo09<0oooo00<0003o0?oo
o`000?l010000?l50?ooo`060000o`3oool0003o0?ooo`000?l0oooo0P000?l70?ooo`030000o`3o
ool0003o0080oooo0P000?l30?ooo`030000o`3oool0003o0080oooo0P000?l00`3oool0003o0?oo
o`040?ooo`050000o`3oool0oooo0?ooo`000?l04P3oool00`000?l0oooo0000o`030?ooo`030000
o`3oool0003o00<0003o<`3oool00`000000oooo0?ooo`1C0?ooo`040;YbV`3Dool0oooD09]b^P80
oooo00L0oooD09/0LP2jj_l0oooo0?ooe02K000007:j00D0oooo00<0omBK07:jjP3oool00P3oool0
1P3Z^W80VmCo0?ooo`3oool0omBK07:jjP80oooo00H0j[Yb07:jjP3oool0oooo0=BK0000L[X30?oo
o`030;YbV`3Dool0oooo00<0oooo00<0oooD09/0V`3Dool00P3oool02P3Z^W8007:j0?ooo`3oom@0
V`1b0;[Zo`3oool0oooD09/00000L[Xn0?ooo`030000003oool0oooo0140oooo00150?ooo`030000
003oool0oooo0<@0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`2C0?ooo`030000
o`3oool0003o00@0003o1@3oool01P000?l0oooo0000o`3oool0003o0?ooo`80003o1`3oool00`00
0?l0oooo0000o`020?ooo`80003o0`3oool00`000?l0oooo0000o`020?ooo`<0003o1P3oool01@00
0?l0oooo0?ooo`3oool0003o0180oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo0000o`03
0000oc<0oooo00<000000?ooo`3oool0D`3oool0103Z^W80VmCo0?oDV`1b^^X30?ooo`060?oZ^P1b
000000000000002Ke=@0Vg:j0P3oool01@2jLP000000000000000000L[[Z0080oooo00L0j[Yb0000
002Ke?l0oooo0=BK00000000L[[Z00<0oooo00P0^W80000000000000079b079b^P3oool0onZj0780
00@0000000@0VmCo0?ooo`3oool0omBK0`0000001P00L[X0oooo0?ooo`3oool0onZj078000800000
00<0VmCD09]b^P3oool0?@3oool00`000000oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo0?oo
o`340?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0SP3oool00`000?l0oooo0000
o`020?ooo`030000o`3oool0003o00@0003o103oool020000?l0oooo0000o`000?l0oooo0000o`3o
ool0003o203oool00`000?l0oooo0000o`020?ooo`80003o0`3oool00`000?l0oooo0?ooo`030?oo
o`80003o1P3oool01@000?l0oooo0?ooo`3oool0003o0180oooo00<0003o0?ooo`000?l00`3oool0
0`000?l0oooo0000o`030000oc<0oooo00<000000?ooo`3oool0D`3oool0103oj[X0LW:j0=BKLP2j
j_l70?ooo`030?ooe02KL[X0oooo01X0oooo00<0^W:K0=Coo`3oool0403oool00`3oom@0Vg:j0?oo
o`0m0?ooo`030000003oool0oooo0140oooo00150?ooo`030000003oool0oooo0<@0oooo00<0003o
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo08D0oooo00<0003o
0?ooo`000?l00P3oool00`000?l0oooo0000o`040000o`<0oooo0P000?l01`3oool0003o0000o`3o
ool0003o0?ooo`000?l0203oool00`000?l0oooo0000o`020?ooo`80003o0`3oool00`000?l0oooo
0?ooo`030?ooo`80003o1P3oool01@000?l0oooo0?ooo`3oool0003o0180oooo00<0003o0?ooo`00
0?l00`3oool00`000?l0oooo0000o`030000oc<0oooo00<000000?ooo`3oool0D@3oool01@3oom@0
V`0000000000000007:j00L0oooo00<0oooD09/00000L[X0103oool00`3oj[X0LP2K0=Coo`0V0?oo
o`030?ooe02K000007:j03h0oooo00<000000?ooo`3oool04@3oool004D0oooo00<000000?ooo`3o
ool0a@3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool0Q@3oool010000?l0oooo0000o`3oool20000o`060?ooo`000?l0oooo0000o`3oool0003o0`3o
ool20000o`070?ooo`000?l0003o0?ooo`000?l0oooo0000o`080?ooo`030000o`3oool0003o0080
oooo0P000?l30?ooo`030000o`3oool0oooo00<0oooo0P000?l60?ooo`80003o0P3oool00`000?l0
oooo0?ooo`0@0?ooo`030000o`3oool0003o00<0oooo00<0003o0?ooo`000?l00P000?ld0?ooo`03
0000003oool0oooo0<h0oooo00<000000?ooo`3oool04@3oool004D0oooo00<000000?ooo`3oool0
a@3oool00`000?l0oooo0?ooo`080?ooo`030?l000000?l0oooo00L0oooo00<0o`000?ooo`3oool0
Q@3oool01@000?l0oooo0000o`3oool0003o0080oooo00@0003o0?ooo`000?l0oooo0P000?l20?oo
o`80003o00L0oooo0000o`3oool0oooo0000o`3oool0003o00T0oooo0P000?l20?ooo`80003o0`3o
ool00`000?l0oooo0?ooo`030?ooo`80003o1P3oool20000o`80oooo00<0003o0?ooo`3oool03`3o
ool010000?l0oooo0?ooo`000?l30?ooo`D0003o=03oool00`000000oooo0?ooo`3>0?ooo`030000
003oool0oooo0140oooo00150?ooo`<00000a@3oool00`000?l0oooo0?ooo`080?ooo`030?l00000
0?l0o`0000L0oooo00<0o`000?ooo`3oool0Q@3oool01@000?l0oooo0000o`3oool0003o0080oooo
00@0003o0?ooo`000?l0oooo0P000?l20?ooo`80003o00L0oooo0000o`3oool0oooo0000o`3oool0
003o00T0oooo0P000?l20?ooo`80003o0`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo00@0oooo0P000?l20?ooo`030000o`3oool0oooo00l0oooo00@0003o0?ooo`3oool0003o0`3o
ool50000oc@0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A0?ooo`00A@3oool0
0`000000oooo0?ooo`350?ooo`030000o`3oool0oooo00P0oooo00<0o`000000o`3o00001`3oool0
0`3o0000oooo0?ooo`250?ooo`030000o`3oool0003o0080003o0P3oool010000?l0oooo0000o`3o
ool20000o`80oooo0P000?l00`3oool0003o0?ooo`020?ooo`80003o2@3oool010000?l0oooo0?oo
o`3oool20000o`<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`<0003o
00<0oooo0000o`3oool03P3oool00`000?l0oooo0000o`020?ooo`030?l000000?l0003o00H0003o
=03oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0140oooo00150?ooo`030000003o
ool0oooo0<D0oooo0P000?l70?ooo`050000o`3oool0003o0000o`3o00001`3oool00`3o0000oooo
0?ooo`250?ooo`030000o`3oool0003o0080003o0P3oool010000?l0oooo0000o`3oool30000o`05
0?ooo`000?l0oooo0?ooo`000?l00`3oool20000o`T0oooo00@0003o0?ooo`3oool0oooo0P000?l3
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool30000o`030?ooo`000?l0
oooo00h0oooo00<0003o0?ooo`000?l00P3oool00`3o0000003o0000o`060000oc@0oooo00<00000
0?ooo`3oool0cP3oool00`000000oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo0?ooo`360?oo
o`030000o`3oool0oooo00D0oooo00D0003o0?ooo`000?l0003o0?l000070?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool0P03oool00`000?l0oooo0000o`020000o`80oooo00@0003o
0?ooo`000?l0oooo0`000?l01@3oool0003o0?ooo`3oool0003o00<0oooo0P000?l90?ooo`030000
o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`040?l0003oool0oooo0000
o`H0oooo1@000?l60?ooo`030000o`3oool0oooo00H0oooo0`000?l20?ooo`030?l000000?l0003o
00@0003o00<0oooo0000o`3oool0<`3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo
0140oooo00150?ooo`030000003oool0oooo0<H0oooo00<0003o0?ooo`3oool01@3oool01@000?l0
oooo0000o`000?l0o`0000L0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`200?oo
o`030000o`3oool0003o0080003o0P3oool010000?l0oooo0?ooo`3oool40000o`<0oooo00@0003o
0?ooo`3oool0oooo0P000?l90?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo
0000o`030?ooo`040?l0003oool0oooo0000o`H0oooo1@000?l60?ooo`030000o`3oool0oooo00H0
oooo0P000?l30?ooo`030?l000000?l0003o00@0003o00<0oooo0000o`3oool0<`3oool00`000000
oooo0?ooo`3>0?ooo`030000003oool0oooo0140oooo00150?ooo`030000003oool0oooo0<H0oooo
00<0003o0?ooo`3oool01@3oool40000o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
0P3oool010000?l0oooo0?ooo`000?mo0?ooo`80003o00<0oooo0000o`3oool00P3oool00`000?l0
oooo0?ooo`020?ooo`<0003o0`3oool010000?l0oooo0?ooo`3oool20000o`T0oooo00<0003o0?oo
o`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o00<0oooo00@0o`000?ooo`3oool0003o1P3o
ool50000o`H0oooo00<0003o0?ooo`3oool01P3oool20000o`<0oooo00<0o`000000o`000?l01000
0?l00`3oool0003o0?ooo`0c0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool04@3o
ool004D0oooo00<000000?ooo`3oool0aP3oool00`000?l0oooo0?ooo`050?ooo`@0003o00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`80003o00<0oooo0000o`3oool0OP3oool2
0000o`030?ooo`000?l0oooo0080oooo00<0003o0?ooo`3oool00P3oool30000o`<0oooo00@0003o
0?ooo`3oool0oooo0P000?l90?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo
0000o`030?ooo`040?l0003oool0oooo0000o`H0oooo1@000?l60?ooo`030000o`3oool0oooo00H0
oooo0P000?l30?ooo`030?l000000?l0oooo00@0003o=P3oool00`000000oooo0?ooo`3>0?ooo`03
0000003oool0oooo0140oooo00150?ooo`030000003oool0oooo0<H0oooo00<0003o0?ooo`3oool0
1@3oool01@000?l0oooo0000o`000?l0o`0000L0oooo00<0003o0?ooo`3oool00P3oool20000o`03
0?ooo`000?l0o`0000L0oooo00<0003o0?ooo`3oool0M03oool20000o`030?ooo`000?l0oooo00L0
oooo0`000?l70?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool00P3oool01@000?l0
oooo0?ooo`3oool0003o00<0oooo00@0o`000?ooo`3oool0003o1P3oool50000o`H0oooo00@0003o
0?ooo`3oool0003o1@3oool00`000?l0oooo0?ooo`020?ooo`030?l000000?l0oooo0080003o00<0
oooo0000o`3oool0=@3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0140oooo0015
0?ooo`030000003oool0oooo0<H0oooo00<0003o0?ooo`3oool01@3oool01P000?l0oooo0000o`00
0?l0o`000000o`H0oooo00<0003o0?ooo`3oool00P3oool20000o`030?ooo`000?l0003o0080oooo
00<0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`1d0?ooo`80003o00<0oooo0000o`3oool0
1`3oool30000o`L0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`020?ooo`050000
o`3oool0oooo0?ooo`3o00000`3oool00`3o0000oooo0?ooo`020?l000D0oooo1@000?l60?ooo`04
0000o`3oool0003o0000o`<0oooo00<0003o0?ooo`000?l0103oool00`3o0000oooo0?ooo`020000
o`030?ooo`000?l0oooo03D0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A0?oo
o`00A@3oool300000<H0oooo00<0003o0?ooo`3oool01@3oool010000?l0oooo0000o`3oool20000
o`H0oooo00<0003o0?ooo`3oool00P3oool20000o`030?ooo`000?l0003o0080oooo00<0003o0?oo
o`000?l00P3oool00`000?l0oooo0?ooo`1d0?ooo`80003o00<0oooo0000o`3oool0203oool20000
o`L0oooo00<0003o0?ooo`3oool03@3oool01@000?l0oooo0?l0003oool0o`0000<0oooo00<0o`00
0?ooo`3oool00P3o00050?ooo`D0003o1P3oool010000?l0oooo0000o`000?l20?ooo`80003o00<0
oooo0000o`3oool00`3oool00`3o0000oooo0?ooo`020000o`030?ooo`000?l0oooo03D0oooo00<0
00000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo0?ooo`36
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`000?l00`3oool20000o`H0oooo00<0003o
0?ooo`3oool00P3oool20000o`030?ooo`000?l0003o0080oooo00<0003o0?ooo`000?l00P3oool0
0`000?l0o`000?ooo`1d0?ooo`80003o00<0oooo0000o`3oool0203oool20000o`L0oooo00<0003o
0?ooo`3oool03@3oool010000?l0oooo0?l0003oool20?l00080oooo00<0o`000?ooo`3oool00P3o
00050?ooo`D0003o1P3oool010000?l0oooo0000o`000?l20?ooo`80003o00<0oooo0000o`3o0000
0`3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`000?l0=P3oool00`000000oooo0?ooo`3>0?oo
o`030000003oool0oooo0140oooo00150?ooo`030000003oool0oooo0<H0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0000o`030?ooo`80003o1P3oool00`000?l0oooo0?l000020?ooo`<0
003o00L0o`000000o`3oool0oooo0000o`3oool0003o0080oooo00<0003o0?l0003oool0M03oool2
0000o`030?ooo`000?l0oooo00P0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0=
0?ooo`040000o`3oool0o`000?ooo`80o`000P3oool00`3o0000oooo0?ooo`020?l000D0oooo1@00
0?l60?ooo`@0003o00L0oooo0000o`3oool0003o0?ooo`000?l0o`0000<0oooo00L0o`000?ooo`3o
ool0oooo0?l0003oool0003o03H0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A
0?ooo`00A@3oool00`000000oooo0?ooo`360?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`000?l00`3oool20000o`80oooo00T0003o0?ooo`3oool0oooo0000o`3oool0o`000?ooo`000?l0
0P3o00000`000?l0oooo0000o`020?ooo`030000o`3oool0003o0080oooo00<0003o0?l0003oool0
M03oool20000o`/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0
003oool0oooo0080oooo00@0o`000?ooo`3o0000o`000P3oool00`3o0000oooo0?ooo`020?l000D0
oooo00<0003o0?ooo`000?l00P000?l60?ooo`@0003o00<0oooo0000o`3oool00P000?l00`3oool0
o`000?ooo`020?ooo`070?l0003oool0oooo0?ooo`3o0000oooo0000o`0f0?ooo`030000003oool0
oooo0<h0oooo00<000000?ooo`3oool04@3oool004D0oooo00<000000?ooo`3oool0aP3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0003o00<0oooo0P000?l20?ooo`090000o`3oool0oooo
0?ooo`000?l0oooo0?l0003oool0003o0080o`0000<0003o0?ooo`000?l00P3oool01`000?l0oooo
0000o`000?l0oooo0000o`3o0000M@3oool20000o`/0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo0080oooo00@0o`000?ooo`3o0000o`000P3oool0
0`3o0000oooo0?ooo`020?l000D0oooo00@0003o0?ooo`000?l0oooo0P000?l50?ooo`D0003o0P3o
ool20000o`030?ooo`3o0000oooo0080oooo00L0o`000?ooo`3oool0oooo0?l0003oool0003o03H0
oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A0?ooo`00A@3oool00`000000oooo
0?ooo`360?ooo`030000o`3oool0oooo00<0oooo0`000?l30?ooo`80003o0P3oool03`000?l0oooo
0?ooo`3oool0003o0?ooo`000?l0oooo0000o`3oool0o`000000o`3oool0003o0?ooo`050000o`03
0?ooo`000?l0o`0007D0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo00X0oooo00@0o`000?ooo`3oool0oooo0P3o00000`3oool0o`000?l000020?oo
o`030?l0003oool0oooo0080o`000`3oool01P3o0000oooo0000o`3oool0003o0?ooo`80003o1@3o
ool50000o`80oooo0P000?l00`3oool0o`000?ooo`020?ooo`80o`000P3oool00`3o0000oooo0000
o`0f0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool04@3oool004D0oooo00<00000
0?ooo`3oool0aP3oool00`000?l0oooo0?ooo`030?ooo`<0003o0`3oool20000o`80oooo0140003o
0?ooo`3oool0oooo0000o`3oool0003o0?l000000?l0oooo0?l000000?l0oooo0000o`3oool0003o
0?l000050000o`030?l0003oool0oooo07<0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo
0?ooo`0:0?ooo`040?l0003oool0oooo0?ooo`80o`0000@0oooo0?l0003o0000oooo0P3o00020?oo
o`80o`000`3oool01P3o0000oooo0?ooo`3oool0003o0?ooo`80003o1@3oool30000o`040?ooo`00
0?l0oooo0?ooo`80003o00<0oooo0?l0003oool00P3oool20?l00080oooo00<0o`000?ooo`000?l0
=P3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0140oooo00150?ooo`030000003o
ool0oooo0<H0oooo00<0003o0?ooo`3oool00P3oool40000o`<0oooo0P000?l20?ooo`0A0000o`3o
ool0oooo0?ooo`000?l0oooo0000o`3o0000003o0?ooo`3o0000003o0?ooo`000?l0oooo0000o`3o
ool01@000?l00`3o0000oooo0?ooo`1c0?ooo`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`050?ooo`040?l0003oool0oooo0?ooo`80o`0000@0oooo0?l0
003o0000oooo0P3o00020?ooo`80o`000`3oool01P3o0000oooo0?ooo`3oool0003o0?ooo`80003o
1@3oool30000o`040?ooo`000?l0oooo0?ooo`80003o00<0oooo0?l0003oool00P3oool20?l00080
oooo00<0o`000?ooo`3oool0=P3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0140
oooo00150?ooo`030000003oool0oooo0<H0oooo00<0003o0?ooo`3oool00P3oool40000o`<0oooo
00@0003o0?ooo`000?l0oooo0P000?l20?ooo`030000o`3oool0003o0080003o0P3oool0203o0000
oooo0000o`3oool0003o0?ooo`000?l0o`0010000?me0?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00D0oooo00@0
o`000?ooo`3oool0oooo0P3o0000103oool0o`000?l0003oool20?l00080oooo0P3o00020?ooo`80
o`000`3oool010000?l0oooo0000o`000?l50?ooo`<0003o00@0oooo0000o`3oool0oooo0P000?l0
0`3oool0o`000?ooo`020?ooo`80o`000P3oool00`3o0000oooo0?ooo`0f0?ooo`030000003oool0
oooo0<h0oooo00<000000?ooo`3oool04@3oool004D0oooo0`0000360?ooo`030000o`3oool0oooo
0080oooo00@0003o0?ooo`000?l0003o0`3oool010000?l0oooo0000o`3oool30000o`060?ooo`00
0?l0o`000000o`3oool0003o0P3oool0203o0000oooo0000o`3oool0003o0?ooo`000?l0o`001000
0?me0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo00D0oooo00@0o`000?ooo`3oool0oooo0P3o0000103oool0o`00
0?l0003oool20?l00080oooo0`3o00000`3oool0o`000?l000030?ooo`040000o`3oool0003o0000
o`@0oooo00H0003o0?ooo`000?l0003o0?ooo`000?l30?ooo`030000o`3oool0o`0000<0oooo0P3o
00020?ooo`030?l0003oool0oooo03H0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?oo
o`0A0?ooo`00A@3oool00`000000oooo0?ooo`360?ooo`030000o`3oool0oooo0080oooo00@0003o
0?ooo`000?l0003o0`3oool00`000?l0oooo0000o`040000o`060?ooo`000?l0o`000000o`3oool0
003o103oool01@000?l0o`000000o`3oool0003o0080o`000`000?me0?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3o00001P3oool0o`000?l0003oool0o`000?ooo`80o`0000<0
oooo0?l0003o00000`3oool010000?l0oooo0000o`000?l40?ooo`060000o`3oool0oooo0000o`3o
ool0003o0`3oool00`000?l0oooo0?l000030?ooo`80o`000P3oool00`3o0000oooo0?ooo`0f0?oo
o`030000003oool0oooo0<h0oooo00<000000?ooo`3oool04@3oool004D0oooo00<000000?ooo`3o
ool0aP3oool010000?l0oooo0?ooo`3oool20000o`030?ooo`000?l0003o00<0oooo00<0003o0?oo
o`000?l010000?l01P3oool0003o0?l000000?l0oooo0000o`@0oooo00L0003o0?l000000?l0oooo
0000o`3oool0o`0000<0003oM03oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0o`0000h0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`050?l0003oool0oooo0?l0
003oool01`3o00000`3oool0o`000?ooo`020?l000030?ooo`3o0000o`0000<0oooo00@0003o0?oo
o`000?l0003o103oool00`000?l0oooo0?ooo`020?ooo`070000o`3oool0oooo0?ooo`000?l0oooo
0?l000030?ooo`80o`000P3oool00`3o0000oooo0?ooo`0f0?ooo`030000003oool0oooo0<h0oooo
00<000000?ooo`3oool04@3oool004D0oooo00<000000?ooo`3oool0aP3oool010000?l0oooo0?oo
o`3oool20000o`80oooo0140003o0?ooo`3oool0oooo0000o`3oool0003o0?l000000?l0o`000000
o`3oool0003o0?l000000?l0oooo0?l000050?ooo`80003o00@0oooo0000o`3oool0o`000`000?l0
0`3o0000oooo0?ooo`1a0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o00004`3oool0
0`3o0000oooo0?ooo`050?ooo`050?l0003oool0oooo0?l0003oool01`3o00000`3oool0o`000?oo
o`020?l000030?ooo`3o0000o`0000<0oooo00@0003o0?ooo`000?l0003o103oool00`000?l0oooo
0?ooo`020?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0?l000030?ooo`80o`000P3oool0103o
0000oooo0?ooo`3o000e0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool04@3oool0
04D0oooo00<000000?ooo`3oool0aP3oool010000?l0oooo0000o`3oool20000o`80oooo00l0003o
0?ooo`3oool0oooo0000o`3oool0003o0?l000000?l0o`000000o`3oool0003o0?l000000?l01`3o
ool20000o`040?ooo`000?l0oooo0?l000@0003oL`3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0o`000140oooo00<0o`000?ooo`3o00001`3oool02@3o0000oooo0?ooo`3o0000oooo0?l0
003oool0o`000?ooo`030?l000050?ooo`3o0000oooo0?l0003oool00`3o00030?ooo`040000o`3o
ool0003o0000o`@0oooo00<0003o0?ooo`3oool00P3oool01`000?l0oooo0?ooo`3oool0003o0?oo
o`3o00000`3oool20?l00080oooo00@0o`000?ooo`3oool0o`00=@3oool00`000000oooo0?ooo`3>
0?ooo`030000003oool0oooo0140oooo00150?ooo`030000003oool0oooo0<H0oooo00@0003o0?oo
o`000?l0oooo0P000?l20?ooo`030000o`3oool0oooo00<0oooo00H0003o0?ooo`3o0000o`000000
o`3o00030000o`L0oooo0P000?l00`3oool0003o0?ooo`020?l000030?ooo`000?l0003o04L0oooo
00<0o`000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0o`000140oooo
00<0o`000?ooo`3o00001`3oool20?l000030?ooo`3o0000oooo0080oooo00<0o`000?ooo`3o0000
0P3o00001@3oool0o`000?ooo`3o0000oooo00<0o`000`3oool010000?l0oooo0000o`000?l40?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o00000P3oool30?l00080oooo00@0o`000?oo
o`3oool0o`00=@3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0140oooo000Q0?oo
o`050?ooe02K0000000000000000L[X0103oool0102jLP00000000000000Vm@40?ooo`040;Yb0000
00000000002Ke0@0oooo00@0^W8000000000000009_D1`3oool00`000000oooo0?ooo`360?ooo`05
0000o`3oool0003o0?ooo`000?l00`3oool00`000?l0oooo0?ooo`030?ooo`060000o`3oool0o`00
0?l000000?l0o`000`000?l70?ooo`040000o`3oool0oooo0000o`80oooo00@0o`000?ooo`000?l0
003oA`3oool00`3o0000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
00004@3oool00`3o0000oooo0?l000030?ooo`040?l0003oool0oooo0?ooo`80o`0000<0oooo0?l0
003oool00P3oool00`3o0000oooo0?l000020?l000050?ooo`3o0000oooo0?l0003oool00`3o0003
0?ooo`040000o`3oool0003o0000o`@0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?l0
00020?ooo`<0o`000P3oool0103o0000oooo0?ooo`3o000e0?ooo`030000003oool0oooo0<h0oooo
00<000000?ooo`3oool04@3oool00240oooo00H0^W8009_Do`3oool0oooo0=BK0000Vm@20?ooo`06
0?oZ^P2K^^X0oooo0?ooo`3DV`00VmCo0P3oool01P3oj[X0Vk[Z0?ooo`3oool0e9/009_Do`80oooo
00H0onZj09^jjP3oool0oooo0=BK002Ke?l60?ooo`030000003oool0oooo0<H0oooo00D0003o0?oo
o`000?l0oooo0000o`0=0?ooo`030000o`3o0000003o0080003o1`3oool010000?l0oooo0?ooo`00
0?l20?ooo`040?l0003oool0003o0000odL0oooo00@0o`000?ooo`3oool0003o:03oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0o`000140oooo00<0o`000?ooo`3o00000`3oool0103o0000
oooo0?ooo`3oool20?l000030?ooo`3o0000oooo00@0oooo0`3o00001P3oool0o`000?ooo`3o0000
oooo0?l00080oooo00<0o`000?ooo`3oool00P3oool00`3o0000003o0?ooo`030?ooo`030000o`3o
ool0oooo00H0oooo00P0003o0?ooo`3o0000o`000?ooo`3o0000oooo0?l00080oooo00@0o`000?oo
o`3oool0o`00=@3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0140oooo000U0?oo
o`060?ooe02KL[X0oooo0?ooo`3DV`00VmCo0P3oool01P3oj[X0LY_D0?ooo`3oool0e9/009_Do`80
oooo00H0onZj07:Ke03oool0oooo0=BK002Ke?l20?ooo`030?oZ^P1bVm@0oooo00D0oooo00<00000
0?ooo`3oool0aP3oool01@000?l0oooo0000o`3oool0003o00d0oooo00<0003o0?ooo`000?l00P00
0?l70?ooo`040000o`3oool0oooo0?l00080oooo00@0o`000?ooo`000?l0003oA`3oool0103o0000
oooo0?ooo`000?lX0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o00004@3oool0103o
0000oooo0?l0003o00020?ooo`040?l0003oool0oooo0?ooo`80o`0000<0oooo0?l0003oool0103o
ool30?l000060?ooo`3o0000oooo0?l0003oool0o`000P3oool00`3o0000oooo0?ooo`020?ooo`07
0?l0003oool0003o0?ooo`000?l0oooo0000o`080?ooo`030000o`3oool0o`000080o`000P3oool0
103o0000oooo0?ooo`3o00020?ooo`030?l0003oool0oooo03<0oooo00<000000?ooo`3oool0cP3o
ool00`000000oooo0?ooo`0A0?ooo`009@3oool01P3DV`00L[[Z0?ooo`3oool0e9]b0;[Zo`80oooo
00H0onZj079b^P3oool0oooo0=BKLP2jj_l20?ooo`060?oZ^P1bL[X0oooo0?ooo`3DVg80^^[o0P3o
ool00`3oj[X0LW:j0?ooo`050?ooo`@00000a@3oool01@000?l0oooo0000o`3oool0003o00d0oooo
10000?l80?ooo`030000o`3oool0oooo00D0oooo0`000?m50?ooo`050?l000000?l0oooo0?ooo`00
0?l0:03oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0o`000140oooo00@0o`000?ooo`3o
0000o`000P3oool0103o0000oooo0?ooo`3oool20?l000030?ooo`3o0000oooo00@0oooo00D0o`00
0?ooo`3o0000oooo0?l000030?ooo`040?l0003oool0oooo0?l00080oooo0`3o00000`3oool0003o
0?ooo`020000o`T0oooo00<0003o0?ooo`3o00000P3o00020?ooo`050?l0003oool0oooo0?l0003o
ool00P3o000e0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool04@3oool00280oooo
00@0oooD09/00000000007:j0`3oool01P3DVg80^^[o0?ooo`3oool0onZj079b^P80oooo00H0e9]b
0;[Zo`3oool0oooo0?oZ^P1bL[X20?ooo`060=BKLP2jj_l0oooo0?ooo`3oj[X0LW:j1P3oool00`00
0000oooo0?ooo`360?ooo`050000o`3oool0003o0?ooo`000?l03@3oool40000o`P0oooo00<0003o
0?ooo`3oool01@3oool40000od@0oooo00D0o`000000o`3oool0oooo0000o`0X0?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3o00004@3oool01@3o0000oooo0?l0003o0000oooo0080o`00
0`3oool20?l000030?ooo`3o0000oooo00@0oooo00D0o`000?ooo`3o0000oooo0?l000030?ooo`04
0?l0003oool0oooo0?l00080oooo0`3o00000`3oool0003o0?ooo`020000o`/0oooo0`3o00020?oo
o`050?l0003oool0oooo0?l0003oool00P3o000e0?ooo`030000003oool0oooo0<h0oooo00<00000
0?ooo`3oool04@3oool002D0oooo00H0j[Yb07:jjP3oool0oooo0=BKLP2jj_l20?ooo`060?oZ^P1b
Vm@0oooo0?ooo`3DVg80^^[o0P3oool01P3oj[X0LY_D0?ooo`3oool0e9]b0;[Zo`80oooo00<0onZj
07:Ke03oool01@3oool00`000000oooo0?ooo`360?ooo`050000o`3oool0003o0?ooo`000?l03@3o
ool010000?l0oooo0000o`000?l80?ooo`030000o`3oool0oooo00D0oooo10000?l70?ooo`030?l0
003oool0oooo03X0oooo00D0o`000000o`3oool0oooo0000o`0X0?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3o00004@3oool00`3o0000oooo0?l000040?l00080oooo0`3o00000`3oool0
o`000?ooo`040?ooo`050?l0003oool0o`000?ooo`3o00000`3oool01P3o0000oooo0?ooo`3oool0
o`000?ooo`<0o`0000<0oooo0000o`000?l00P000?l40?ooo`030?l0003oool0oooo00@0oooo0`3o
00020?ooo`030?l0003oool0o`0000@0o`00=@3oool00`000000oooo0?ooo`3>0?ooo`030000003o
ool0oooo0140oooo000Q0?ooo`060=BK0000L[X0oooo0?ooo`3Z^W80L[[Z0P3oool01P3oe9/007:j
0?ooo`3oool0e9/009_Do`80oooo00H0omBK001b^P3oool0oooo0=BK002Ke?l20?ooo`060?oDV`00
L[X0oooo0?ooo`3DV`00VmCo1P3oool00`000000oooo0?ooo`360?ooo`050000o`3oool0003o0?oo
o`000?l0403oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo10000?l70?oo
o`030?l0003oool0oooo03X0oooo00L0o`000000o`3oool0oooo0000o`3oool0o`0002H0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?l0000A0?ooo`030?l0003oool0o`000080o`0000T0
oooo0?l0003oool0oooo0?l0003oool0o`000?ooo`3o00001@3oool01@3o0000oooo0?l0003oool0
o`0000L0oooo00H0o`000?ooo`3o0000oooo0?l0003oool40000o`@0oooo00<0o`000?ooo`3oool0
103oool30?l00080oooo00<0o`000?ooo`3o0000103o000e0?ooo`030000003oool0oooo0<h0oooo
00<000000?ooo`3oool04@3oool00280oooo00@0j[Yb00000000000007:j103oool0103Z^W800000
00000000Vm@40?ooo`040>ZjLP0000000000002Ke0@0oooo00@0j[Yb00000000000009_D1`3oool0
0`000000oooo0?ooo`360?ooo`050000o`3oool0003o0?ooo`000?l0403oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo00D0oooo10000?l70?ooo`030?l0003oool0oooo03P0oooo00D0
003o0?ooo`3o0000003o0?ooo`020000o`030?ooo`000?l0oooo00P0oooo00<0o`000?ooo`3oool0
6P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0o`0000T0oooo00<0o`000?ooo`3oool0
1@3oool00`3o0000oooo0?l000020?l000090?ooo`3o0000oooo0?ooo`3o0000oooo0?l0003oool0
o`0000D0oooo00D0o`000?ooo`3o0000oooo0?l000070?ooo`060?l0003oool0o`000?ooo`3o0000
oooo0P000?l00`3oool0003o0?ooo`030?ooo`030?l0003oool0oooo00@0oooo0`3o00020?ooo`03
0?l0003oool0o`0000@0o`00=@3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo0140
oooo00150?ooo`030000003oool0oooo0<H0oooo00D0003o0?ooo`000?l0oooo0000o`0@0?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool20000o`030?l000000?l0oooo00H0
oooo00<0o`000?ooo`3oool0=`3oool20000o`040?ooo`000?l0003o0?ooo`80003o00<0oooo0000
o`000?l0203oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3o0000oooo00<0oooo00<0o`000?oo
o`3o00001@3oool01@3o0000oooo0?ooo`3oool0o`0000L0oooo103o00020?ooo`080?l0003oool0
oooo0?l0003oool0o`000?ooo`3o00070?ooo`030?l0003oool0o`0000L0oooo00L0o`000?ooo`3o
0000oooo0?l0003oool0003o0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`03
0?ooo`040?l0003oool0o`000?l00080oooo00<0o`000?ooo`3o0000103o000e0?ooo`030000003o
ool0oooo0<h0oooo00<000000?ooo`3oool04@3oool004D0oooo00<000000?ooo`3oool0aP3oool0
10000?l0oooo0000o`000?lA0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool20000o`030?l000000?l0oooo00H0oooo00<0o`000?ooo`3oool0=`3oool20000o`060?ooo`00
0?l0003o0?ooo`000?l0o`000`000?l80?ooo`030?l0003oool0oooo01X0oooo00<0003o0?l0003o
ool00`3oool00`3o0000oooo0?l000050?ooo`050?l0003oool0oooo0?ooo`3o00001`3oool40?l0
0080oooo00P0o`000?ooo`3oool0o`000?ooo`3o0000oooo0?l000L0oooo00<0o`000?ooo`3o0000
1`3oool01`3o0000oooo0?l0003oool0o`000?ooo`000?l00P3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo00<0oooo00@0o`000?ooo`3o0000o`000P3oool00`3o0000oooo0?l00004
0?l003D0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0A0?ooo`00A@3oool00`00
0000oooo0?ooo`360?ooo`040000o`3oool0003o0000oa40oooo00<0003o0?ooo`3oool03P3oool2
0000o`030?l000000?l0oooo00H0oooo00<0o`000?ooo`3oool0=`3oool20000o`060?l000000?l0
003o0?ooo`000?l0o`000`000?l80?ooo`030?l0003oool0oooo01X0oooo00<0003o0?l0003oool0
0`3oool00`3o0000oooo0?l000050?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool0103o0000
oooo0?ooo`3oool40?l00080oooo00P0o`000?ooo`3oool0o`000?ooo`3o0000oooo0?l000L0oooo
00<0o`000?ooo`3o00001`3oool01`3o0000oooo0?l0003oool0o`000?ooo`000?l01`3oool00`3o
0000oooo0?ooo`030?ooo`040?l0003oool0o`000?l00080oooo00<0o`000?ooo`3o0000103o000e
0?ooom8000004`3oool004D0oooo00<000000?ooo`3oool0aP3oool010000?l0oooo0000o`000?lA
0?ooo`030000o`3oool0oooo00h0oooo0P000?l00`3oool0003o0?ooo`060?ooo`030?l0003oool0
oooo03L0oooo00<0003o0?l000000?l00P000?l00`3oool0003o0?l000030000o`030?ooo`000?l0
oooo00D0oooo00<0o`000?ooo`3oool06@3oool20000o`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3o00001@3oool00`3o0000oooo0?ooo`020?l000<0oooo00@0o`000?ooo`3oool0oooo103o
00020?ooo`080?l0003oool0oooo0?l0003oool0o`000?ooo`3o00080?ooo`80o`001`3oool01`3o
0000oooo0?l0003oool0o`000?ooo`000?l01`3oool00`3o0000oooo0?ooo`030?ooo`040?l0003o
ool0o`000?l000<0oooo0`3o00000`3oool0o`000?l0003o0?oooa/0oooo00150?ooo`<00000a`3o
ool30000oa40oooo00<0003o0?ooo`3oool03`3oool01@000?l0oooo0000o`3oool0003o00D0oooo
00<0003o0?ooo`3oool0=`3oool00`000?l0o`000000o`020000o`030?ooo`000?l0o`0000<0003o
00<0oooo0000o`3oool01@3oool00`3o0000oooo0?ooo`0G0?ooo`050?l0003oool0003o0000o`3o
0000103oool00`3o0000oooo0?l000050?ooo`030?l0003oool0oooo0080o`000`3oool0103o0000
oooo0?ooo`3oool30?l000<0oooo00D0o`000?ooo`3oool0o`000?ooo`030?l000P0oooo0P3o0007
0?ooo`070?l0003oool0o`000?ooo`3o0000oooo0000o`070?ooo`030?l0003oool0oooo00<0oooo
00@0o`000?ooo`3o0000o`000`3oool30?l000030?ooo`3o0000o`000?l0oooo6`3oool004D0oooo
00<000000?ooo`3oool0a`3oool30000oa40oooo00<0003o0?ooo`3oool03`3oool01@000?l0oooo
0000o`3oool0003o00D0oooo00<0003o0?ooo`3oool0=`3oool020000?l0o`000000o`3oool0003o
0?ooo`000?l0o`000`000?l00`3oool0003o0?ooo`050?ooo`80o`00603oool01@3o0000oooo0000
o`000?l0o`0000@0oooo0`3o00050?ooo`030?l0003oool0oooo00<0o`0000<0oooo0?l0003o0000
0`3oool30?l000@0oooo00@0o`000?ooo`3o0000oooo0`3o00080?ooo`030?l0003oool0oooo00H0
oooo00L0o`000?ooo`3o0000oooo0?l0003oool0003o00L0oooo00<0o`000?ooo`3oool00`3oool0
103o0000oooo0?l0003o00030?ooo`<0o`0000<0oooo0?l0003o0000o`3ooolK0?ooo`00A@3oool0
0`000000oooo0?ooo`370?ooo`<0003o4@3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0
o`000080003o0`3oool00`3o0000oooo0000o`0i0?ooo`0=0000o`3o0000o`000?ooo`000?l0o`00
0000o`3oool0003o0?l000000?l0oooo0000o`060?ooo`030000o`3o0000oooo01L0oooo00D0o`00
0?ooo`000?l0003o0?l000040?ooo`<0o`001@3oool00`3o0000oooo0?ooo`030?l000030?ooo`3o
0000o`0000<0oooo0`3o00040?ooo`040?l0003oool0o`000?ooo`<0o`00203oool00`3o0000oooo
0?ooo`060?ooo`070?l0003oool0o`000?ooo`3o0000oooo0000o`070?ooo`030?l0003oool0oooo
00<0oooo00@0o`000?ooo`3o0000o`000`3oool30?l000030?ooo`3o0000o`000?l0oooo6`3oool0
04D0oooo00<000000?ooo`3oool0a`3oool30000oa40oooo00<0003o0?ooo`3oool03`3oool00`00
0?l0oooo0?l000020000o`<0oooo00<0o`000?ooo`000?l00P3oool00`3o0000oooo0?ooo`0c0?oo
o`050000o`3o0000o`000?l0003oool00P000?l20?ooo`050000o`3oool0003o0?ooo`000?l01P3o
ool00`000?l0o`000?ooo`0G0?ooo`050000o`3oool0003o0000o`3o0000103oool30?l000030?oo
o`3o0000oooo0080oooo00<0o`000?ooo`3oool00`3o00000`3oool0o`000?l000030?ooo`<0o`00
103oool30?l000040?ooo`3o0000o`000?l000P0oooo00<0o`000?ooo`3oool01`3oool20?l00003
0?ooo`3o0000oooo00L0oooo0P3o00050?ooo`040?l0003oool0o`000?l000<0oooo0P3o00020?oo
o`80o`00o`3ooolK0?ooo`00A@3oool00`000000oooo0?ooo`370?ooo`<0003o4@3oool00`000?l0
oooo0?ooo`0?0?ooo`030000o`3oool0o`000080003o0`3oool01P3o0000oooo0000o`3o0000oooo
0?l003D0oooo00D0003o0?l0003o0000o`000?ooo`020000o`80oooo00D0003o0?ooo`000?l0oooo
0000o`060?ooo`030000o`3o0000oooo01L0oooo00D0003o0?ooo`000?l0003o0?l000040?ooo`<0
o`0000<0oooo0?l0003o00000P3oool00`3o0000oooo0?ooo`030?l000030?ooo`3o0000o`000080
oooo103o00040?ooo`<0o`000P3oool20?l000P0oooo00<0o`000?ooo`3oool01`3oool20?l00003
0?ooo`3o0000oooo00L0oooo0P3o00020?ooo`050?l0003oool0oooo0?l0003oool00P3o00030?oo
o`80o`000P3oool20?l00?l0oooo6`3oool004D0oooo00<000000?ooo`3oool0a`3oool30000ob<0
oooo00<0003o0?ooo`3o00000P000?l30?ooo`060000o`3oool0003o0?l0003oool0o`00=@3oool0
1@000?l0o`000?ooo`3o0000oooo0080003o0P3oool01P000?l0oooo0000o`3oool0003o0?l000D0
oooo00<0003o0?l0003oool04@3oool00`3o0000oooo0?ooo`030?ooo`050000o`3oool0003o0000
o`3o0000103oool30?l000030?ooo`3o0000o`000080oooo00<0o`000?ooo`3oool00`3o00000`3o
ool0o`000?l000020?ooo`@0o`00103oool30?l00080oooo0P3o000B0?ooo`80o`0000<0oooo0?l0
003oool01`3oool20?l00080oooo00D0o`000?ooo`3oool0o`000?ooo`020?l000<0oooo0P3o0002
0?ooo`80o`00o`3ooolK0?ooo`00A@3oool00`000000oooo0?ooo`370?ooo`<0003o8`3oool00`00
0?l0oooo0?l000020000o`<0oooo00H0003o0?ooo`000?l0o`000?ooo`3o000H0?ooo`030000o`3o
ool0oooo01D0oooo0P000?l30?ooo`070000o`3o0000oooo0?l0003oool0003o0?l000020?ooo`04
0000o`3oool0003o0?ooo`80003o1@3oool00`000?l0o`000?ooo`0A0?ooo`030?l0003oool0oooo
00<0oooo00D0003o0?l000000?l0003o0?l000040?ooo`H0o`000P3oool20?l000040?ooo`3o0000
o`000?ooo`<0o`000P3oool40?l000@0oooo0`3o00020?ooo`80o`004P3oool20?l000030?ooo`3o
0000oooo00L0oooo00D0o`000?ooo`3o0000oooo0?l000020?ooo`040?l0003oool0o`000?l000<0
oooo0P3o00020?ooo`80o`00o`3ooolK0?ooo`00A@3oool00`000000oooo0?ooo`370?ooo`<0003o
8`3oool00`000?l0oooo0?ooo`020000o`<0oooo00H0003o0?ooo`000?l0o`000?ooo`3o000H0?oo
o`030000o`3oool0oooo01D0oooo0P000?l20?ooo`80003o0P3oool00`3o0000oooo0000o`030?oo
o`040000o`3oool0003o0?l00080003o1@3oool00`000?l0o`000?ooo`0A0?ooo`030?l0003oool0
oooo00<0oooo00D0003o0?l000000?l0003o0?l000040?ooo`H0o`000P3oool20?l000040?ooo`3o
0000o`000?ooo`<0o`000P3oool20?l000030?ooo`3o0000oooo00<0oooo0`3o00020?ooo`80o`00
4P3oool20?l000030?ooo`3o0000oooo00L0oooo00D0o`000?ooo`3o0000oooo0?l000020?ooo`04
0?l0003oool0o`000?l000<0oooo0P3o00020?ooo`80o`00o`3ooolK0?ooo`00A@3oool00`000000
oooo0?ooo`370?ooo`<0003o8`3oool00`000?l0oooo0?ooo`020000o`<0oooo00H0003o0?l00000
0?l0o`000?ooo`000?lH0?ooo`030000o`3oool0oooo01D0oooo0`000?l00`3oool0003o0?l00002
0?ooo`030?l0003oool0o`0000<0oooo00<0003o0?ooo`3oool00`000?l20?ooo`050000o`3oool0
oooo0000o`3o00004P3oool00`000?l0oooo0?ooo`020?ooo`030?l000000?l0o`000080003o00<0
o`000?ooo`3oool00P3oool20?l000040?ooo`3o0000o`000?l00080oooo0P3o0000103oool0o`00
0?l0003oool30?l00080oooo0P3o00000`3oool0o`000?ooo`030?ooo`<0o`000P3oool20?l00180
oooo0P3o00000`3oool0o`000?ooo`070?ooo`040?l0003oool0o`000?ooo`80o`0000<0oooo0?l0
003oool00P3o00030?ooo`80o`000P3oool20?l00?l0oooo6`3oool004D0oooo0`0000370?ooo`<0
003o8`3oool00`000?l0oooo0?ooo`020000o`<0oooo0`000?l20?l000030000o`3oool0oooo01H0
oooo00<0003o0?ooo`3oool05@3oool30000o`030?ooo`000?l0o`000080oooo00<0o`000?ooo`3o
00000`3oool00`000?l0oooo0?ooo`030000o`070?l0003oool0003o0?ooo`000?l0oooo0000o`0B
0?ooo`030000o`3oool0oooo0080oooo00<0o`000000o`3o00000P000?l00`3o0000oooo0?ooo`02
0?ooo`80o`000P3oool20?l00080oooo0P3o0000103oool0o`000?ooo`3oool30?l00080oooo0P3o
00060?ooo`<0o`000P3oool20?l00180oooo0P3o0000103oool0o`000?ooo`3o00060?ooo`030?l0
003oool0o`0000<0o`0000<0oooo0?l0003oool00P3o00030?ooo`80o`000P3oool20?l00?l0oooo
6`3oool004D0oooo00<000000?ooo`3oool0a`3oool20000ob@0oooo00<0003o0?ooo`3oool00P00
0?l30?ooo`<0003o0P3o00000`000?l0oooo0?ooo`0F0?ooo`030000o`3o0000oooo01D0oooo1@00
0?l01P3o0000oooo0?ooo`3o0000oooo0?l000<0oooo00<0o`000?ooo`3oool00`000?l00`3o0000
oooo0000o`020000o`030?ooo`000?l0oooo0140oooo00<0003o0?ooo`3oool00P3oool00`3o0000
003o0?l000020000o`030?l0003oool0o`000080oooo0P3o00020?ooo`80o`000P3oool20?l00004
0?ooo`3o0000oooo0?ooo`<0o`000P3oool20?l000H0oooo0`3o00020?ooo`80o`004P3oool20?l0
00040?ooo`3o0000oooo0?l000H0oooo00<0o`000?ooo`3o00000`3o00000`3oool0o`000?ooo`02
0?l000@0oooo00<0o`000?ooo`3oool00P3o003o0?oooa/0oooo00150?ooo`030000003oool0oooo
0<P0oooo00<0003o0?ooo`3oool08P3oool00`000?l0oooo0?ooo`020000o`<0oooo0P000?l0103o
ool0003o0?l000000?lH0?ooo`80003o5P3oool50000o`030?l0003oool0oooo00H0oooo00<0o`00
0?ooo`3oool010000?l01P3oool0003o0000o`000?l0oooo0000oa80oooo00H0003o0?ooo`3oool0
oooo0000o`3o00030000o`040?ooo`3o0000oooo0?l00080oooo0P3o00020?ooo`<0o`0000D0oooo
0?l0003o0000oooo0?l000020?ooo`<0o`000P3oool20?l000H0oooo0`3o00020?ooo`80o`004P3o
ool20?l000040?ooo`3o0000oooo0?l000H0oooo00<0o`000?ooo`3o00000`3o00000`3oool0o`00
0?ooo`020?l000@0oooo00@0o`000?ooo`3oool0o`00o`3ooolL0?ooo`00A@3oool00`000000oooo
0?ooo`380?ooo`030000o`3oool0oooo0280oooo00D0003o0?ooo`3oool0o`000000o`030?ooo`80
003o00H0oooo0000o`3o0000003o0?ooo`3o000F0?ooo`80003o5P3oool20000o`040?ooo`000?l0
003o0?l000P0oooo00<0o`000?ooo`3oool00P000?l0103oool0003o0000o`3o00020000o`030?oo
o`000?l0oooo00/0oooo00<0o`000?ooo`3oool00`3oool01P000?l0oooo0?l0003oool0003o0?l0
00<0003o0P3o0000103oool0o`000?ooo`3oool20?l00080oooo0`3o0000103oool0o`000?l0003o
00030?ooo`<0o`000P3oool20?l000H0oooo0P3o00030?ooo`80o`004P3oool20?l000040?ooo`3o
0000oooo0?l000H0oooo00<0o`000?ooo`3o00000`3o00001@3oool0o`000?ooo`3oool0o`0000@0
oooo00@0o`000?ooo`3oool0o`00o`3ooolL0?ooo`00A@3oool00`000000oooo0?ooo`380?ooo`03
0000o`3oool0oooo0280oooo00<0003o0?ooo`3oool00P3o00000`000?l0oooo0?ooo`020000o`06
0?ooo`000?l0o`000000o`3oool0o`005P3oool20000oaH0oooo00H0003o0?l0003oool0o`000000
o`3o000;0?ooo`030000o`3oool0oooo0080003o00D0o`000000o`000?l0oooo0000o`0<0?ooo`03
0?l0003oool0oooo00<0oooo00@0003o0?ooo`3o0000oooo0P000?l01@3oool0003o0000o`3o0000
oooo0080o`000P3oool20?l00080oooo00@0o`000?ooo`3o0000oooo0`3o00030?ooo`030?l0003o
ool0o`000080oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0F0?ooo`80o`0000@0
oooo0?l0003oool0o`001P3oool00`3o0000oooo0?l000030?l000050?ooo`3o0000oooo0?ooo`3o
0000103oool0103o0000oooo0?ooo`3o003o0?oooa`0oooo00150?ooo`030000003oool0oooo0<P0
oooo00<0003o0?ooo`3oool08P3oool00`000?l0oooo0?ooo`020?l000040000o`3oool0oooo0000
o`80oooo00@0003o0?l000000?l0oooo0P3o000B0?ooo`030?l0003oool0oooo0080003o5P3oool0
1@000?l0o`000?ooo`3oool0o`0000`0oooo00<0003o0?ooo`3oool00P000?l01@3o0000oooo0000
o`3oool0003o00`0oooo00<0o`000?ooo`3oool00`3oool20000o`060?l0003oool0003o0000o`3o
ool0003o0P3o00000`3oool0o`000?l000020?ooo`80o`000P3oool0103o0000oooo0?l0003oool3
0?l000<0oooo00@0o`000?ooo`3o0000oooo0P3o000P0?ooo`80o`0000H0oooo0?l0003o0000o`00
0?ooo`3o00040?ooo`030?l0003oool0o`0000<0o`0000D0oooo0?l0003oool0oooo0?l000040?oo
o`040?l0003oool0oooo0?l00?l0oooo703oool004D0oooo00<000000?ooo`3oool0b03oool00`00
0?l0oooo0?ooo`0R0?ooo`030000o`3oool0oooo0080o`0000@0003o0?ooo`3oool0003o0P3oool3
0000o`<0o`004P3oool01@3o0000oooo0000o`3oool0003o01H0oooo00D0003o0?ooo`3oool0oooo
0?l0000<0?ooo`030000o`3oool0oooo0080003o00H0o`000?ooo`000?l0oooo0000o`3o000;0?oo
o`030?l0003oool0oooo00<0oooo0`000?l01@3oool0003o0000o`3oool0003o0080o`0000D0oooo
0?l0003o0000o`000?ooo`020?l00080oooo00<0o`000?ooo`3o0000103o00030?ooo`050?l0003o
ool0o`000?ooo`3o00008@3oool20?l000060?ooo`3o0000o`000?l0003oool0o`00103oool00`3o
0000oooo0?l000030?l000050?ooo`3o0000oooo0?ooo`3o0000103oool0103o0000oooo0?ooo`3o
003o0?oooa`0oooo00150?ooo`030000003oool0oooo0<P0oooo00<0003o0?ooo`3oool08P3oool0
1P000?l0oooo0?ooo`3o0000oooo0000o`80oooo00<0003o0?ooo`3oool00`000?l30?l00180oooo
00D0o`000?ooo`000?l0oooo0000o`0E0?ooo`80003o403oool01@000?l0oooo0?ooo`3oool0003o
0080o`0000@0003o0?ooo`3o0000003o2`3oool00`000?l0o`000?ooo`030?ooo`<0003o00P0oooo
0000o`000?l0oooo0000o`3oool0o`000?ooo`<0o`0000<0oooo0?l0003o00000P3oool00`3o0000
oooo0?l000040?l000<0oooo00D0o`000?ooo`3o0000oooo0?l0000R0?ooo`030?l0003oool0o`00
0080o`0000<0oooo0?l0003oool00`3oool00`3o0000oooo0?l000040?l000<0oooo00<0o`000?oo
o`3oool00P3oool0103o0000oooo0?ooo`3o003o0?oooa`0oooo00150?ooo`030000003oool0oooo
0<P0oooo00<0003o0?ooo`3oool08P3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo
0000o`80oooo0`000?l30?l00180oooo00D0o`000?ooo`000?l0oooo0000o`0E0?ooo`80003o403o
ool01P000?l0oooo0?ooo`3oool0o`000?ooo`80o`000P3oool00`000?l0oooo0?ooo`090?ooo`03
0000o`3o0000oooo00<0oooo0`000?l0203oool0003o0000o`3oool0003o0?ooo`3o0000oooo103o
00001P3oool0o`000?ooo`3oool0o`000?ooo`D0o`000`3oool00`3o0000oooo0?l000020?l00280
oooo00<0o`000?ooo`3o00000P3o00000`3oool0o`000?ooo`030?ooo`030?l0003oool0o`000080
o`0000<0oooo0?l0003oool00P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo0?l0
oooo6P3oool004D0oooo0`0000380?ooo`030000o`3oool0oooo0280oooo00<0003o0?ooo`3oool0
0P3oool010000?l0oooo0?ooo`000?l20?ooo`<0003o00<0o`000?ooo`3o00004P3oool20?l00003
0000o`3oool0003o00/0oooo00<0o`000?ooo`3oool01@3oool010000?l0oooo0000o`000?l@0?oo
o`060000o`3oool0oooo0?ooo`3o0000oooo0P3o00020?ooo`030000o`3oool0oooo00T0oooo0P00
0?l40?ooo`<0003o00P0oooo0000o`000?l0oooo0000o`3oool0o`000?ooo`@0o`0000D0oooo0?l0
003oool0oooo0?l000020?ooo`80o`0000<0oooo0?l0003oool00P3oool00`3o0000oooo0?l00002
0?l00280oooo00<0o`000?ooo`3o00000P3o00000`3oool0o`000?ooo`030?ooo`030?l0003oool0
o`000080o`0000<0oooo0?l0003oool00P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0
oooo0?l0oooo6P3oool004D0oooo00<000000?ooo`3oool0lP3oool010000?l0oooo0?ooo`000?l2
0?ooo`80003o00@0oooo0000o`000?l0o`004@3oool0203o0000003o0?l000000?l0oooo0000o`3o
ool0o`002@3oool00`3o0000oooo0?ooo`040?ooo`030?l000000?l0oooo0080003o403oool01@00
0?l0oooo0?ooo`3oool0o`000080oooo00@0o`000?ooo`3oool0003o2`3oool20000o`<0oooo00H0
o`000000o`000?l0003o0?l000000?l20?ooo`060000o`3oool0o`000?ooo`3o0000oooo0P3o0000
1@3oool0o`000?ooo`3oool0o`000080oooo0P3o00000`3oool0o`000?ooo`020?ooo`030?l0003o
ool0oooo0080o`008P3oool00`3o0000oooo0?l000020?l000070?ooo`3o0000oooo0?ooo`3o0000
oooo0?l000020?ooo`80o`0000<0oooo0?l0003oool00P3oool00`3o0000oooo0?ooo`050?ooo`03
0?l0003oool0oooo0?l0oooo6P3oool004D0oooo00<000000?ooo`3oool0lP3oool010000?l0oooo
0?ooo`000?l20?ooo`80003o00@0oooo0000o`000?l0003o4@3oool0203o0000003o0?l000000?l0
oooo0000o`3oool0o`002@3oool00`3o0000oooo0?ooo`040?ooo`D0003o5`3oool01@3o0000oooo
0?ooo`000?l0o`0000X0oooo0P000?l30?ooo`030?l000000?l0003o00<0003o0P3oool01P000?l0
oooo0?ooo`3oool0o`000?ooo`80o`0000D0oooo0?l0003oool0oooo0?l000020?ooo`80o`0000<0
oooo0?l0003oool00P3oool00`3o0000oooo0?ooo`020?l00280oooo00<0o`000?ooo`3o00000P3o
00001`3oool0o`000?ooo`3oool0o`000?ooo`3o00000P3oool20?l000030?ooo`3o0000oooo0080
oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`3o0?oooaX0oooo00150?ooo`030000
003oool0oooo0?80oooo00@0003o0?ooo`3oool0003o0`3oool01@000?l0oooo0000o`3oool0003o
0140oooo00P0o`000000o`000?l0003o0?ooo`000?l0oooo0000o`T0oooo00<0003o0?ooo`3oool0
103oool40000o`030?l0003oool0oooo01D0oooo00D0o`000?ooo`3oool0o`000000o`090?ooo`03
0?l000000?l0003o00<0oooo00<0o`000000o`000?l00`000?l20?ooo`060000o`3oool0oooo0?oo
o`3o0000oooo0P3o00040?ooo`030?l0003oool0oooo0080o`0000<0oooo0?l0003oool00P3oool0
1@3o0000oooo0?ooo`3oool0o`000280oooo00<0o`000?ooo`3o00000P3o00001`3oool0o`000?oo
o`3oool0o`000?ooo`3o00000P3oool20?l000030?ooo`3o0000oooo00X0oooo00<0o`000?ooo`3o
ool0o`3ooolJ0?ooo`00A@3oool00`000000oooo0?ooo`3b0?ooo`040000o`3oool0oooo0000o`D0
oooo00<0003o0?ooo`000?l04@3oool0203o0000003o0?ooo`000?l0oooo0000o`3oool0003o2@3o
ool00`000?l0oooo0?ooo`040?ooo`@0003o00<0o`000?ooo`3oool0603oool00`3o0000003o0?oo
o`080?ooo`<0003o0`3oool00`000?l0o`000000o`030000o`80oooo00H0003o0?ooo`3oool0oooo
0?l0003oool20?l000@0oooo00D0o`000?ooo`3oool0oooo0?l000050?ooo`050?l0003oool0oooo
0?ooo`3o00008P3oool00`3o0000oooo0?l000020?l000070?ooo`3o0000oooo0?ooo`3o0000oooo
0?l000030?ooo`030?l0003oool0o`0000/0oooo00<0o`000?ooo`3oool0o`3ooolJ0?ooo`00A@3o
ool00`000000oooo0?ooo`3b0?ooo`040000o`3oool0oooo0000o`D0oooo00<0003o0?ooo`000?l0
4@3oool20000o`060?ooo`000?l0oooo0000o`3oool0003o2@3oool00`000?l0oooo0?ooo`040?oo
o`050000o`3oool0003o0000o`3o00006P3oool00`3o0000003o0?ooo`080?ooo`<0003o0`3oool0
0`000?l0o`000000o`030000o`H0oooo00@0o`000?ooo`3o0000o`00203oool00`3o0000oooo0?oo
o`070?ooo`030?l0003oool0oooo0200oooo00<0o`000?ooo`3o00000P3o00001`3oool0o`000?oo
o`3oool0o`000?ooo`3o00000`3oool00`3o0000oooo0?l0000;0?ooo`030?l0003oool0oooo0?l0
oooo6P3oool004D0oooo00<000000?ooo`3oool0lP3oool010000?l0oooo0?ooo`000?l50?ooo`03
0000o`3oool0003o0140oooo0P000?l01P3oool0003o0?ooo`000?l0oooo0000o`T0oooo00<0003o
0?ooo`3oool0103oool010000?l0oooo0000o`000?lK0?ooo`030?l000000?l0oooo00P0oooo0P00
0?l01P3o0000003o0?ooo`3o0000003o0?ooo`80003o00<0o`000000o`3oool01@3oool0103o0000
oooo0?l0003o00080?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool0803oool00`3o
0000oooo0?l000020?l000070?ooo`3o0000o`000?ooo`3o0000oooo0?l000030?ooo`030?l0003o
ool0o`0000/0oooo00<0o`000?ooo`3oool0o`3ooolJ0?ooo`00A@3oool00`000000oooo0?ooo`3b
0?ooo`040000o`3oool0oooo0000o`D0oooo00<0003o0?ooo`000?l04@3oool20000o`<0oooo00D0
003o0?ooo`000?l0oooo0000o`070?ooo`030000o`3oool0oooo00@0oooo00@0003o0?ooo`000?l0
003o6`3oool00`3o0000003o0?ooo`080?ooo`80003o00H0oooo0000o`3oool0o`000000o`3oool2
0000o`80o`001P3oool00`3o0000oooo0?l000090?ooo`030?l0003oool0oooo00L0oooo00<0o`00
0?ooo`3oool0803oool00`3o0000oooo0?l000050?l000040?ooo`3o0000oooo0?l000<0oooo00<0
o`000?ooo`3o00002`3oool00`3o0000oooo0?ooo`3o0?oooaX0oooo00150?ooo`030000003oool0
oooo0?80oooo00@0003o0?ooo`3oool0003o1@3oool00`000?l0oooo0000o`0@0?ooo`030?l00000
0?l0003o00<0oooo00<0003o0?ooo`000?l00P000?l70?ooo`030000o`3oool0oooo00@0oooo00@0
003o0?ooo`000?l0003o6`3oool00`3o0000003o0?ooo`080?ooo`80003o00D0oooo0000o`3oool0
o`000000o`020?ooo`030000o`3o0000o`0000H0oooo00<0o`000?ooo`3o00002@3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo0200oooo00<0o`000?ooo`3oool01@3o0000103oool0
o`000?ooo`3o00030?ooo`030?l0003oool0o`0000/0oooo00<0o`000?ooo`3oool0o`3ooolJ0?oo
o`00A@3oool300000?80oooo00@0003o0?ooo`3oool0003o1@3oool00`000?l0oooo0000o`0@0?oo
o`030?l000000?l0003o00<0oooo00<0003o0?ooo`000?l00P000?l70?ooo`030000o`3oool0oooo
00<0oooo00<0o`000000o`3oool07@3oool00`3o0000003o0?ooo`020?ooo`030000o`3oool0oooo
00<0oooo0P000?l0103oool0003o0?ooo`000?l30?ooo`030000o`3oool0o`0000H0oooo00<0o`00
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0Z0?ooo`030?l0003oool0oooo00L0o`0000<0oooo
0?l0003oool00P3oool00`3o0000oooo0?l0000;0?ooo`030?l0003oool0oooo0?l0oooo6P3oool0
04D0oooo00<000000?ooo`3oool0lP3oool20000o`030?ooo`000?l0oooo00@0oooo00<0003o0?oo
o`000?l0403oool00`3o0000003o0000o`030?ooo`050000o`3oool0003o0?l000000?l01`3oool0
0`000?l0oooo0?ooo`020?ooo`030?l000000?l0003o01l0oooo00H0o`000000o`3oool0oooo0000
o`3o00040?ooo`80003o00@0oooo0000o`3oool0003o0`3oool00`000?l0oooo0?l000060?ooo`03
0?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0;@3oool70?l000030?ooo`3o0000oooo0080
oooo00<0o`000?ooo`3o00002`3oool00`3o0000oooo0?ooo`3o0?oooaX0oooo00150?ooo`030000
003oool0oooo0?80oooo0P000?l00`3oool0003o0?ooo`060?ooo`030000o`3oool0oooo00h0oooo
00<0o`000000o`000?l00`3oool01@000?l0oooo0000o`3o0000003o00L0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000003o0000o`0O0?ooo`070?l000000?l0oooo0?ooo`000?l0o`000000o`03
0?ooo`060000o`3o0000oooo0000o`3o0000003o0`3oool00`000?l0oooo0?ooo`120?ooo`L0o`00
00<0oooo0?l0003oool00P3oool00`3o0000oooo0?l0000;0?ooo`030?l0003oool0oooo0?l0oooo
6P3oool004D0oooo00<000000?ooo`3oool0lP3oool20000o`030?ooo`000?l0oooo00H0oooo00<0
003o0?ooo`3oool03P3oool00`000?l0oooo0000o`030?ooo`050000o`3o0000003o0?ooo`000?l0
1@3oool20000o`030?l000000?l0oooo0080oooo00<0003o0?l0003o00007`3oool0103o0000003o
0?ooo`3oool30000o`<0oooo00H0003o0?ooo`3oool0003o0?l000000?l30?ooo`030000o`3oool0
oooo0480oooo1`3o00000`3oool0o`000?ooo`020?ooo`030?l0003oool0o`0000/0oooo00<0o`00
0?ooo`3oool0o`3ooolJ0?ooo`00A@3oool00`000000oooo0?ooo`3b0?ooo`<0003o203oool00`00
0?l0oooo0?ooo`0>0?ooo`030000o`3oool0003o00<0oooo00D0003o0?l000000?l0oooo0000o`04
0?ooo`<0003o00<0oooo0000o`3oool00P3oool00`000?l0oooo0?l0000O0?ooo`040?l000000?l0
oooo0?ooo`80003o00D0o`000000o`3oool0003o0?l000020?ooo`<0003o0`3oool00`000?l0oooo
0?ooo`120?ooo`H0o`0000<0oooo0?l0003o00000`3oool00`3o0000oooo0?l0000;0?ooo`030?l0
003oool0oooo0?l0oooo6P3oool004D0oooo00<000000?ooo`3oool0lP3oool30000o`P0oooo00<0
003o0?ooo`3oool03P3oool00`000?l0oooo0000o`030?ooo`80003o0P3oool00`000?l0oooo0?oo
o`020?ooo`<0003o00<0oooo0000o`3oool00P3oool00`000?l0oooo0?l0000O0?ooo`040?l00000
0?l0oooo0?ooo`80003o00@0o`000000o`3o0000003o0`3oool20000o`@0oooo00<0003o0?ooo`3o
ool0@`3oool50?l000030?ooo`3o0000oooo00<0oooo00<0o`000?ooo`3oool02`3oool00`3o0000
oooo0?ooo`3o0?oooaX0oooo000Q0?ooo`050?ooe02K0000000000000000L[X0103oool0102jLP00
000000000000L[X40?ooo`040;Yb000000000000002Ke0@0oooo00@0^W8000000000000009_D1`3o
ool00`000000oooo0?ooo`3b0?ooo`<0003o203oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3o
ool0003o00D0oooo0P000?l20?ooo`030000o`3o0000oooo0080oooo0`000?l00`3oool0003o0?oo
o`020?ooo`030000o`3oool0o`0001l0oooo00@0o`000000o`3oool0oooo0P000?l0103o0000003o
0?l000000?l30?ooo`80003o103oool00`000?l0oooo0?ooo`130?ooo`D0o`0000<0oooo0?l0003o
ool00`3oool00`3o0000oooo0?ooo`0;0?ooo`030?l0003oool0oooo0?l0oooo6P3oool00240oooo
00H0^W8009_Do`3oool0oooo0=BK0000Vm@20?ooo`060;Yb001b^^X0oooo0?ooo`3Z^W8009_D0P3o
ool01P3oj[X0Vk[Z0?ooo`3oool0e9/009_Do`80oooo00H0onZj09^jjP3oool0oooo0=BK002Ke?l6
0?ooo`030000003oool0oooo0?80oooo0P000?l90?ooo`030000o`3oool0oooo00`0oooo00<0003o
0?ooo`000?l01@3oool20000o`80oooo0P000?l30?ooo`80003o0P3oool01@000?l0oooo0?ooo`00
0?l0o`000280oooo00<0o`000000o`000?l00P000?l0103o0000003o0000o`000?l30?ooo`80003o
BP3oool30?l000040?ooo`3o0000oooo0?l000@0oooo00<0o`000?ooo`3oool02`3oool00`3o0000
oooo0?ooo`3o0?oooaX0oooo000U0?ooo`030?ooe02KL[X0oooo00D0oooo00H0oooD09]b^P3oool0
oooo0=BK002Ke?l20?ooo`060?oZ^P1bVm@0oooo0?ooo`3DV`00VmCo0P3oool00`3oj[X0LY_D0?oo
o`050?ooo`030000003oool0oooo0?80oooo0P000?l90?ooo`030000o`3oool0oooo00`0oooo00<0
003o0?ooo`000?l01P3oool00`000?l0oooo0?ooo`020000o`<0oooo0P000?l20?ooo`040000o`3o
ool0oooo0000ob<0oooo00<0o`000000o`000?l00P000?l20?l000030?ooo`3o0000oooo0080oooo
00<0003o0?l0003oool0B@3oool30?l000<0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo
0?ooo`3o0?oooaX0oooo000U0?ooo`030=BK001b^^X0oooo00D0oooo00H0omBK002Ke03oool0oooo
0=BKLP2jj_l20?ooo`060?oZ^P1bL[X0oooo0?ooo`3DVg80^^[o0P3oool00`3oj[X0LW:j0?ooo`05
0?ooo`@00000l@3oool20000o`T0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0000o`06
0?ooo`030000o`3oool0oooo00<0003o00@0o`000000o`3o0000003o0P3oool010000?l0oooo0?oo
o`000?lS0?ooo`030?l000000?l0003o0080003o00@0oooo0?l0003oool0o`000`3oool00`000?l0
oooo0?ooo`190?ooo`<0o`005P3oool00`3o0000oooo0?ooo`3o0?oooaX0oooo000R0?ooo`040?oo
e02K00000000001b^P<0oooo00H0onZj07800000000000000000V`3Dool20?ooo`060=BKLP2jj_l0
oooo0?ooo`3oj[X0LW:j0P3oool01P3DVg80^^[o0?ooo`3oool0onZj079b^PH0oooo00<000000?oo
o`3oool0lP3oool20000o`T0oooo00<0003o0?ooo`3oool02P3oool01@000?l0oooo0000o`3oool0
003o00H0oooo00<0003o0?ooo`3oool01@000?l01@3o0000oooo0?ooo`3oool0003o0080oooo00<0
003o0?ooo`3oool08@3oool00`3o0000003o0000o`020000o`030?ooo`3o0000oooo00@0oooo00<0
003o0?ooo`3oool0B@3oool30?l00?l0oooo<`3oool002D0oooo00H0j[Yb07:jjP3oool0oooo0?oZ
^P1bVm@60?ooo`060=BKLP2jj_l0oooo0?ooo`3oj[X0LY_D0P3oool01P3DVg80^^[o0?ooo`3oool0
onZj07:Ke0H0oooo00<000000?ooo`3oool0lP3oool20000o`T0oooo00<0003o0?ooo`3oool02P3o
ool01@000?l0oooo0000o`3oool0003o00H0oooo00<0003o0?ooo`3oool01@000?l01@3o0000oooo
0?ooo`3oool0003o0080oooo00<0003o0?ooo`3oool08@3oool01`3o0000003o0000o`3o0000003o
0?ooo`3o00001@3oool00`000?l0oooo0?ooo`190?ooo`<0o`00o`3ooolc0?ooo`008@3oool01P3D
V`0007:j0?ooo`3oool0j[Yb07:jjP80oooo00<0onZj07:Ke03oool01@3oool01P3oe9/007:j0?oo
o`3oool0e9/009_Do`80oooo00H0omBK001b^P3oool0oooo0=BK002Ke?l60?ooo`030000003oool0
oooo0?80oooo0P000?l90?ooo`030000o`3o0000oooo00X0oooo0`000?l00`3oool0003o0?ooo`05
0?ooo`030000o`3oool0oooo0080003o0P3oool00`000?l0oooo0?ooo`020?ooo`040000o`3o0000
oooo0000ob<0oooo00L0o`000000o`000?l0o`000000o`3oool0o`0000D0oooo00<0o`000?ooo`3o
ool0B@3oool30?l00?l0oooo<`3oool00280oooo00@0j[Yb00000000000007:j0`3oool01P3oj[X0
LP00000000000000002K0=Coo`<0oooo00@0j[Yb00000000000009_D103oool0103Z^W8000000000
0000Vm@70?ooo`030000003oool0oooo0?80oooo0P000?l90?ooo`030000o`3o0000oooo00X0oooo
0`000?l00`3o0000003o0?ooo`050?ooo`030000o`3oool0oooo0080003o0P3oool00`000?l0oooo
0?ooo`020?ooo`040?l000000?l0003o0?l002<0oooo0P3o00001@000?l0o`000000o`3oool0o`00
00D0oooo00<0o`000?ooo`3oool0B@3oool30?l00?l0oooo<`3oool004D0oooo00<000000?ooo`3o
ool0lP3oool20000o`T0oooo00<0003o0?l0003oool02P3oool50000o`H0oooo00<0003o0?ooo`3o
ool00P000?l20?ooo`030000o`3oool0oooo0080oooo00<0o`000000o`000?l0903oool20?l00003
0000o`3oool0003o00L0oooo00<0o`000?ooo`3oool0B@3oool30?l00?l0oooo<`3oool004D0oooo
00<000000?ooo`3oool0lP3oool20000o`T0oooo00<0003o0?l0003oool02P3oool50000o`H0oooo
00<0003o0?ooo`3oool00P000?l20?ooo`030?l0003oool0oooo0080oooo00<0o`000000o`000?l0
903oool01@3o0000oooo0000o`3oool0003o00L0oooo00<0o`000?ooo`3oool0B@3oool00`3o0000
oooo0?l0003o0?oooc<0oooo00150?ooo`030000003oool0oooo0?80oooo00<0o`000000o`3oool0
203oool00`000?l0o`000?ooo`0:0?ooo`D0003o2@3oool01@000?l0oooo0?ooo`3oool0o`0000D0
oooo0P000?lT0?ooo`050?l0003oool0003o0?ooo`000?l0D`3oool00`3o0000oooo0?l0003o0?oo
oc<0oooo00150?ooo`030000003oool0oooo0?80oooo00<0o`000000o`3oool02@3oool00`000?l0
oooo0?ooo`090?ooo`D0003o2@3oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo0P000?lV0?oo
o`030000o`3oool0003o05<0oooo00<0o`000?ooo`3o0000o`3ooolc0?ooo`00A@3oool300000?<0
oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080
oooo00<0o`000000o`000?l00`000?l90?ooo`050000o`3oool0oooo0?ooo`3o00001@3oool00`00
0?l0o`000?ooo`0W0?ooo`030000o`3oool0oooo0540oooo00<0o`000?ooo`3oool0o`3ooolc0?oo
o`00A@3oool00`000000oooo0?ooo`3c0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l000000?l0003o00<0003o2@3oool01@000?l0
oooo0?ooo`3oool0o`0000D0oooo0P3o000X0?ooo`030000o`3oool0oooo0540oooo00<0o`000?oo
o`3oool0o`3ooolc0?ooo`00A@3oool00`000000oooo0?ooo`3c0?ooo`030000o`3oool0oooo00P0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0o`0000<0
003o2@3oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo00<0o`000?ooo`3oool09`3oool00`00
0?l0oooo0?ooo`1A0?ooo`030?l0003oool0oooo0?l0oooo<`3oool004D0oooo00<000000?ooo`3o
ool0l`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?l000030000o`T0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`0W0?ooo`030?l0003oool0oooo0540oooo00<0o`000?ooo`3oool0o`3ooolc0?ooo`00
A@3oool00`000000oooo0?ooo`3c0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0
0`3oool020000?l0oooo0?ooo`3oool0o`000000o`3oool0o`000`000?l90?ooo`030000o`3oool0
oooo0?l0oooo^`3oool004D0oooo00<000000?ooo`3oool0l`3oool00`000?l0oooo0?ooo`080?oo
o`030000o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0oooo0P000?l00`3oool0o`000000o`02
0000o`T0oooo00<0003o0?ooo`3oool0o`3ooonk0?ooo`00A@3oool00`000000oooo0?ooo`3c0?oo
o`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`3oool2
0000o`80oooo0`000?l90?ooo`030000o`3oool0oooo0?l0oooo^`3oool004D0oooo00<000000?oo
o`3oool0l`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00<0oooo00@0003o0?oo
o`3oool0oooo0P000?l20?ooo`<0003oo`3oooo70?ooo`00A@3oool00`000000oooo0?ooo`3c0?oo
o`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`3oool2
0000o`80oooo0`000?oo0?ooolL0oooo00150?ooo`<00000l`3oool00`000?l0oooo0?ooo`080?oo
o`030000o`3oool0oooo0080oooo00<0o`000000o`3oool00P3oool20000o`80oooo00<0o`000000
o`000?l0o`3oooo70?ooo`00A@3oool00`000000oooo0?ooo`3c0?ooo`030000o`3oool0oooo00P0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000003o0?ooo`020?ooo`80003o0P3oool00`3o0000
oooo0000o`3o0?ooolL0oooo00150?ooo`030000003oool0oooo0?<0oooo00<0003o0?ooo`3oool0
203oool00`000?l0o`000?ooo`020?ooo`030?l000000?l0oooo0080oooo0P000?l20?ooo`030?l0
003oool0003o0?l0ooooa`3oool004D0oooo00<000000?ooo`3oool0l`3oool00`000?l0oooo0?oo
o`080?ooo`030000o`3o0000oooo0080oooo00<0o`000000o`3oool00P3oool01`000?l0oooo0?oo
o`3oool0o`000?ooo`000?l0o`3oooo70?ooo`00A@3oool00`000000oooo0?ooo`3c0?ooo`030000
o`3oool0oooo00T0oooo00H0003o0?ooo`3oool0oooo0?l000000?l30?ooo`070000o`3oool0oooo
0?ooo`3o0000oooo0000o`3o0?ooolL0oooo00150?ooo`030000003oool0oooo0?<0oooo00<0003o
0?ooo`3oool02@3oool010000?l0oooo0?ooo`3oool20000o`<0oooo00L0003o0?ooo`3oool0oooo
0?l0003oool0003o0?l0ooooa`3oool004D0oooo00<000000?ooo`3oool0l`3oool00`3o0000oooo
0?ooo`090?ooo`040000o`3oool0oooo0?ooo`80003o0`3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo0?l0ooooa@3oool004D0oooo00<000000?ooo`3oool0o`3oool010000?l0oooo
0?l0003oool20000o`<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`3o0?ooolD0
oooo00150?ooo`030000003oool0oooo0?l0oooo00@0003o0?ooo`3o0000oooo0P000?l30?ooo`03
0000o`3oool0oooo0?l0oooob`3oool004D0oooo0`00003o0?ooo`040000o`3oool0o`000?ooo`80
003o0`3oool00`000?l0oooo0?ooo`3o0?oool/0oooo00150?ooo`030000003oool0oooo0?l0oooo
00@0003o0?ooo`000?l0oooo0P000?l30?ooo`030000o`3oool0oooo0?l0oooob`3oool004D0oooo
00<000000?ooo`3oool0o`3oool010000?l0o`000000o`3oool20000o`<0oooo00<0003o0?ooo`3o
ool0o`3oooo;0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooo`040000o`3o0000003o0?ooo`80
003o0`3oool00`000?l0oooo0?ooo`3o0?oool/0oooo00150?ooo`030000003oool0oooo0?l0oooo
00@0003o0?l000000?l0o`000P000?l30?ooo`030000o`3oool0oooo0?l0oooob`3oool004D0oooo
00<000000?ooo`3oool0o`3oool010000?l0o`000000o`3o00020000o`80o`0000<0oooo0000o`3o
ool0o`3oooo<0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooo`040000o`3oool0003o0?l00080
003o0P3o00000`3oool0003o0?ooo`3o0?oool`0oooo00150?ooo`030000003oool0oooo0?l0oooo
0`000?l01`3o0000003o0000o`3o0000003o0?ooo`000?l0o`3oooo=0?ooo`00A@3oool00`000000
oooo0?ooo`3o0?ooo`<0003o00L0o`000000o`000?l0o`000000o`3o0000003o0?l0ooooc@3oool0
04D0oooo00<000000?ooo`3oool0o`3oool30000o`030?ooo`000?l0003o0080003o00<0o`000000
o`3oool0o`3oooo<0?ooo`00A@3oool300000?l0oooo0`000?l00`3oool0003o0000o`020000o`03
0?ooo`000?l0oooo0?l0ooooc03oool004D0oooo00<000000?ooo`3oool0o`3oool40000o`060?oo
o`000?l0003o0000o`3oool0003oo`3oooo=0?ooo`00A@3oool00`000000oooo0?ooo`3o0?ooo`80
003o00<0oooo0000o`3oool01@000?oo0?ooold0oooo00150?ooo`030000003oool0oooo0?l0oooo
00@0003o0?ooo`3oool0003o0`3oool30000ool0ooooc@3oool004D0oooo00<000000?ooo`3oool0
o`3oool010000?l0oooo0?ooo`000?l30?ooo`<0003oo`3oooo=0?ooo`00A@3oool00`000000oooo
0?ooo`3o0?ooo`L0oooo0P000?oo0?ooolh0oooo000S0?ooo`040=BK00000000000007:jjP<0oooo
00@0^W8000000000000009_D103oool0102jLP00000000000000Vm@40?ooo`040;Yb000000000000
002Ke0L0oooo00<000000?ooo`3oool0o`3oool80?ooo`030000o`3oool0oooo0?l0ooooc03oool0
02@0oooo00<0onZj07:Ke03oool00P3oool01P3oj[X0Vk[Z0?ooo`3oool0e9/009_Do`80oooo00H0
onZj09^jjP3oool0oooo0=BK002Ke?l20?ooo`060?oZ^P2K^^X0oooo0?ooo`3DV`00VmCo1P3oool0
0`000000oooo0?ooo`3o0?ooool0ooooe`3oool002@0oooo00<0onZj07:Ke03oool00P3oool01P3D
V`00VmCo0?ooo`3oool0onZj07:Ke080oooo00H0e9/009_Do`3oool0oooo0?oZ^P1bVm@20?ooo`06
0=BK002Ke?l0oooo0?ooo`3oj[X0LY_D1P3oool00`000000oooo0?ooo`3o0?ooool0ooooe`3oool0
0240oooo00<0e9/00000000000000P0000001@1b^^X0oooo0?ooo`3DVg80^^[o0080oooo00H0onZj
079b^P3oool0oooo0=BKLP2jj_l20?ooo`060?oZ^P1bL[X0oooo0?ooo`3DVg80^^[o0P3oool00`3o
j[X0LW:j0?ooo`050?ooo`@00000o`3ooooo0?ooomH0oooo000Q0?ooo`050>ZjLP00Vm@0oooo0?oZ
^P1bVm@00`3oool01P3DVg80^^[o0?ooo`3oool0onZj079b^P80oooo00H0e9]b0;[Zo`3oool0oooo
0?oZ^P1bL[X20?ooo`060=BKLP2jj_l0oooo0?ooo`3oj[X0LW:j1P3oool00`000000oooo0?ooo`3o
0?ooool0ooooe`3oool00280oooo00@0e9/007:jjP3oj[X0LY_D0`3oool01P3DVg80^^[o0?ooo`3o
ool0onZj07:Ke080oooo00H0e9]b0;[Zo`3oool0oooo0?oZ^P1bVm@20?ooo`060=BKLP2jj_l0oooo
0?ooo`3oj[X0LY_D1P3oool00`000000oooo0?ooo`3o0?ooool0ooooe`3oool002<0oooo00<0^W80
09^j^P1bVm@00`3oool01P3oe9/007:j0?ooo`3oool0e9/009_Do`80oooo00H0omBK001b^P3oool0
oooo0=BK002Ke?l20?ooo`060?oDV`00L[X0oooo0?ooo`3DV`00VmCo1P3oool00`000000oooo0?oo
o`3o0?ooool0ooooe`3oool002<0oooo00<0oooD09/00000Vm@0103oool0103Z^W80000000000000
Vm@40?ooo`040>ZjLP0000000000002Ke0@0oooo00@0j[Yb00000000000009_D1`3oool00`000000
oooo0?ooo`3o0?ooool0ooooe`3oool00?l0ooooo`3ooooo0?ooob00oooo003o0?ooool0ooooo`3o
oolP0?ooo`00o`3ooooo0?ooool0oooo803oool00?l0ooooo`3ooooo0?ooob00oooo003o0?ooool0
ooooo`3ooolP0?ooo`00o`3ooooo0?ooool0oooo803oool00?l0ooooo`3ooooo0?ooob00oooo003o
0?ooool0ooooo`3ooolP0?ooo`00o`3ooom60?ooo`040;Yb000000000000001b^QD0oooo00D0e9/0
000000000000000009_Do`3o0?oook/0oooo003o0?ooodL0oooo00<0^W9b0;[Zo`3oool05`3oool0
0`3oe9/0L[[Z0?ooo`3o0?oook/0oooo003C0?ooo`030?ooe02K000000000080000000@0001b0;[Z
o`3oool0j[Yb0P000000202Ke?l0omBK000000000000L[[Z0?ooo`3oj[X0LP000`000000102Ke?l0
oooo0?ooe02K00040000000509_Do`3oool0oooo0?ooo`3oe9/00P0000000`0009/0e?oo0?ooo`06
0?ooo`060>ZjLP00000000000000000009/0e?oo0P3oool00`3oom@0V`0000000002000000040000
V`3Dool0oooD09/000@0000000/0VmCo0?ooe02K00000000001b^P3oj[X0LP00002Ke03Z^W800000
07:jjP060?ooo`040=BK000000000000001b^P80oooo00D0onZj07800000000009_D0?oDV`020000
000407:jjP3oool0oooD09/000<0000000d0002K0=Coe02K00000000001b^P3oj[X0LP00002Ke03Z
^W80000007:jjP2jLW80Vi]b00<0000000@0L[[Z0?ooo`3oom@0V`00100000001@0009/0e?oo0?oo
o`3oj[X0LP0000<0000000<0VmCo0?ooo`3oool00P3oool0403oe9/0002K0=Coo`3oool0oooD09/0
0000000007:j0?oZ^P1b000009_D0>ZjLP000000L[[Z0?ooe02K0003000000070000V`3Dool0onZj
07800000000009_D0?oDV`020000000407:jjP3oool0oooo0?oDV`80000000<0002K0=Coo`3oool0
o`3ooonI0?ooo`00d`3oool00`3oom@0V`1b0;[Zo`020?ooo`060?oZ^P1bVm@0oooo0?ooo`3Z^W80
VmCo0P3oool01P3oe9/0L[[Z0?ooo`3oool0^W9b0;[Zo`80oooo00<0oooD09]b^P3oool00P3oool0
0`3oe9/0L[[Z0?ooo`050?ooo`060;YbLP2jj_l0oooo0?oDV`0009/0e?oo203oool00`3DV`00VmCo
0?ooo`030?ooo`030;Yb002Ke?l0oooo00H0oooo00<0omBK07:jjP3oool00`3oool0203oom@0Vg:j
0?ooo`3oj[X0LY_D0?ooo`3Z^W80L[[Z1P3oool01P3Z^W8009_D0?ooo`3oool0j[Yb002Ke080oooo
00H0onZj07:Ke03oool0oooo0?oDV`1b^^X20?ooo`030;Yb002Ke?l0oooo00@0oooo00/0oooD09]b
^P3oool0onZj07:Ke03oool0j[Yb07:jjP3oool0^W80001b^P030?ooo`030;YbV`3Dool0oooo0080
oooo00<0j[Yb07:jjP3oool00`3oool01P2jLW80^^[o0?ooo`3oool0oooD09]b^P@0oooo00<0^W9b
0;ZjV`1b^^X00P3oool02`3oom@0Vg:j0?ooo`3oj[X0LY_D0?ooo`3Z^W80L[[Z0?ooo`2jLP00VmCo
00H0oooo00H0onZj07:Ke03oool0oooo0?oDV`1b^^X30?ooo`060;YbLP2jj_l0oooo0?oDV`0009/0
e?ooo`3ooonI0?ooo`00f03oool01P3oom@0V`2K0=Coo`3oool0j[Yb09_Do`80oooo00D0omBK07:j
jP3oool0onZj07:Ke0040?ooo`060=BKLP2jj_l0oooo0?ooo`3oe9/0L[[Z1P3oool00`2jLY/0e?oo
0?ooo`0;0?ooo`030=BK002Ke?l0oooo0080oooo00<0omBK002Ke03oool01`3oool00`3oe9/0L[[Z
0?ooo`030?ooo`080?ooe02KL[X0oooo0?oZ^P1bVm@0oooo0>ZjLP1b^^X60?ooo`060=BKLP2jj_l0
oooo0?ooo`3oj[X0LW:j0P3oool02@3oj[X0LY_D0?ooo`3oool0omBK07:jjP3oool0omBK002Ke006
0?ooo`0;0?ooe02KL[X0oooo0?oZ^P1bVm@0oooo0>ZjLP1b^^X0oooo0;YbLP2jj_l00`3oool00`3Z
^W80VmCo0?ooo`020?ooo`030>ZjLP1b^^X0oooo0080oooo00<0onZj07:Ke03oool00`3oool0503D
Vg80^^[o0?ooo`3oool0omBK002Ke03oool0^W:K0=Coo`3oool0oooD09]b^P3oool0onZj07:Ke03o
ool0j[Yb07:jjP3oe9/009_D1`3oool01P3oj[X0LY_D0?ooo`3oool0omBK07:jjP<0oooo00<0^W:K
0=Coo`3oool0o`3ooonL0?ooo`00f03oool01P3Z^W8007:j0?ooo`3oool0j[Yb09_Do`80oooo00D0
omBK07:jjP3oool0onZj07:Ke0040?ooo`060=BKLP2jj_l0oooo0?ooo`3oe9/0L[[Z1P3oool00`2j
LY/0e?oo0?ooo`0;0?ooo`030=BK002Ke?l0oooo0080oooo00<0omBK0000000000000`0000001P00
09/0e?oo0?ooo`3oool0omBK07:jjP@0oooo00P0oooD09]b^P3oool0onZj07:Ke03oool0j[Yb07:j
jPH0oooo00H0e9]b0;[Zo`3oool0oooo0?ooe02KL[X20?ooo`080?oZ^P1bVm@0oooo0?ooo`3oe9/0
L[[Z0?ooo`3oe9/50000000=0000V`3Dool0oooD09]b^P3oool0onZj07:Ke03oool0j[Yb07:jjP3o
ool0^W8009_Do`030?ooo`030>ZjLP2Ke?l0oooo0080oooo00<0j[Yb07:jjP3oool00P3oool00`3o
j[X0LY_D0?ooo`030?ooo`0C0=BKLP2jj_l0oooo0?ooo`2jLY/0e?oo0?ooo`3oe9/0L[[Z0?ooo`3o
om@0Vg:j0?ooo`3oj[X0LY_D0?ooo`3Z^W80L[[Z0?oDV`05000000050000V`3Dool0oooo0?oZ^P1b
Vm@00P3oool00`3oe9/0L[[Z0?ooo`020?ooo`030;YbV`3Dool0oooo0?l0ooooW03oool00=D0oooo
00@0^W8000000000000007:j0`3oool01P3Z^W80001b0;[Zo`3oool0j[Yb07:jjP80oooo00H0^W80
07:jjP3oool0oooo0?oDV`00L[X30?ooo`060?oDV`00000007:j0?ooo`3oe9/0VmCo0P3oool00`2j
LY/0e?oo0?ooo`0;0?ooo`030=BK002Ke?l0oooo0080oooo00<0oooD09/0V`3Dool00P3oool00`3Z
^W8007:j0?ooo`020?ooo`0>0?oDV`00000007:j0?ooo`3oe9/0VmCo0?ooe02K0000VmCo0?oDV`00
0780^^[o0>ZjLP1b^^X60?ooo`060=BKLP2jj_l0oooo0?ooo`3oom@0Vg:j0P3oool02P3oj[X0LP1b
0;[Zo`3oool0j[Yb07:jjP3oool0oooD09/0V`3Dool20?ooo`0C0>ZjLP00L[X0oooo0?ooe02K0000
VmCo0?oDV`000780^^[o0>ZjLP1b^^X0oooo0;Yb000009/0e?oo0?ooo`3oj[X0LP2K0=Coo`030?oo
o`030>ZjLP1b^^X0oooo00<0oooo00H0^W8007:jjP3oool0oooo0?oDV`00L[X20?ooo`030?oDV`1b
^^X0oooo0080oooo00d0^W:K0=Coo`3oom@0V`0009_Do`3oe9/0001b0;[Zo`3Z^W80L[[Z0?ooe02K
09/0e?oo0080oooo00X0j[Yb001b^P3oool0oooo0?oZ^P1b0780^^[o0?ooo`3Z^W80L[[Z0`3oool0
0`2jLY/0e?oo0?ooo`3o0?oooi`0oooo003D0?ooo`030>ZjLP1b^^X0oooo00D0oooo00H0j[Yb09^j
^P1b000000000000V`3Dool30?ooo`050;Yb0000000000000000V`3Dool00P3oool02@2jLP000000
07:jjP3Z^W8000000000V`3Dool0onZj078000040000000309_Do`3oool0oooo00L0oooo00<0e9/0
09_Do`3oool00`3oool01@3oe9/0000000000000000007:j00<0oooo00l0^W800000001b^^X0j[Yb
0000000009/0e?oD09/00000LW80V`000000LP2je;X0LP000000LP2jj_l01P3oool03P3DVg80^^[o
0?ooo`3oool0oooD09]b^P3oool0onZj07800000LW80LP000000000009/0e?oo0P3oool04P3oe9/0
000000000000000007:j0?ooo`3oom@0V`00001bLP2K0000001b0;[D^P1b0000001b0;[Zo`2jLP00
001b0;ZjV`80000000<0001b0;[Zo`3oool00`3oool00`3Z^W80L[[Z0?ooo`040?ooo`0H0;Yb0000
000000000000V`3Dool0oooo0?ooe02K0000000009_Do`3oool0j[Yb00000000LW80V`00001bLP2K
0000001b0;[D^P1b0000001b0;[Zo`3oool0omBK0`0000003@00L[X0oooo0?ooo`3oj[X0LP00001b
LP1b000000000000V`3Dool0oooo0?oZ^P1b0000100000000`2Ke?l0oooo0?ooo`3o0?oooiP0oooo
003D0?ooo`060>ZjLP1b^^X0oooo0?ooo`3DV`0007:j0P3oool00`3Z^W80VmCo0?ooo`0F0?ooo`03
0;YbV`3Dool0oooo00P0oooo00P0j[Yb07:jjP3oool0e9/009_Do`3oool0^W9b0;[Zoah0oooo00H0
e9]b0;[Zo`3oool0oooo0?ooe02KL[XT0?ooo`030>ZjLP1b^^X0oooo02`0oooo00<0^W:K0=Coo`3o
ool0o`3ooonL0?ooo`00e@3oool02@2jLP00000000000000Vi/0Vg:j0?ooo`3Z^W80000009_Do`0R
0?ooo`030>ZjLP000000000000<0000000<0001b0;[Zo`3oool0703oool01@3DV`0000000000001b
^^X0j[Yb0080000000<007:j0?ooo`3oool07`3oool0103Z^W8000000000001b^^[o0?oool`0oooo
003o0?ooool0ooooo`3ooolP0?ooo`00o`3ooooo0?ooool0oooo803oool00?l0ooooo`3ooooo0?oo
ob00oooo003o0?ooool0ooooo`3ooolP0?ooo`00o`3ooooo0?ooool0oooo803oool00?l0ooooo`3o
oooo0?ooob00oooo003o0?ooool0ooooo`3ooolP0?ooo`00o`3ooooo0?ooool0oooo803oool00?l0
ooooo`3ooooo0?ooob00oooo003o0?ooool0ooooo`3ooolP0?ooo`00o`3ooooo0?ooool0oooo803o
ool00001\
\>"],
  ImageRangeCache->{{{0, 796.938}, {339.063, 0}} -> {-1.07528, -0.648942, \
0.00478483, 0.00478483}, {{19.625, 542.125}, {330.938, 8.0625}} -> {1941.35, \
621.743, 0.154628, 13.8402}, {{568.25, 777.25}, {274, 117.25}} -> {-9.23561, \
-1.146, 0.0200959, 0.0200959}, {{579.438, 641.625}, {262.75, 200.563}} -> \
{-19.6354, -3.45431, 0.0402014, 0.0402014}, {{579.438, 641.625}, {190.625, \
128.438}} -> {-19.6354, -5.77393, 0.0402014, 0.0402014}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Construct the Job Finding Probability F according to \"Reassessing the Ins \
and Outs of Unemployment,\" January 28, 2005 version, Equation (4).\
\>", "Subsubsection"],

Cell[BoxData[{
    \(\(FindM = 
        1.  - \(Drop[UnempM, 1] - Drop[ShortAdjM, 1]\)\/Drop[UnempM, \(-1\)];\
\)\), "\n", 
    \(\(findM = \(-Log[1 - FindM]\);\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Construct\ the\ Separation\ Rate\ s\ according\ to\ Equation\ 5. \)], \
"Subsubsection"],

Cell[BoxData[{
    \(t = 1; sepM = {}; 
    While[t < Length[UnempM], 
      sepM = Append[sepM, 
          s /. \[InvisibleSpace]FindRoot[
              UnempM\[LeftDoubleBracket]t + 
                    1\[RightDoubleBracket] \[Equal] \(\((1 - \
\[ExponentialE]\^\(\(-findM\[LeftDoubleBracket]t\[RightDoubleBracket]\) - \
s\))\)\ s\ \((UnempM\[LeftDoubleBracket]t\[RightDoubleBracket] + EmpM\
\[LeftDoubleBracket]t\[RightDoubleBracket])\)\)\/\(findM\[LeftDoubleBracket]t\
\[RightDoubleBracket] + s\) + \
\[ExponentialE]\^\(\(-findM\[LeftDoubleBracket]t\[RightDoubleBracket]\) - s\)\
\ UnempM\[LeftDoubleBracket]t\[RightDoubleBracket], {s, 0.03}]]; 
      t += 1];\n\), "\n", 
    \(\(SepM = 1 - \[ExponentialE]\^\(-sepM\);\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute Quarterly Averages", "Subsubsection"],

Cell[BoxData[{
    \(\(findQ = 
        1\/3\ Plus @@ 
            Transpose[Partition[findM, 3]];\)\), "\[IndentingNewLine]", 
    \(\(UrateQ = \(1\/3\) 
          Plus @@ Transpose[
              Partition[UrateM, 3]];\)\), "\[IndentingNewLine]", 
    \(\(sepQ = 
        1\/3\ Plus @@ 
            Transpose[Partition[sepM, 3]];\)\), "\[IndentingNewLine]", 
    \(\(HelpQ = 
        Plus @@ Transpose[Partition[HelpM, 3]];\)\), "\[IndentingNewLine]", 
    \(\(UnempQ = Plus @@ Transpose[Partition[UnempM, 3]];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Export\ Data\ for\ LaTeX\)], "Subsubsection"],

Cell[BoxData[{
    \(\(Export["\<find.dat\>", dateQ[findQ]];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<urate.dat\>", 
        dateQ[N[UrateQ]]];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<sep.dat\>", dateQ[sepQ]];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<theta.dat\>", 
        dateQ[N[\(100  HelpQ\)\/UnempQ]]];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<uss.dat\>", 
        dateQ[N[sepQ\/\(sepQ + findQ\)]]];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<uf.dat\>", 
        dateQ[N[Mean[sepQ]\/\(Mean[sepQ] + findQ\)]]];\)\), "\
\[IndentingNewLine]", 
    \(\(Export["\<us.dat\>", 
        dateQ[N[sepQ\/\(sepQ + Mean[findQ]\)]]];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Print the Correlation between the job finding and unemployment rates and \
between the separation and unemployment rates.\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Print[
        Correlation[Detrend[findQ, smooth], 
          Detrend[UrateQ, smooth]]];\)\), "\n", 
    \(\(Print[
        Correlation[Detrend[sepQ, smooth], 
          Detrend[UrateQ, smooth]]];\)\), "\n", 
    \(\(Print[
        Correlation[Detrend[findQ, smooth], 
          Detrend[HelpQ\/UnempQ, smooth]]];\)\)}], "Input"],

Cell[BoxData[
    \(\(-0.96522682969764`\)\)], "Print"],

Cell[BoxData[
    \(0.6492817924646983`\)], "Print"],

Cell[BoxData[
    \(0.9612087820137091`\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Print the output of a regression of \"Hypothetical\" unemployment rates (only \
changes in f or only changes in s) on the actual unemployment rate.\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Print[
        Regress[Transpose[{Detrend[UrateQ, smooth], 
              Detrend[Mean[sepQ]\/\(Mean[sepQ] + findQ\), smooth]}], {1, x}, 
          x]];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        Regress[Transpose[{Detrend[UrateQ, smooth], 
              Detrend[sepQ\/\(sepQ + Mean[findQ]\), smooth]}], {1, x}, 
          x]];\)\)}], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"ParameterTable", "\[Rule]", 
          TagBox[GridBox[{
                {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"SE\"\>", \
"\<\"TStat\"\>", "\<\"PValue\"\>"},
                {"1", \(-7.508118279625338`*^-13\), 
                  "0.002734093382026035`", \(-2.7461089401641525`*^-10\), 
                  "0.9999998771586129`"},
                {"x", "0.7911537416669415`", "0.014532701893472267`", 
                  "54.439549332688664`", "0.`"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            Function[ BoxForm`e$, 
              TableForm[ 
              BoxForm`e$, TableHeadings -> {{1, x}, {"Estimate", "SE", 
                "TStat", "PValue"}}]]]}], 
        ",", \(RSquared \[Rule] 0.9326549426865182`\), 
        ",", \(AdjustedRSquared \[Rule] 0.9323402461570159`\), 
        ",", \(EstimatedVariance \[Rule] 0.0016146575902739292`\), ",", 
        RowBox[{"ANOVATable", "\[Rule]", 
          InterpretationBox[GridBox[{
                {"\<\"\"\>", "\<\"DF\"\>", "\<\"SumOfSq\"\>", \
"\<\"MeanSq\"\>", "\<\"FRatio\"\>", "\<\"PValue\"\>"},
                {"\<\"Model\"\>", "1", "4.7853034308867715`", 
                  "4.7853034308867715`", "2963.6645315462442`", "0.`"},
                {"\<\"Error\"\>", "214", "0.34553672431862087`", 
                  "0.0016146575902739292`", "\<\"\"\>", "\<\"\"\>"},
                {"\<\"Total\"\>", "215", 
                  "5.130840155205393`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            
            TableForm[ {{1, 4.7853034308867715, 4.7853034308867715, 
              2963.6645315462442, 0.0}, {
              214, .34553672431862087, .0016146575902739292}, {215, 
              5.1308401552053926}}, TableHeadings -> {{"Model", "Error", 
              "Total"}, {"DF", "SumOfSq", "MeanSq", "FRatio", 
              "PValue"}}]]}]}], "}"}]], "Print"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"ParameterTable", "\[Rule]", 
          TagBox[GridBox[{
                {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"SE\"\>", \
"\<\"TStat\"\>", "\<\"PValue\"\>"},
                {"1", \(-1.767067443228861`*^-12\), 
                  "0.0032738786160784465`", \(-5.39747391534482`*^-10\), 
                  "0.9999998771586129`"},
                {"x", "0.21699174706641752`", "0.01740185696496761`", 
                  "12.469459294100192`", "0.`"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            Function[ BoxForm`e$, 
              TableForm[ 
              BoxForm`e$, TableHeadings -> {{1, x}, {"Estimate", "SE", 
                "TStat", "PValue"}}]]]}], 
        ",", \(RSquared \[Rule] 0.420819245089896`\), 
        ",", \(AdjustedRSquared \[Rule] 0.41811279296414783`\), 
        ",", \(EstimatedVariance \[Rule] 0.0023151487376481964`\), ",", 
        RowBox[{"ANOVATable", "\[Rule]", 
          InterpretationBox[GridBox[{
                {"\<\"\"\>", "\<\"DF\"\>", "\<\"SumOfSq\"\>", \
"\<\"MeanSq\"\>", "\<\"FRatio\"\>", "\<\"PValue\"\>"},
                {"\<\"Model\"\>", "1", "0.35997649275936244`", 
                  "0.35997649275936244`", "155.48741508722168`", "0.`"},
                {"\<\"Error\"\>", "214", "0.4954418298567141`", 
                  "0.0023151487376481964`", "\<\"\"\>", "\<\"\"\>"},
                {"\<\"Total\"\>", "215", 
                  "0.8554183226160765`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            
            TableForm[ {{1, .35997649275936244, .35997649275936244, 
              155.48741508722168, 0.0}, {
              214, .49544182985671409, .0023151487376481964}, {
              215, .85541832261607653}}, TableHeadings -> {{"Model", "Error", 
              "Total"}, {"DF", "SumOfSq", "MeanSq", "FRatio", 
              "PValue"}}]]}]}], "}"}]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Do the same, dropping the earlier time period.", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(z = 140; Print[start + z\/4 - 1];\), "\n", 
    \(\(Print[
        Regress[Drop[
            Transpose[{Detrend[UrateQ, smooth], 
                Detrend[Mean[sepQ]\/\(Mean[sepQ] + findQ\), smooth]}], 
            z], {1, x}, x]];\)\), "\n", 
    \(\(Print[
        Regress[Drop[
            Transpose[{Detrend[UrateQ, smooth], 
                Detrend[sepQ\/\(sepQ + Mean[findQ]\), smooth]}], z], {1, x}, 
          x]];\)\)}], "Input"],

Cell[BoxData[
    \(1985\)], "Print"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"ParameterTable", "\[Rule]", 
          TagBox[GridBox[{
                {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"SE\"\>", \
"\<\"TStat\"\>", "\<\"PValue\"\>"},
                {"1", "0.007730534467990729`", "0.00423583278773948`", 
                  "1.8250329640883332`", "0.07203169105708751`"},
                {"x", "0.9494311331751619`", "0.028596389011948636`", 
                  "33.201084681651736`", "0.`"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            Function[ BoxForm`e$, 
              TableForm[ 
              BoxForm`e$, TableHeadings -> {{1, x}, {"Estimate", "SE", 
                "TStat", "PValue"}}]]]}], 
        ",", \(RSquared \[Rule] 0.937091521222437`\), 
        ",", \(AdjustedRSquared \[Rule] 0.9362414066443618`\), 
        ",", \(EstimatedVariance \[Rule] 0.0013296598019023323`\), ",", 
        RowBox[{"ANOVATable", "\[Rule]", 
          InterpretationBox[GridBox[{
                {"\<\"\"\>", "\<\"DF\"\>", "\<\"SumOfSq\"\>", \
"\<\"MeanSq\"\>", "\<\"FRatio\"\>", "\<\"PValue\"\>"},
                {"\<\"Model\"\>", "1", "1.465699987517205`", 
                  "1.465699987517205`", "1102.3120240382098`", "0.`"},
                {"\<\"Error\"\>", "74", "0.09839482534077258`", 
                  "0.0013296598019023323`", "\<\"\"\>", "\<\"\"\>"},
                {"\<\"Total\"\>", "75", 
                  "1.5640948128579775`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            
            TableForm[ {{1, 1.465699987517205, 1.465699987517205, 
              1102.3120240382098, 0.0}, {
              74, .098394825340772582, .0013296598019023323}, {75, 
              1.5640948128579775}}, TableHeadings -> {{"Model", "Error", 
              "Total"}, {"DF", "SumOfSq", "MeanSq", "FRatio", 
              "PValue"}}]]}]}], "}"}]], "Print"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"ParameterTable", "\[Rule]", 
          TagBox[GridBox[{
                {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"SE\"\>", \
"\<\"TStat\"\>", "\<\"PValue\"\>"},
                {"1", \(-0.007649354899247244`\), 
                  "0.0048550380526038986`", \(-1.5755499372748833`\), 
                  "0.11939540614872657`"},
                {"x", "0.05018139178843783`", "0.032776684958370834`", 
                  "1.5310087597989988`", "0.13003123901460745`"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            Function[ BoxForm`e$, 
              TableForm[ 
              BoxForm`e$, TableHeadings -> {{1, x}, {"Estimate", "SE", 
                "TStat", "PValue"}}]]]}], 
        ",", \(RSquared \[Rule] 0.030702978576761745`\), 
        ",", \(AdjustedRSquared \[Rule] 0.017604370179150286`\), 
        ",", \(EstimatedVariance \[Rule] 0.0017468201794452827`\), ",", 
        RowBox[{"ANOVATable", "\[Rule]", 
          InterpretationBox[GridBox[{
                {"\<\"\"\>", "\<\"DF\"\>", "\<\"SumOfSq\"\>", \
"\<\"MeanSq\"\>", "\<\"FRatio\"\>", "\<\"PValue\"\>"},
                {"\<\"Model\"\>", "1", "0.004094525228858975`", 
                  "0.004094525228858975`", "2.3439878225812723`", 
                  "0.130031239014606`"},
                {"\<\"Error\"\>", "74", "0.1292646932789509`", 
                  "0.0017468201794452827`", "\<\"\"\>", "\<\"\"\>"},
                {"\<\"Total\"\>", "75", 
                  "0.13335921850780988`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"}
                },
              RowSpacings->1,
              ColumnSpacings->3,
              RowAlignments->Baseline,
              ColumnAlignments->{Left}],
            
            TableForm[ {{1, .0040945252288589751, .0040945252288589751, 
              2.3439878225812723, .130031239014606}, {
              74, .1292646932789509, .0017468201794452827}, {
              75, .13335921850780988}}, TableHeadings -> {{"Model", "Error", 
              "Total"}, {"DF", "SumOfSq", "MeanSq", "FRatio", 
              "PValue"}}]]}]}], "}"}]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Construct the hypothetical unemployment rate with changes only in vacancies\
\>", "Subsubsection"],

Cell[BoxData[{
    \(t = 1; 
    hyp = h /. Solve[\((1 - h)\) Mean[SepM] \[Equal] 
            0.017\ \(h\^0.5\) HelpM[\([\)\(t\)\(]\)]\^0.5, h];\), "\n", 
    \(\(While[t < Length[HelpM], t += 1; 
        hyp = Append[hyp, 
            Last[hyp] + \((1 - Last[hyp])\) Mean[SepM] - 
              0.017\ \(Last[hyp]\^0.5\) 
                HelpM[\([\)\(t\)\(]\)]\^0.5]];\)\), "\n", 
    \(\(hypQ = 
        1\/3\ Plus @@ 
            Transpose[Partition[hyp, 3]];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<hyp.dat\>", dateQ[hypQ]];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<hypt.dat\>", 
        dateQ[Trend[hypQ, smooth]]];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<hypd.dat\>", 
        dateQ[Detrend[hypQ, smooth]]];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<uratet.dat\>", 
        dateQ[Trend[N[UrateQ], smooth]]];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<urated.dat\>", 
        dateQ[Detrend[N[UrateQ], smooth]]];\)\)}], "Input"]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 715}},
WindowSize->{1016, 681},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 6, 119, "Input"],

Cell[CellGroupData[{
Cell[2124, 61, 45, 0, 34, "Subsubsection"],
Cell[2172, 63, 846, 18, 224, "Input"],
Cell[3021, 83, 68, 1, 35, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3126, 89, 82, 1, 34, "Subsubsection"],
Cell[3211, 92, 56, 1, 36, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3304, 98, 44, 0, 34, "Subsubsection"],
Cell[3351, 100, 50, 1, 35, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3438, 106, 220, 4, 53, "Subsubsection"],
Cell[3661, 112, 331, 6, 80, "Text"],

Cell[CellGroupData[{
Cell[4017, 122, 1490, 27, 455, "Input"],
Cell[5510, 151, 150, 2, 51, "Print"],
Cell[5663, 155, 149, 2, 51, "Print"],
Cell[5815, 159, 165, 2, 51, "Print"],
Cell[5983, 163, 172, 2, 51, "Print"],
Cell[6158, 167, 223, 3, 51, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6430, 176, 106, 2, 34, "Subsubsection"],

Cell[CellGroupData[{
Cell[6561, 182, 638, 13, 189, "Input"],
Cell[7202, 197, 154, 3, 30, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7405, 206, 76, 0, 34, "Subsubsection"],
Cell[7484, 208, 81, 1, 51, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7602, 214, 101, 2, 34, "Subsubsection"],

Cell[CellGroupData[{
Cell[7728, 220, 320, 5, 77, "Input"],
Cell[8051, 227, 145736, 3311, 351, 30517, 1884, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[153836, 3544, 177, 3, 53, "Subsubsection"],
Cell[154016, 3549, 176, 4, 75, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[154229, 3558, 108, 2, 35, "Subsubsection"],
Cell[154340, 3562, 740, 14, 217, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[155117, 3581, 51, 0, 34, "Subsubsection"],
Cell[155171, 3583, 528, 12, 168, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[155736, 3600, 65, 1, 35, "Subsubsection"],
Cell[155804, 3603, 670, 13, 238, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[156511, 3621, 154, 3, 34, "Subsubsection"],

Cell[CellGroupData[{
Cell[156690, 3628, 351, 9, 96, "Input"],
Cell[157044, 3639, 55, 1, 30, "Print"],
Cell[157102, 3642, 52, 1, 30, "Print"],
Cell[157157, 3645, 52, 1, 30, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[157258, 3652, 180, 3, 53, "Subsubsection"],

Cell[CellGroupData[{
Cell[157463, 3659, 375, 8, 141, "Input"],
Cell[157841, 3669, 2168, 45, 169, "Print"],
Cell[160012, 3716, 2169, 45, 169, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[162230, 3767, 71, 0, 34, "Subsubsection"],

Cell[CellGroupData[{
Cell[162326, 3771, 458, 11, 176, "Input"],
Cell[162787, 3784, 37, 1, 30, "Print"],
Cell[162827, 3787, 2129, 44, 165, "Print"],
Cell[164959, 3833, 2236, 46, 165, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[167244, 3885, 108, 2, 34, "Subsubsection"],
Cell[167355, 3889, 962, 20, 221, "Input"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

